@@ -30,14 +30,22 @@
 #include "Marker.h"
 
 // Qt
-#include <QtCore/QWeakPointer>
+#include <QString>
+#include <QVariant>
 
 // System
+#include <utility>  // std::pair
+#include <vector>
 #include <set>
 #include <map>
+#include <string>
+#include <list>
+
 
 namespace Rosegarden
 {
+
+
 // We store tempo in quarter-notes per minute * 10^5 (hundred
 // thousandths of a quarter-note per minute).  This means the maximum
 // tempo in a 32-bit integer is about 21400 qpm.  We use a signed int
@@ -52,6 +60,7 @@ class NotationQuantizer;
 
 class CompositionObserver;
 
+
 /// Composition contains a complete representation of a piece of music.
 /**
  * It is a container for multiple Segment objects (m_segments), as well as
@@ -741,6 +750,16 @@ public:
                                     int bars, int beats,
                                     int fractions, int remainder) const;
 
+    enum class TimeMode {
+        MusicalTime,
+        RealTime,
+        RawTime
+    };
+    /// Convert a time in MIDI Ticks (timeT) to various human-readable formats.
+    QString makeTimeString(timeT midiTicks, TimeMode timeMode) const;
+    /// Convert MIDI ticks to a QVariant suitable for a table key column.
+    QVariant makeTimeVariant(timeT midiTicks, TimeMode timeMode) const;
+
 
     /**
      * Get the current playback position.
