@@ -152,7 +152,9 @@ Instrument::getLocalizedPresentationName() const
 
     // translate the left piece (we'll leave the #1..#n as an untranslatable
     // Rosegarden-specific concept unless people are really bothered by it)
-    return QString("%1 %2").arg(QObject::tr(inameL.toLocal8Bit())).arg(inameR);
+    return QString("%1 %2")
+            .arg(QCoreApplication::translate("INSTRUMENT", inameL.toLocal8Bit()))
+            .arg(inameR);
 }
 
 /* unused
@@ -222,7 +224,7 @@ Instrument::isProgramValid() const
          oBankIter != validBanks.end();
          ++oBankIter)
     {
-        if (oBankIter->partialCompare(m_program.getBank())) {
+        if (oBankIter->compareKey(m_program.getBank())) {
             bankValid = true;
             break;
         }
