@@ -23,9 +23,10 @@
 
 #include <string>
 
-// Internal representation of some very MIDI-specific event types
-// that fall clearly outside of NotationTypes and still require
-// representation.
+// Event factories for some very MIDI-specific event types
+// that fall clearly outside of NotationTypes.
+
+// See NotationTypes.h for more Event types.
 
 
 namespace Rosegarden 
@@ -53,7 +54,7 @@ namespace PitchBend
 
 namespace Controller
 {
-    extern const std::string EventType;
+    extern const char *EventType;
     constexpr int EventSubOrdering = -5;
 
     extern const PropertyName NUMBER;
@@ -63,6 +64,34 @@ namespace Controller
     Event *makeEvent(timeT absoluteTime, MidiByte number, MidiByte value);
 }
 
+//////////////////////////////////////////////////////////////////////
+// Registered Parameter Numbers
+namespace RPN
+{
+    extern const char *EventType;
+    constexpr int EventSubOrdering = -5;
+
+    extern const PropertyName NUMBER;
+    extern const PropertyName VALUE;
+
+    /// Returned Event is on heap; caller takes responsibility for ownership.
+    Event *makeEvent(timeT absoluteTime, int number, int value);
+}
+
+//////////////////////////////////////////////////////////////////////
+// Non-Registered Parameter Numbers
+namespace NRPN
+{
+    extern const char *EventType;
+    constexpr int EventSubOrdering = -5;
+
+    extern const PropertyName NUMBER;
+    extern const PropertyName VALUE;
+
+    /// Returned Event is on heap; caller takes responsibility for ownership.
+    Event *makeEvent(timeT absoluteTime, int number, int value);
+}
+
 //////////////////////////////////////////////////////////////////////
 
 namespace KeyPressure
