@@ -1,7 +1,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -17,11 +17,21 @@
 #include "Property.h"
 #include "base/PropertyName.h"
 
+#include <rosegardenprivate_export.h>
+
 #include <map>
 
 namespace Rosegarden {
 
-class PropertyMap : public std::map<PropertyName, PropertyStoreBase *>
+/// Holds name/value pairs in an effort to reduce memory usage.
+/**
+ * Event has a PropertyMap (Event::EventData::m_properties) which allows Event
+ * objects to be flexible about the fields that they contain.  All Event objects
+ * need a time (Event::m_absoluteTime) and (usually) a duration
+ * (Event::m_duration) but not all Event objects need a pitch
+ * (BaseProperties::PITCH).  E.g a control change Event does not need a pitch.
+ */
+class ROSEGARDENPRIVATE_EXPORT PropertyMap : public std::map<PropertyName, PropertyStoreBase *>
 {
 public:
     PropertyMap() { }
