@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -15,7 +15,7 @@
 
 #define RG_MODULE_STRING "[SegmentNotationHelper]"
 // Turn off all debugging here.
-//#define RG_NO_DEBUG_PRINT
+#define RG_NO_DEBUG_PRINT
 
 #include "SegmentNotationHelper.h"
 #include "base/NotationTypes.h"
@@ -32,7 +32,7 @@
 
 //#define DEBUG_DECOUNTERPOINT
 
-namespace Rosegarden 
+namespace Rosegarden
 {
 using std::string;
 using std::list;
@@ -80,6 +80,7 @@ SegmentNotationHelper::findNotationAbsoluteTime(timeT t)
     return i;
 }
 
+/* unused
 Segment::iterator
 SegmentNotationHelper::findNearestNotationAbsoluteTime(timeT t)
 {
@@ -98,6 +99,7 @@ SegmentNotationHelper::findNearestNotationAbsoluteTime(timeT t)
 
     return i;
 }
+*/
 
 void
 SegmentNotationHelper::setNotationProperties(timeT startTime, timeT endTime)
@@ -177,6 +179,7 @@ SegmentNotationHelper::getNextAdjacentNote(iterator i,
     if (!isBeforeEndMarker(i)) return i;
     if (!(*i)->isa(Note::EventType)) return end();
 
+    RG_DEBUG << "getNextAdjacentNote" << *(*i);
     timeT iEnd = getNotationEndTime(*i);
     long ip = 0, jp = 0;
     if (!(*i)->get<Int>(PITCH, ip) && matchPitch) return end();
@@ -192,17 +195,23 @@ SegmentNotationHelper::getNextAdjacentNote(iterator i,
             if (!(*j)->get<Int>(PITCH, jp) || (jp != ip)) continue;
         }
 
+        RG_DEBUG << "getNextAdjacentNote" << jStart << iEnd;
         if (allowOverlap || (jStart == iEnd)) return j;
+        // Allow tying of grace notes
+        bool isGrace = (*i)->has(IS_GRACE_NOTE) &&
+            (*i)->get<Bool>(IS_GRACE_NOTE);
+        RG_DEBUG << "getNextAdjacentNote isGrace" << isGrace;
+        if (isGrace && jStart < iEnd) return j;
     }
 }
 
-   
+
 Segment::iterator
 SegmentNotationHelper::getPreviousAdjacentNote(iterator i,
                                                timeT rangeStart,
                                                bool matchPitch,
                                                bool allowOverlap)
-{ 
+{
     iterator j(i);
     if (!isBeforeEndMarker(i)) return i;
     if (!(*i)->isa(Note::EventType)) return end();
@@ -233,11 +242,11 @@ SegmentNotationHelper::getPreviousAdjacentNote(iterator i,
 
 
 Segment::iterator
-SegmentNotationHelper::findContiguousNext(iterator el) 
+SegmentNotationHelper::findContiguousNext(iterator el)
 {
     std::string elType = (*el)->getType(),
         reject, accept;
-     
+
     if (elType == Note::EventType) {
         accept = Note::EventType;
         reject = Note::EventRestType;
@@ -252,7 +261,7 @@ SegmentNotationHelper::findContiguousNext(iterator el)
     bool success = false;
 
     iterator i = ++el;
-    
+
     for(; isBeforeEndMarker(i); ++i) {
         std::string iType = (*i)->getType();
 
@@ -268,7 +277,7 @@ SegmentNotationHelper::findContiguousNext(iterator el)
 
     if (success) return i;
     else return end();
-    
+
 }
 
 Segment::iterator
@@ -278,7 +287,7 @@ SegmentNotationHelper::findContiguousPrevious(iterator el)
 
     std::string elType = (*el)->getType(),
         reject, accept;
-     
+
     if (elType == Note::EventType) {
         accept = Note::EventType;
         reject = Note::EventRestType;
@@ -319,7 +328,7 @@ SegmentNotationHelper::noteIsInChord(Event *note)
 {
     iterator i = segment().findSingle(note);
     timeT t = note->getNotationAbsoluteTime();
-    
+
     for (iterator j = i; j != end(); ++j) { // not isBeforeEndMarker, unnecessary here
         if (j == i) continue;
         if ((*j)->isa(Note::EventType)) {
@@ -357,7 +366,8 @@ SegmentNotationHelper::noteIsInChord(Event *note)
 
 //!!! This doesn't appear to be used any more and may well not work.
 // Ties are calculated in several different places, and it's odd that
-// we don't have a decent API for them 
+// we don't have a decent API for them
+/* unused
 Segment::iterator
 SegmentNotationHelper::getNoteTiedWith(Event *note, bool forwards)
 {
@@ -389,7 +399,7 @@ SegmentNotationHelper::getNoteTiedWith(Event *note, bool forwards)
             (((*i)->getAbsoluteTime() + (*i)->getDuration()) != myTime)) {
             return end();
         }
-        
+
         if (!(*i)->get<Bool>(forwards ?
                              BaseProperties::TIED_BACKWARD :
                              BaseProperties::TIED_FORWARD, tied) || !tied) {
@@ -401,7 +411,7 @@ SegmentNotationHelper::getNoteTiedWith(Event *note, bool forwards)
 
     return end();
 }
-
+*/
 
 bool
 SegmentNotationHelper::collapseRestsIfValid(Event* e, bool& collapseForward)
@@ -456,7 +466,7 @@ SegmentNotationHelper::collapseRestsIfValid(Event* e, bool& collapseForward)
         insert(e1);
         return true;
     }
-    
+
     return false;
 }
 
@@ -508,7 +518,7 @@ SegmentNotationHelper::splitIntoTie(iterator &from, iterator to,
 
     list<Event *> toInsert;
     list<iterator> toErase;
-          
+
     // Split all the note and rest events in range [from, to[
     //
     for (iterator i = from; i != to; ++i) {
@@ -606,20 +616,20 @@ SegmentNotationHelper::isViable(timeT duration, int dots)
 {
     bool viable;
 
-/*!!!
+/* !!!
     duration = basicQuantizer().quantizeDuration(duration);
 
     if (dots >= 0) {
         viable = (duration == Quantizer(Quantizer::RawEventData,
-                                        Quantizer::DefaultTarget,
+                                        Quantizer::DefaultTarget,  // "DefaultQ"
                                         Quantizer::NoteQuantize, 1, dots).
                   quantizeDuration(duration));
     } else {
         viable = (duration == notationQuantizer().quantizeDuration(duration));
     }
 */
-    
-    //!!! what to do about this?
+
+    // !!! what to do about this?
 
     timeT nearestDuration =
         Note::getNearestNote(duration, dots >= 0 ? dots : 2).getDuration();
@@ -634,7 +644,7 @@ SegmentNotationHelper::isViable(timeT duration, int dots)
 void
 SegmentNotationHelper::makeRestViable(iterator i)
 {
-    timeT absTime = (*i)->getAbsoluteTime(); 
+    timeT absTime = (*i)->getAbsoluteTime();
     timeT duration = (*i)->getDuration();
     erase(i);
     segment().fillWithRests(absTime, absTime + duration);
@@ -752,7 +762,7 @@ SegmentNotationHelper::makeThisNoteViable(iterator noteItr, bool splitAtBars)
             // is longer than the event duration.  The following check will
             // make sure the notation duration is truncated to the event
             // duration thus preventing the endless loop.
-            
+
             // Bug #1419
             //
             // The above referenced check obviously didn't work correctly.  The
@@ -777,11 +787,6 @@ SegmentNotationHelper::makeThisNoteViable(iterator noteItr, bool splitAtBars)
                     e->getAbsoluteTime(), e->getDuration());  // notation
             toInsert.push_back(e1);
             break;
-
-            // Add in the remaining time.
-            toInsert.push_back(e);
-            e = nullptr;
-            break;
         }
 
         toInsert.push_back(splits.first);
@@ -852,9 +857,14 @@ SegmentNotationHelper::insertNote(timeT absoluteTime, Note note, int pitch,
 Segment::iterator
 SegmentNotationHelper::insertNote(Event *modelEvent)
 {
+    RG_DEBUG << "insertNote";
+    RG_DEBUG << *modelEvent;
+
     timeT absoluteTime = modelEvent->getAbsoluteTime();
     iterator i = segment().findNearestTime(absoluteTime);
 
+    RG_DEBUG << "absoluteTime" << absoluteTime;
+
     // If our insertion time doesn't match up precisely with any
     // existing event, and if we're inserting over a rest, split the
     // rest at the insertion time first.
@@ -868,11 +878,23 @@ SegmentNotationHelper::insertNote(Event *modelEvent)
 
     timeT duration = modelEvent->getDuration();
 
-    if (i != end() && (*i)->has(BEAMED_GROUP_TUPLET_BASE)) {
-        duration = duration * (*i)->get<Int>(BEAMED_GROUP_TUPLED_COUNT) /
-            (*i)->get<Int>(BEAMED_GROUP_UNTUPLED_COUNT);
+    iterator j = i;
+    while (j != end()) {
+        // ignore non note/rest
+        bool noteOrRest = (*j)->isa(Note::EventType) ||
+            (*j)->isa(Note::EventRestType);
+        if (noteOrRest) {
+            break;
+        } else {
+            ++j;
+        }
+    }
+    if (j != end() && (*j)->has(BEAMED_GROUP_TUPLET_BASE)) {
+        duration = duration * (*j)->get<Int>(BEAMED_GROUP_TUPLED_COUNT) /
+            (*j)->get<Int>(BEAMED_GROUP_UNTUPLED_COUNT);
     }
 
+    RG_DEBUG << "duration" << duration;
     //!!! Deal with end-of-bar issues!
 
     return insertSomething(i, duration, modelEvent, false);
@@ -908,21 +930,21 @@ SegmentNotationHelper::insertRest(timeT absoluteTime, Note note)
 // iterator (which will have been replaced)
 
 Segment::iterator
-SegmentNotationHelper::collapseRestsForInsert(iterator i,
+SegmentNotationHelper::collapseRestsForInsert(iterator firstRest,
                                               timeT desiredDuration)
 {
     // collapse at most once, then recurse
 
-    if (!segment().isBeforeEndMarker(i) ||
-        !(*i)->isa(Note::EventRestType)) return i;
+    if (!segment().isBeforeEndMarker(firstRest) ||
+        !(*firstRest)->isa(Note::EventRestType)) return firstRest;
 
-    timeT d = (*i)->getDuration();
-    iterator j = findContiguousNext(i); // won't return itr after end marker
-    if (d >= desiredDuration || j == end()) return i;
+    timeT d = (*firstRest)->getDuration();
+    iterator j = findContiguousNext(firstRest); // won't return itr after end marker
+    if (d >= desiredDuration || j == end()) return firstRest;
 
-    Event *e(new Event(**i, (*i)->getAbsoluteTime(), d + (*j)->getDuration()));
+    Event *e(new Event(**firstRest, (*firstRest)->getAbsoluteTime(), d + (*j)->getDuration()));
     iterator ii(insert(e));
-    erase(i);
+    erase(firstRest);
     erase(j);
 
     return collapseRestsForInsert(ii, desiredDuration);
@@ -934,7 +956,7 @@ SegmentNotationHelper::insertSomething(iterator i, int duration,
                                        Event *modelEvent, bool tiedBack)
 {
     // Rules:
-    // 
+    //
     // 1. If we hit a bar line in the course of the intended inserted
     // note, we should split the note rather than make the bar the
     // wrong length.  (Not implemented yet)
@@ -946,7 +968,7 @@ SegmentNotationHelper::insertSomething(iterator i, int duration,
     // then we should insert the new note/rest literally and remove
     // rests as appropriate.  Rests should never prevent us from
     // inserting what the user asked for.
-    // 
+    //
     // 3. If there are notes in the way of an inserted note, however,
     // we split whenever "reasonable" and truncate our user's note if
     // not reasonable to split.  We can't always give users the Right
@@ -1165,30 +1187,37 @@ SegmentNotationHelper::setInsertedNoteGroup(Event *e, iterator i)
 
 
 Segment::iterator
-SegmentNotationHelper::insertClef(timeT absoluteTime, Clef clef)
+SegmentNotationHelper::insertClef(timeT absoluteTime, const Clef& clef)
 {
     return insert(clef.getAsEvent(absoluteTime));
 }
 
 
 Segment::iterator
-SegmentNotationHelper::insertSymbol(timeT absoluteTime, Symbol symbol)
+SegmentNotationHelper::insertSymbol(timeT absoluteTime, const Symbol& symbol)
 {
     return insert(symbol.getAsEvent(absoluteTime));
 }
 
 
 Segment::iterator
-SegmentNotationHelper::insertKey(timeT absoluteTime, Key key)
+SegmentNotationHelper::insertKey(timeT absoluteTime, const Key& key)
 {
     return insert(key.getAsEvent(absoluteTime));
 }
 
 
 Segment::iterator
-SegmentNotationHelper::insertText(timeT absoluteTime, Text text)
+SegmentNotationHelper::insertText(timeT absoluteTime, const Text& text)
 {
-    return insert(text.getAsEvent(absoluteTime));
+    Segment::iterator i = insert(text.getAsEvent(absoluteTime));
+
+    // If text is lyric, invalidateVerseCount() have to be called to avoid a
+    // crash when opening the lyric editor if the lyric is on a still
+    // non-existent verse(fix bug #1598)
+    if (text.getTextType() == Text::Lyric) segment().invalidateVerseCount();
+
+    return i;
 }
 
 
@@ -1322,7 +1351,7 @@ SegmentNotationHelper::deleteEvent(Event *e, bool collapseRest)
         if (i != end()) erase(i);
     }
 
-    return res;    
+    return res;
 }
 
 
@@ -1341,7 +1370,7 @@ SegmentNotationHelper::hasEffectiveDuration(iterator i)
             hasDuration = false;
         }
     }
-    
+
     return hasDuration;
 }
 
@@ -1438,12 +1467,20 @@ SegmentNotationHelper::makeTupletGroup(timeT t, int untupled, int tupled,
 
     for (iterator i = segment().findTime(t); i != end(); ++i) {
 
+        // skip anything that is not a note or a rest
+        bool noteOrRest = (*i)->isa(Note::EventType) ||
+            (*i)->isa(Note::EventRestType);
+        if (! noteOrRest) continue;
+
         if (!haveStartNotationTime) {
             notationTime = (*i)->getNotationAbsoluteTime();
-            fillWithRestsTo = notationTime + (untupled * unit);
+            fillWithRestsTo = notationTime + (tupled * unit);
             haveStartNotationTime = true;
         }
 
+        RG_DEBUG << "SegmentNotationHelper::makeTupletGroup iter" <<
+            *i << (*i)->getNotationAbsoluteTime();
+
         if ((*i)->getNotationAbsoluteTime() >=
             notationTime + (untupled * unit)) break;
 
@@ -1476,6 +1513,27 @@ SegmentNotationHelper::makeTupletGroup(timeT t, int untupled, int tupled,
 
         toInsert.push_back(e);
         toErase.push_back(i);
+        // At the end of a segment we may run out of events before the
+        // tuplet is complete. So complete it here
+        iterator j = i;
+        ++j;
+        if (j == end()) {
+            // yes i is the last event
+            timeT noteEnd = e->getAbsoluteTime() + e->getDuration();
+            timeT tupletEnd = notationTime + (tupled * unit);
+            if (tupletEnd > noteEnd) {
+                RG_DEBUG << "SegmentNotationHelper::makeTupletGroup:" <<
+                    "adding last event to the segment" << noteEnd << tupletEnd;
+                Event *el = new Event(**i, noteEnd, tupletEnd - noteEnd);
+                el->set<Int>(BEAMED_GROUP_ID, groupId);
+                el->set<String>(BEAMED_GROUP_TYPE, GROUP_TYPE_TUPLED);
+
+                el->set<Int>(BEAMED_GROUP_TUPLET_BASE, unit);
+                el->set<Int>(BEAMED_GROUP_TUPLED_COUNT, tupled);
+                el->set<Int>(BEAMED_GROUP_UNTUPLED_COUNT, untupled);
+                toInsert.push_back(el);
+            }
+        }
     }
 
     for (list<iterator>::iterator i = toErase.begin();
@@ -1489,12 +1547,14 @@ SegmentNotationHelper::makeTupletGroup(timeT t, int untupled, int tupled,
     }
 
     if (haveStartNotationTime) {
+        RG_DEBUG << "SegmentNotationHelper::makeTupletGroup: fillWithRests" <<
+            notationTime + (tupled * unit) << fillWithRestsTo;
         segment().fillWithRests(notationTime + (tupled * unit),
                                 fillWithRestsTo);
     }
 }
 
-    
+
 
 
 void
@@ -1527,7 +1587,7 @@ SegmentNotationHelper::unbeamAux(iterator from, iterator to)
 
   Auto-beaming code derived from X11 Rosegarden's ItemListAutoBeam
   and ItemListAutoBeamSub in editor/src/ItemList.c.
-  
+
 */
 
 void
@@ -1617,7 +1677,7 @@ SegmentNotationHelper::autoBeam(iterator from, iterator to, string type)
   which would be going around in the gunman's head as he trains a laser
   sight into your bedroom through the narrow gap in your curtains and
   dances the little red dot around nervously on your wall."
-  
+
 */
 
 void
@@ -1631,7 +1691,7 @@ SegmentNotationHelper::autoBeamBar(iterator from, iterator to,
     timeT minimum = 0;
 
     // If the denominator is 2 or 4, beam in twos (3/4, 6/2 etc).
-    
+
     if (denom == 2 || denom == 4) {
 
         if (num % 3) {
@@ -1807,7 +1867,7 @@ SegmentNotationHelper::guessClef(iterator from, iterator to)
                 Pitch p(**i);
                 totalHeight += p.getHeightOnStaff(clef, key);
                 ++noteCount;
-            } catch (Exception e) {
+            } catch (const Exception &e) {
                 // no pitch in note
             }
         }
@@ -1837,7 +1897,7 @@ bool
 SegmentNotationHelper::removeRests(timeT time, timeT &duration, bool testOnly)
 {
     Event dummy("dummy", time, 0, MIN_SUBORDERING);
-    
+
     RG_DEBUG << "SegmentNotationHelper::removeRests(" << time
               << ", " << duration << ")";
 
@@ -1848,7 +1908,7 @@ SegmentNotationHelper::removeRests(timeT time, timeT &duration, bool testOnly)
            (*from)->getAbsoluteTime() == time &&
            (*from)->getDuration() == 0) ++from;
     if (from == segment().end()) return false;
-    
+
     iterator to = from;
 
     timeT eventTime = time;
@@ -1880,7 +1940,7 @@ SegmentNotationHelper::removeRests(timeT time, timeT &duration, bool testOnly)
 
     bool checkLastRest = false;
     iterator lastEvent = to;
-    
+
     if (eventTime < finalTime) {
         // shorten last event's duration, if possible
 
@@ -1932,7 +1992,7 @@ SegmentNotationHelper::reorganizeRests(timeT startTime, timeT endTime,
 {
     iterator ia = segment().findTime(startTime);
     iterator ib = segment().findTime(endTime);
-    
+
     if (ia == end()) return;
 
     std::vector<iterator> erasable;
@@ -1970,7 +2030,7 @@ SegmentNotationHelper::reorganizeRests(timeT startTime, timeT endTime,
         segment().insert(insertable[ii]);
 }
 
-
+/* unused
 void
 SegmentNotationHelper::normalizeContiguousRests(timeT startTime,
                                                 timeT duration,
@@ -1996,7 +2056,7 @@ SegmentNotationHelper::normalizeContiguousRests(timeT startTime,
         acc += *i;
     }
 }
-
+*/
 
 void
 SegmentNotationHelper::mergeContiguousRests(timeT startTime,
@@ -2033,7 +2093,7 @@ SegmentNotationHelper::collapseNoteAggressively(Event *note,
         (*j)->set<Bool>(TIED_BACKWARD, true);
         return end();
     }
-    
+
     timeT iEnd = (*i)->getNotationAbsoluteTime() + (*i)->getNotationDuration();
     timeT jEnd = (*j)->getNotationAbsoluteTime() + (*j)->getNotationDuration();
 
@@ -2048,7 +2108,7 @@ SegmentNotationHelper::collapseNoteAggressively(Event *note,
     // deselecting fro mthe selection set.
     (*i)->unset(TIED_BACKWARD);
     (*i)->unset(TIED_FORWARD);
-    
+
     (*j)->unset(TIED_BACKWARD);
     (*j)->unset(TIED_FORWARD);
 
@@ -2281,6 +2341,128 @@ SegmentNotationHelper::autoSlur(timeT startTime, timeT endTime, bool legatoOnly)
     }
 }
 
+void SegmentNotationHelper::updateIndications(timeT startTime, timeT endTime)
+{
+    RG_DEBUG << "updateIndications" << startTime << endTime;
+
+    // Find slurs in range and add to slurMap.
+
+    typedef std::list<Event*> NoteList;
+    // Map of slurs to a list of notes covered by that slur.
+    typedef std::map<Event* /* slur */, NoteList /* notes */> SlurMap;
+    SlurMap slurMap;
+
+    // For each Event in the Segment, find the slurs and the notes that go
+    // with them.
+    for (Segment::iterator i = begin();
+         i != end() && segment().isBeforeEndMarker(i); ++i) {
+
+        if ((*i)->getNotationAbsoluteTime() > endTime) break;
+
+        // Indication Event
+        if ((*i)->isa(Indication::EventType)) {
+            RG_DEBUG << "updateIndications found indication";
+            const Indication ind(**i);
+
+            const timeT indicationStart = (*i)->getNotationAbsoluteTime();
+            const timeT indicationEnd = indicationStart + ind.getIndicationDuration();
+            if (indicationEnd < startTime) {
+                RG_DEBUG << "updateIndications ignore out of range indication";
+                continue;
+            }
+
+            // Make sure we get all the Notes in this Indication.
+            // ??? What if it isn't a slur?  We check that afterwards.  E.g.
+            //     what if it is a Crescendo?  That would trigger this extension.
+            //     It doesn't break anything.  It just might do a little more
+            //     work than necessary.  Recommend moving the slur type check
+            //     above this.  More for clarity than performance.
+            if (indicationEnd > endTime) endTime = indicationEnd;
+
+            std::string indType = ind.getIndicationType();
+            RG_DEBUG << "updateIndications found indication" << indType << indicationStart << indicationEnd;
+
+            // Not a slur?  Try the next Event.
+            if (indType != Indication::Slur &&
+                indType != Indication::PhrasingSlur) continue;
+
+            RG_DEBUG << "updateIndications checking (phrasing) slur";
+
+            // Add an entry to the slurMap without any notes.
+            slurMap[*i];
+        }
+
+        // Note Event.
+        if ((*i)->isa(Note::EventType)) {
+            // For each slur in the slurMap...
+            for (SlurMap::value_type& pair : slurMap) {
+                const Event* slurEvent = pair.first;
+                NoteList& noteList = pair.second;
+
+                const timeT slurStart = slurEvent->getNotationAbsoluteTime();
+                const timeT slurEnd = slurStart + slurEvent->getNotationDuration();
+                const timeT noteStart = (*i)->getNotationAbsoluteTime();
+                const timeT noteEnd = noteStart + (*i)->getNotationDuration();
+
+                RG_DEBUG << "updateIndications check note for slur" << noteStart << noteEnd << slurStart << slurEnd;
+
+                // If this note is contained in the slur...
+                if (noteStart >= slurStart && noteEnd <= slurEnd) {
+                    // Add the Note to this slurMap entry.
+                    noteList.push_back(*i);
+
+                    RG_DEBUG << "updateIndications add note to note list" << noteList.size() << &noteList;
+                }
+            }
+        }
+    }
+
+    // The slurMap now contains all (phrasing) slurs each with a list of notes.
+
+    // For each slur in the slurMap, remove or adjust as appropriate.
+    for (SlurMap::value_type& pair : slurMap) {
+        Event* slurEvent = pair.first;
+        const NoteList& noteList = pair.second;
+
+        const timeT slurStart = slurEvent->getNotationAbsoluteTime();
+        const timeT slurEnd = slurStart + slurEvent->getNotationDuration();
+
+        RG_DEBUG << "updateIndications checking slur at" << slurStart << noteList.size() << &noteList;
+
+        if (noteList.size() <= 1) {
+            RG_DEBUG << "updateIndications remove unnecessary slur";
+            // A slur with 1 or 0 notes cannot exist - remove it
+            segment().eraseSingle(slurEvent);
+        } else {
+            // Compute the start and end times of the slur.
+            timeT notesStart = segment().getEndTime();
+            timeT notesEnd = 0;
+
+            // For each note within the slur, adjust the time range.
+            for (const Event *note : noteList) {
+                const timeT noteStart = (note)->getNotationAbsoluteTime();
+                const timeT noteEnd = noteStart + (note)->getNotationDuration();
+
+                if (noteStart < notesStart) notesStart = noteStart;
+                if (noteEnd > notesEnd) notesEnd = noteEnd;
+            }
+
+            RG_DEBUG << "updateIndications check slur length" << slurStart << slurEnd << notesStart << notesEnd;
+
+            // If slur does not match notes, replace it with one that does.
+            if (slurStart != notesStart || slurEnd != notesEnd) {
+                RG_DEBUG << "updateIndications adjust slur" << slurStart << slurEnd << "->" << notesStart << notesEnd;
+
+                const timeT duration = notesEnd - notesStart;
+                Event* newSlur = new Event(*slurEvent, notesStart, duration);
+
+                segment().insert(newSlur);
+                segment().eraseSingle(slurEvent);
+            }
+        }
+    }
+}
+
 int SegmentNotationHelper::findBorderTuplet(iterator it, iterator &start, iterator &end){
     iterator beginB = segment().findTime(segment().getBarStartForTime((*it)->getAbsoluteTime()));
     iterator endB = segment().findTime(segment().getBarEndForTime((*it)->getAbsoluteTime()));
@@ -2328,4 +2510,3 @@ int SegmentNotationHelper::findBorderTuplet(iterator it, iterator &start, iterat
     return count;
 }
 } // end of namespace
-
