@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -18,14 +18,15 @@
 #define RG_SEGMENT_NOTATION_HELPER_H
 
 #include "base/Segment.h"
+#include "base/TimeSignature.h"
 
-namespace Rosegarden 
+namespace Rosegarden
 {
 
-class SegmentNotationHelper : protected SegmentHelper
+class ROSEGARDENPRIVATE_EXPORT SegmentNotationHelper : protected SegmentHelper
 {
 public:
-    SegmentNotationHelper(Segment &t) : SegmentHelper(t) { }
+    explicit SegmentNotationHelper(Segment &t) : SegmentHelper(t) { }
     ~SegmentNotationHelper() override;
 
     using SegmentHelper::segment;
@@ -36,11 +37,11 @@ public:
      * on the whole segment.
      */
     void setNotationProperties(timeT startTime = 0, timeT endTime = 0);
-    
+
     /**
      * Return the notation absolute time plus the notation duration.
      */
-    timeT getNotationEndTime(Event *e);
+    static timeT getNotationEndTime(Event *e);
 
     /**
      * Return an iterator pointing at the first event in the segment
@@ -60,15 +61,15 @@ public:
      * completeness, but in most cases if you're about to call them
      * you should ask yourself why.)
      */
-    iterator findNearestNotationAbsoluteTime(timeT t);
+    // unused iterator findNearestNotationAbsoluteTime(timeT t);
+
 
-    
     /**
      * Looks for another note immediately following the one pointed to
      * by the given iterator, and (if matchPitch is true) of the same
      * pitch, and returns an iterator pointing to that note.  Returns
      * end() if there is no such note.
-     * 
+     *
      * The notes are considered "adjacent" if the quantized start
      * time of one matches the quantized end time of the other, unless
      * allowOverlap is true in which case overlapping notes are also
@@ -91,7 +92,7 @@ public:
      * will be considered.  (This method has no other way to know when
      * to stop scanning; potentially the very first note in the segment
      * could turn out to be adjacent to the very last one.)
-     * 
+     *
      * The notes are considered "adjacent" if the quantized start
      * time of one matches the quantized end time of the other, unless
      * allowOverlap is true in which case overlapping notes are also
@@ -118,7 +119,7 @@ public:
      * both in the same chord) or anything else.  "Contiguous" refers
      * only to their locations in the segment's event container,
      * which normally means what you expect for rests but not notes.
-     * 
+     *
      * See also SegmentNotationHelper::getNextAdjacentNote.
      */
     iterator findContiguousNext(iterator);
@@ -137,7 +138,7 @@ public:
      * both in the same chord) or anything else.  "Contiguous" refers
      * only to their locations in the segment's event container,
      * which normally means what you expect for rests but not notes.
-     * 
+     *
      * See also SegmentNotationHelper::getPreviousAdjacentNote.
      */
     iterator findContiguousPrevious(iterator);
@@ -156,7 +157,7 @@ public:
      * Untested and probably marked-for-expiry -- prefer
      * SegmentPerformanceHelper::getTiedNotes
      */
-    iterator getNoteTiedWith(Event *note, bool goForwards);
+    // unused iterator getNoteTiedWith(Event *note, bool forwards);
 
 
     /**
@@ -166,16 +167,16 @@ public:
      *
      * You should pass note-quantized durations into this method
      */
-    bool isSplitValid(timeT a, timeT b);
+    static bool isSplitValid(timeT a, timeT b);
 
 
     /**
-     * Splits events in the [from, to[ interval into 
+     * Splits events in the [from, to[ interval into
      * tied events of duration baseDuration + events of duration R,
      * with R being equal to the events' initial duration minus baseDuration
      *
      * The events in [from, to[ must all be at the same absolute time
-     * 
+     *
      * Does not check "reasonableness" of expansion first
      *
      * Events may be notes or rests (rests will obviously not be tied)
@@ -211,7 +212,7 @@ public:
      *
      * You should pass note-quantized durations into this method
      */
-    bool isCollapseValid(timeT a, timeT b);
+    static bool isCollapseValid(timeT a, timeT b);
 
     /**
      * If possible, collapses the rest event with the following or
@@ -254,7 +255,7 @@ public:
 
     /**
      * Inserts a rest, doing all the clever split/merge stuff as
-     * appropriate.  Requires segment to be in a composition.  
+     * appropriate.  Requires segment to be in a composition.
      * Returns iterator pointing to last event inserted (there
      * may be more than one, as rest may have had to be split)
      *
@@ -267,35 +268,35 @@ public:
      * Insert a clef.
      * Returns iterator pointing to clef.
      */
-    iterator insertClef(timeT absoluteTime, Clef clef);
+    iterator insertClef(timeT absoluteTime, const Clef& clef);
 
     /**
      * Insert a symbol.
      * Returns iterator pointing to symbol.
      */
-    iterator insertSymbol(timeT absoluteTime, Symbol symbol);
+    iterator insertSymbol(timeT absoluteTime, const Symbol& symbol);
 
     /**
      * Insert a key.
      * Returns iterator pointing to key.
      */
-    iterator insertKey(timeT absoluteTime, Key key);
+    iterator insertKey(timeT absoluteTime, const Key& key);
 
     /**
      * Insert a text event.
      * Returns iterator pointing to text event.
      */
-    iterator insertText(timeT absoluteTime, Text text);
+    iterator insertText(timeT absoluteTime, const Text& text);
 
     /**
      * Deletes a note, doing all the clever split/merge stuff as
-     * appropriate.  Requires segment to be in a composition.  
+     * appropriate.  Requires segment to be in a composition.
      */
     void deleteNote(Event *e, bool collapseRest = false);
 
     /**
      * Deletes a rest, doing all the clever split/merge stuff as
-     * appropriate.  Requires segment to be in a composition.  
+     * appropriate.  Requires segment to be in a composition.
      *
      * @return whether the rest could be deleted -- a rest can only
      * be deleted if there's a suitable rest next to it to merge it
@@ -325,7 +326,7 @@ public:
      * will be acceptable.  The default is whatever the segment's
      * quantizer considers acceptable (probably either 1 or 2 dots).
      */
-    bool isViable(Event *e, int dots = -1) {
+    static bool isViable(Event *e, int dots = -1) {
         return isViable(e->getDuration(), dots);
     }
 
@@ -340,13 +341,13 @@ public:
      * will be acceptable.  The default is whatever the segment's
      * quantizer considers acceptable (probably either 1 or 2 dots).
      */
-    bool isViable(timeT duration, int dots = -1);
+    static bool isViable(timeT duration, int dots = -1);
+
 
-    
     /**
      * Given an iterator pointing to a rest, split that rest up
      * according to the durations returned by TimeSignature's
-     * getDurationListForInterval     
+     * getDurationListForInterval
      */
     void makeRestViable(iterator i);
 
@@ -371,7 +372,7 @@ public:
      * optionally splits notes and rests at barlines -- this is
      * actually the most common user-visible use of this function.
      */
-    void makeNotesViable(iterator i, iterator j, bool splitAtBars = true);
+    void makeNotesViable(iterator from, iterator to, bool splitAtBars = true);
 
 
     /**
@@ -421,7 +422,7 @@ public:
     /**
      * Make a beamed group of tuplet type, whose tuplet properties are
      * specified as "(untupled-count) notes of duration (unit) played
-     * in the time of (tupled-count)".  For example, a quaver triplet 
+     * in the time of (tupled-count)".  For example, a quaver triplet
      * group could be specified with untupled = 3, tupled = 2, unit =
      * (the duration of a quaver).
      *
@@ -470,7 +471,7 @@ public:
      * Guess which clef a section of music is supposed to be in,
      * ignoring any clef events actually found in the section.
      */
-    Clef guessClef(iterator from, iterator to);
+    static Clef guessClef(iterator from, iterator to);
 
 
     /**
@@ -493,7 +494,7 @@ public:
      * duration and the return value appropriately.
      *
      * (Used for Event pasting.)
-     */ 
+     */
     bool removeRests(timeT time, timeT &duration, bool testOnly = false);
 
 
@@ -520,7 +521,7 @@ public:
     iterator collapseNoteAggressively(Event *, timeT rangeEnd);
 
 
-    
+
     std::pair<Event *, Event *> splitPreservingPerformanceTimes(Event *e,
                                                                 timeT q1);
 
@@ -540,7 +541,14 @@ public:
      */
     void autoSlur(timeT startTime, timeT endTime, bool legatoOnly);
 
-    
+    /// Remove and adjust slurs as needed for a time range.
+    /**
+     * ??? This routine really just deals in slurs.  Would a better name be
+     *     updateSlurs()?
+     *
+     */
+    void updateIndications(timeT startTime, timeT endTime);
+
 protected:
     const Quantizer &basicQuantizer();
     const Quantizer &notationQuantizer();
@@ -560,11 +568,11 @@ protected:
 
 
     /// for use by insertNote and insertRest
-    iterator insertSomething(iterator position, int duration,
+    iterator insertSomething(iterator i, int duration,
                              Event *modelEvent, bool tiedBack);
 
     /// for use by insertSomething
-    iterator insertSingleSomething(iterator position, int duration,
+    iterator insertSingleSomething(iterator i, int duration,
                                    Event *modelEvent, bool tiedBack);
 
     /// for use by insertSingleSomething
@@ -575,7 +583,7 @@ protected:
 			    bool groupGraces);
 
     /// for use by unbeam
-    void unbeamAux(iterator from, iterator to);
+    static void unbeamAux(iterator from, iterator to);
 
     /// for use by autoBeam
 
@@ -594,9 +602,10 @@ protected:
     void reorganizeRests(timeT, timeT, Reorganizer);
 
     /// for use by normalizeRests
-    void normalizeContiguousRests(timeT, timeT, std::vector<Event *>&);
+    // unused void normalizeContiguousRests(timeT, timeT, std::vector<Event *>&);
 
     /// for use by collapseRestsAggressively
+    // cppcheck-suppress functionStatic
     void mergeContiguousRests(timeT, timeT, std::vector<Event *>&);
 
     /// find border of tupled
