@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -47,7 +47,7 @@ class Quantizer;
  * an iterator into that container.  Derived classes must call
  * initialise().  It has to be done this way otherwise the expected
  * virtual functions wouldn't get called.
- * 
+ *
  * The initialise() method scans the surrounding area of the list for
  * the maximal set of contiguous or within-the-same-bar elements
  * before and after the passed-in iterator such that all elements are
@@ -168,7 +168,7 @@ public:
     GenericChord(Container &c,
                  Iterator elementInChord,
                  const Quantizer *quantizer,
-                 PropertyName stemUpProperty = PropertyName::EmptyPropertyName);
+                 PropertyName stemUpProperty = PropertyName::Empty());
 
     ~GenericChord() override;
 
@@ -234,10 +234,10 @@ class Chord : public GenericChord<Event, Segment, true>
 
  public:
     Chord(Container &c,
-          Iterator elementInChord,
+          const Iterator& elementInChord,
           const Quantizer *quantizer,
           PropertyName stemUpProperty =
-          PropertyName::EmptyPropertyName)
+          PropertyName::Empty())
         : GenericChord<Element, Container, singleStaff>
               (c, elementInChord, quantizer, stemUpProperty)
         { initialise(); }
@@ -251,10 +251,10 @@ class GlobalChord : public GenericChord<Event, CompositionTimeSliceAdapter, fals
 
  public:
     GlobalChord(Container &c,
-          Iterator elementInChord,
+          const Iterator& elementInChord,
           const Quantizer *quantizer,
           PropertyName stemUpProperty =
-          PropertyName::EmptyPropertyName)
+          PropertyName::Empty())
         : GenericChord<Element, Container, singleStaff>
               (c, elementInChord, quantizer, stemUpProperty)
         { initialise(); }
@@ -373,7 +373,7 @@ AbstractSet<Element, Container>::sample(const Iterator &i, bool)
     const Quantizer &q(getQuantizer());
     Event *e = AbstractSet::getAsEvent(i);
     timeT d(q.getQuantizedDuration(e));
-    
+
     if (e->isa(Note::EventType) || d > 0) {
         if (m_longest == getContainer().end() ||
             d > q.getQuantizedDuration(AbstractSet::getAsEvent(m_longest))) {
@@ -407,7 +407,7 @@ AbstractSet<Element, Container>::sample(const Iterator &i, bool)
 
 
 //////////////////////////////////////////////////////////////////////
- 
+
 template <class Element, class Container, bool singleStaff>
 GenericChord<Element, Container, singleStaff>::GenericChord(Container &c,
                                                             Iterator i,
@@ -493,7 +493,7 @@ GenericChord<Element, Container, singleStaff>::sample(const Iterator &i,
         // explicitly in different groups, or have stems pointing in
         // different directions by design, or have substantially
         // different x displacements, count as separate chords.
-        
+
         // Per #930473 ("Inserting notes into beamed chords is
         // broken"), if one note is in a group and the other isn't,
         // that's no problem.  In fact we should actually modify the
@@ -503,7 +503,7 @@ GenericChord<Element, Container, singleStaff>::sample(const Iterator &i,
 
             Event *e0 = GenericChord::getAsEvent(AbstractSet<Element, Container>::m_baseIterator);
 
-            if (!(m_stemUpProperty == PropertyName::EmptyPropertyName)) {
+            if (!(m_stemUpProperty == PropertyName::Empty())) {
 
                 if (e0->has(m_stemUpProperty) &&
                     e1->has(m_stemUpProperty) &&
@@ -639,7 +639,7 @@ GenericChord<Element, Container, singleStaff>::getPitches() const
         if (GenericChord::getAsEvent(*i)->has(BaseProperties::PITCH)) {
             int pitch = get__Int
                 (GenericChord::getAsEvent(*i), BaseProperties::PITCH);
-            if (pitches.size() > 0 && pitches[pitches.size()-1] == pitch) 
+            if (pitches.size() > 0 && pitches[pitches.size()-1] == pitch)
                 continue;
             pitches.push_back(pitch);
         }
@@ -699,8 +699,8 @@ GenericChord<Element, Container, singleStaff>::getFirstElementNotInChord()
     return m_firstReject;
 }
 
-        
-template <class Element, class Container, bool singleStaff>     
+
+template <class Element, class Container, bool singleStaff>
 bool
 GenericChord<Element, Container, singleStaff>::PitchGreater::operator()(const Iterator &a,
                                                            const Iterator &b)
@@ -709,7 +709,8 @@ GenericChord<Element, Container, singleStaff>::PitchGreater::operator()(const It
         long ap = get__Int(GenericChord::getAsEvent(a), BaseProperties::PITCH);
         long bp = get__Int(GenericChord::getAsEvent(b), BaseProperties::PITCH);
         return (ap < bp);
-    } catch (Event::NoData) {
+    } catch (const Event::NoData &) {
+        // cppcheck-suppress ConfigurationNotChecked
         RG_WARNING << "Bad karma: PitchGreater failed to find one or both pitches";
         return false;
     }
@@ -720,4 +721,3 @@ GenericChord<Element, Container, singleStaff>::PitchGreater::operator()(const It
 
 
 #endif
-
