@@ -62,16 +62,19 @@ Studio::Studio() :
     // And we always have one audio and one soft-synth device, whose
     // IDs match the base instrument numbers (for no good reason
     // except easy identifiability)
-    addDevice(QObject::tr("Audio").toUtf8().data(),
+    addDevice(QCoreApplication::translate("INSTRUMENT",
+                                          "Audio").toUtf8().data(),
               AudioInstrumentBase, AudioInstrumentBase,
               Device::Audio);
-    addDevice(QObject::tr("Synth plugin").toUtf8().data(),
+    addDevice(QCoreApplication::translate("INSTRUMENT",
+                                          "Synth plugin").toUtf8().data(),
               SoftSynthInstrumentBase, SoftSynthInstrumentBase,
               Device::SoftSynth);
 }
 
 Studio::~Studio()
 {
+    RG_DEBUG << "dtor";
     DeviceListIterator dIt = m_devices.begin();
 
     for (; dIt != m_devices.end(); ++dIt)
@@ -86,6 +89,11 @@ Studio::~Studio()
     for (size_t i = 0; i < m_recordIns.size(); ++i) {
         delete m_recordIns[i];
     }
+
+    if (!m_observers.empty()) {
+        RG_WARNING << "dtor: Warning:" << m_observers.size() <<
+            "observers still extant";
+    }
 }
 
 void
@@ -116,6 +124,12 @@ Studio::addDevice(const std::string &name,
     }
 
     m_devices.push_back(d);
+    // inform the observers
+    for(ObserverList::const_iterator i = m_observers.begin();
+        i != m_observers.end(); ++i) {
+        (*i)->deviceAdded(d);
+    }
+
 }
 
 void
@@ -124,8 +138,14 @@ Studio::removeDevice(DeviceId id)
     DeviceListIterator it;
     for (it = m_devices.begin(); it != m_devices.end(); it++) {
         if ((*it)->getId() == id) {
-            delete *it;
+            Device* d = *it;
             m_devices.erase(it);
+            // inform the observers
+            for(ObserverList::const_iterator i = m_observers.begin();
+                i != m_observers.end(); ++i) {
+                (*i)->deviceRemoved(d);
+            }
+            delete(d);
             return;
         }
     }
@@ -926,5 +946,17 @@ Studio::getAvailableMIDIInstrument(const Composition *composition) const
     return SoftSynthInstrumentBase;
 }
 
+void Studio::addObserver(StudioObserver *obs)
+{
+    RG_DEBUG << "addObserver" << this << obs;
+    m_observers.push_back(obs);
+}
+
+void Studio::removeObserver(StudioObserver *obs)
+{
+    RG_DEBUG << "removeObserver" << this << obs;
+    m_observers.remove(obs);
+}
+
 
 }
