@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -18,21 +18,23 @@
 
 #include <string>
 
-// [rwb]
-//
-//   Abstract base class that forces all derived classes
-//   to implement the virtual toXmlString object.
-//
-//   Yes, this is similar to  the XmlStoreableEvent class
-//   in gui/ but with hopes to be more general so that any
-//   classes in base/ can go ahead and implement it.
-//
-//
+#include <rosegardenprivate_export.h>
 
 namespace Rosegarden
 {
 
-class XmlExportable
+
+/**
+ * Abstract base class that forces all derived classes
+ * to implement the virtual toXmlString object.
+ *
+ * Yes, this is similar to the XmlStoreableEvent class
+ * in gui/ but with hopes to be more general so that any
+ * classes in base/ can go ahead and implement it.
+ *
+ * \author rwb
+ */
+class ROSEGARDENPRIVATE_EXPORT XmlExportable
 {
 public:
     XmlExportable() {;}
@@ -40,10 +42,11 @@ public:
 
     virtual std::string toXmlString() const = 0;
 
+    /// Escape any xml special characters and validate utf8.
     static std::string encode(const std::string &);
 };
 
+
 }
 
 #endif // RG_XMLEXPORTABLE_H
-
