@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -41,7 +41,11 @@ class CutCommand : public MacroCommand
 
 public:
     /// Make a CutCommand that cuts events from within a Segment
-    CutCommand(EventSelection &selection,
+    CutCommand(EventSelection *selection,
+               Clipboard *clipboard);
+
+    CutCommand(EventSelection *selection1,
+               EventSelection *selection2,
                Clipboard *clipboard);
 
     /// Make a CutCommand that cuts whole Segments
