@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -19,28 +19,24 @@
 #ifndef RG_SELECTIONPROPERTYCOMMAND_H
 #define RG_SELECTIONPROPERTYCOMMAND_H
 
-#include "base/PropertyName.h"
 #include "base/parameterpattern/ParameterPattern.h"
-#include "document/BasicSelectionCommand.h"
-#include <QString>
+#include "document/BasicCommand.h"
+
 #include <QCoreApplication>
 
 
-class Set;
-
-
 namespace Rosegarden
 {
 
-class SelectionPropertyCommand : public BasicSelectionCommand
+
+// cppcheck-suppress noConstructor
+class SelectionPropertyCommand : public BasicCommand
 {
     Q_DECLARE_TR_FUNCTIONS(Rosegarden::SelectionPropertyCommand)
 
 public:
-
-    SelectionPropertyCommand(ParameterPattern::Result result);
-
-    static QString getGlobalName() { return tr("Set &Property"); }
+    // cppcheck-suppress noConstructor
+    explicit SelectionPropertyCommand(ParameterPattern::Result result);
 
     void modifySegment() override;
 
