@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -44,7 +44,7 @@ public:
                                         timeT endTime) :
         BasicCommand(getGlobalName(), s, startTime, endTime) { }
 
-    NormalizeRestsCommand(EventSelection &selection);
+    explicit NormalizeRestsCommand(EventSelection &selection);
 
     static QString getGlobalName() { return tr("&Normalize Rests"); }
 
