@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -15,21 +15,17 @@
     COPYING included with this distribution for more information.
 */
 
-
 #include "RestoreTiesCommand.h"
 
-#include "base/NotationTypes.h"
 #include "base/Selection.h"
-#include "document/BasicSelectionCommand.h"
 #include "base/BaseProperties.h"
-#include "gui/editors/notation/NotationProperties.h"
 #include "document/CommandRegistry.h"
-#include <QString>
 
 
 namespace Rosegarden
 {
 
+
 void
 RestoreTiesCommand::registerCommand(CommandRegistry *r)
 {
@@ -41,7 +37,7 @@ RestoreTiesCommand::registerCommand(CommandRegistry *r)
 void
 RestoreTiesCommand::modifySegment()
 {
-    EventSelection::eventcontainer::iterator i;
+    EventContainer::iterator i;
 
     for (i = m_selection->getSegmentEvents().begin();
          i != m_selection->getSegmentEvents().end(); ++i) {
@@ -50,4 +46,5 @@ RestoreTiesCommand::modifySegment()
     }
 }
 
+
 }
