@@ -1,10 +1,9 @@
-
 /* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
 
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -19,40 +18,37 @@
 #ifndef RG_UNTUPLETCOMMAND_H
 #define RG_UNTUPLETCOMMAND_H
 
-#include "document/BasicSelectionCommand.h"
-#include <QString>
+#include "document/BasicCommand.h"
+
 #include <QCoreApplication>
 
 
-
-
 namespace Rosegarden
 {
 
+
 class EventSelection;
 class CommandRegistry;
 
-
-class UnTupletCommand : public BasicSelectionCommand
+class UnTupletCommand : public BasicCommand
 {
-    Q_DECLARE_TR_FUNCTIONS(Rosegarden::UnTupletCommand)
+    Q_DECLARE_TR_FUNCTIONS(Rosegarden::UnTupletCommand);
 
 public:
-    UnTupletCommand(EventSelection &selection) :
-        BasicSelectionCommand(getGlobalName(), selection, true),
-        m_selection(&selection) { }
-
-    static QString getGlobalName() {
-        return tr("&Untuplet");
-    }
+    explicit UnTupletCommand(EventSelection &selection) :
+        BasicCommand(tr("&Untuplet"), selection, true),
+        m_selection(&selection)
+    { }
 
     static void registerCommand(CommandRegistry *r);
 
 protected:
     void modifySegment() override;
-    EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
-};
 
+private:
+    // only used on 1st execute (cf bruteForceRedo)
+    EventSelection *m_selection;
+};
 
 
 }
