@@ -18,7 +18,6 @@
 #ifndef RG_ROSEGARDENMAINWINDOW_H
 #define RG_ROSEGARDENMAINWINDOW_H
 
-#include "gui/application/RosegardenMainViewWidget.h"
 #include "base/MidiProgram.h"
 #include "gui/dialogs/TempoDialog.h"
 #include "gui/widgets/ZoomSlider.h"
@@ -60,10 +59,12 @@ class QAction;
 namespace Rosegarden
 {
 
+
+class RosegardenMainViewWidget;
 class TriggerSegmentManager;
 class TransportDialog;
 class TrackParameterBox;
-class TempoView;
+class TempoAndTimeSignatureEditor;
 class SynthPluginManagerDialog;
 class StartupTester;
 class SequenceManager;
@@ -96,6 +97,7 @@ class WarningWidget;
 class DocumentConfigureDialog;
 class ConfigureDialog;
 
+
 /// The main Rosegarden application window.
 /**
   * This class sets up the main window and reads the config file as well as
@@ -429,7 +431,7 @@ protected:
      * good and that (if it exists) the user agrees to overwrite.
      * Return a null string if the write should not go ahead.
      */
-    QString getValidWriteFileName(QString descriptiveExtension, QString label);
+    QString launchSaveAsDialog(QString filter, QString label);
 
     /**
      * Find any non-ASCII strings in a composition that has been
@@ -493,9 +495,6 @@ signals:
     /// emitted when the set of selected segments changes (relayed from RosegardenMainViewWidget)
     void segmentsSelected(const SegmentSelection &);
 
-    /// emitted when the composition state (selected track, solo, etc...) changes
-    void compositionStateUpdate();
-
     /// emitted when a plugin dialog selects a plugin
     void pluginSelected(InstrumentId, int, int);
 
@@ -658,6 +657,11 @@ public slots:
      */
     void slotExportMusicXml();
 
+    /**
+     * Export (render) file to audio (only audio and synth plugins)
+     */
+    void slotExportWAV();
+
     /**
      * closes all open windows by calling close() on each memberList
      * item until the list is empty, then quits the application.  If
@@ -1361,6 +1365,7 @@ public slots:
     void slotTransposeSegments();
     void slotTransposeSemitones();
     void slotSwitchPreset();
+    void slotInterpret();
 
     /// Panic button pressed
     void slotPanic();
@@ -1568,10 +1573,6 @@ private:
     SequencerThread *m_sequencerThread;
     bool m_sequencerCheckedIn;
 
-#ifdef HAVE_LIBJACK
-    QProcess *m_jackProcess;
-#endif // HAVE_LIBJACK
-
     /// CPU meter in the main window status bar.
     /**
      * This is NOT a general-purpose progress indicator.  You want to use
@@ -1618,7 +1619,7 @@ private:
     MidiMixerWindow       *m_midiMixer;
     BankEditorDialog      *m_bankEditor;
     MarkerEditor          *m_markerEditor;
-    TempoView             *m_tempoView;
+    TempoAndTimeSignatureEditor *m_tempoAndTimeSignatureEditor;
     TriggerSegmentManager *m_triggerSegmentManager;
     ConfigureDialog       *m_configDlg;
     DocumentConfigureDialog *m_docConfigDlg;
