@@ -270,7 +270,7 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) :
 
     ++row;
 
-    layout->addWidget(new QLabel(tr("Advanced Looping (beta)"),
+    layout->addWidget(new QLabel(tr("Advanced Looping"),
                                  frame), row, 0);
     m_advancedLooping = new QCheckBox(frame);
     m_advancedLooping->setChecked(Preferences::getAdvancedLooping());
@@ -292,7 +292,7 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) :
 
     ++row;
 
-    layout->addWidget(new QLabel(tr("LV2 Plugin Support (experimental)"),
+    layout->addWidget(new QLabel(tr("LV2 Plugin Support (beta)"),
                                  frame), row, 0);
     m_lv2 = new QCheckBox(frame);
     m_lv2->setChecked(Preferences::getLV2());
@@ -589,9 +589,10 @@ void GeneralConfigurationPage::apply()
 
     settings.setValue("jacktransport", jackTransport);
 
-    MappedEvent mEjackValue(MidiInstrumentBase,  // InstrumentId
-                            MappedEvent::SystemJackTransport,
-                            MidiByte(jackValue));
+    MappedEvent mEjackValue;
+    mEjackValue.setInstrumentId(MidiInstrumentBase);  // ??? Needed?
+    mEjackValue.setType(MappedEvent::SystemJackTransport);
+    mEjackValue.setData1(MidiByte(jackValue));
     StudioControl::sendMappedEvent(mEjackValue);
 
     settings.endGroup();
