@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -33,11 +33,10 @@ class RosegardenDocument;
 
 class DocumentConfigureDialog : public ConfigureDialogBase
 {
-    //Q_OBJECT
+    Q_OBJECT
 public:
-    DocumentConfigureDialog(RosegardenDocument *doc,
-                            QWidget *parent=nullptr,
-                            const char *name=nullptr);
+    DocumentConfigureDialog(QWidget *parent,
+                            const char *name = nullptr);
 
     void showAudioPage();
 
