@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -36,9 +36,9 @@ namespace Rosegarden
 class IdentifyTextCodecDialog : public QDialog
 {
     Q_OBJECT
-    
+
 public:
-    IdentifyTextCodecDialog(QWidget *parent, std::string text);
+    IdentifyTextCodecDialog(QWidget *parent, const std::string& text);
 
     QString getCodec() const { return m_codec; }
 
@@ -47,7 +47,7 @@ protected slots:
 
 protected:
     QString getExampleText();
-    
+
     std::string m_text;
     QString m_codec;
     QStringList m_codecs;
