@@ -288,13 +288,16 @@ ManageMetronomeDialog::populate(int deviceIndex)
 
             QString iname(QObject::tr((*iit)->getName().c_str()));
             QString ipname((*iit)->getLocalizedPresentationName());
-            QString programName(QObject::tr((*iit)->getProgramName().c_str()));
+            QString programName(
+                QCoreApplication::translate("INSTRUMENT",
+                                            (*iit)->getProgramName().c_str()));
 
             QString text;
 
             if ((*iit)->getType() == Instrument::SoftSynth) {
 
-                iname.replace(QObject::tr("Synth plugin "), "");
+                iname.replace(QCoreApplication::translate("INSTRUMENT",
+                                                          "Synth plugin "), "");
                 programName = "";
 
                 AudioPluginInstance *plugin = (*iit)->getPlugin
