@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -15,6 +15,7 @@
     COPYING included with this distribution for more information.
 */
 
+#define RG_MODULE_STRING "[SimpleEventEditDialog]"
 
 #include "SimpleEventEditDialog.h"
 #include "base/BaseProperties.h"
@@ -24,10 +25,13 @@
 #include "document/RosegardenDocument.h"
 #include "gui/editors/guitar/Chord.h"
 #include "misc/Strings.h"
+#include "misc/Debug.h"
+#include "misc/ConfigGroups.h"  // for LastUsedPathsConfigGroup
 #include "PitchDialog.h"
 #include "TimeDialog.h"
 #include "gui/widgets/LineEdit.h"
 #include "gui/widgets/FileDialog.h"
+#include "sound/Midi.h"
 
 #include <QComboBox>
 #include <QDialog>
@@ -37,12 +41,14 @@
 #include <QGroupBox>
 #include <QGridLayout>
 #include <QLabel>
+#include <QMessageBox>
 #include <QPushButton>
 #include <QSpinBox>
 #include <QString>
 #include <QWidget>
 #include <QVBoxLayout>
 #include <QLayout>
+#include <QSettings>
 
 
 
@@ -104,8 +110,9 @@ SimpleEventEditDialog::SimpleEventEditDialog(QWidget *parent,
 
         // Connect up the combos
         //
-        connect(m_typeCombo, SIGNAL(activated(int)),
-                SLOT(slotEventTypeChanged(int)));
+        connect(m_typeCombo,
+                    static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
+                this, &SimpleEventEditDialog::slotEventTypeChanged);
 
     } else {
 
@@ -331,13 +338,13 @@ SimpleEventEditDialog::setupForEvent()
 
         try {
             m_pitchSpinBox->setValue(m_event.get<Int>(PITCH));
-        } catch (Event::NoData) {
+        } catch (const Event::NoData &) {
             m_pitchSpinBox->setValue(60);
         }
 
         try {
             m_velocitySpinBox->setValue(m_event.get<Int>(VELOCITY));
-        } catch (Event::NoData) {
+        } catch (const Event::NoData &) {
             m_velocitySpinBox->setValue(100);
         }
 
@@ -369,14 +376,14 @@ SimpleEventEditDialog::setupForEvent()
         try {
             m_pitchSpinBox->setValue(m_event.get<Int>
                                      (Controller::NUMBER));
-        } catch (Event::NoData) {
+        } catch (const Event::NoData &) {
             m_pitchSpinBox->setValue(0);
         }
 
         try {
             m_velocitySpinBox->setValue(m_event.get<Int>
                                         (Controller::VALUE));
-        } catch (Event::NoData) {
+        } catch (const Event::NoData &) {
             m_velocitySpinBox->setValue(0);
         }
 
@@ -407,14 +414,14 @@ SimpleEventEditDialog::setupForEvent()
         try {
             m_pitchSpinBox->setValue(m_event.get<Int>
                                      (KeyPressure::PITCH));
-        } catch (Event::NoData) {
+        } catch (const Event::NoData &) {
             m_pitchSpinBox->setValue(0);
         }
 
         try {
             m_velocitySpinBox->setValue(m_event.get<Int>
                                         (KeyPressure::PRESSURE));
-        } catch (Event::NoData) {
+        } catch (const Event::NoData &) {
             m_velocitySpinBox->setValue(0);
         }
 
@@ -444,7 +451,7 @@ SimpleEventEditDialog::setupForEvent()
         try {
             m_pitchSpinBox->setValue(m_event.get<Int>
                                      (ChannelPressure::PRESSURE));
-        } catch (Event::NoData) {
+        } catch (const Event::NoData &) {
             m_pitchSpinBox->setValue(0);
         }
 
@@ -477,7 +484,7 @@ SimpleEventEditDialog::setupForEvent()
         try {
             m_pitchSpinBox->setValue(m_event.get<Int>
                                      (ProgramChange::PROGRAM) + 1);
-        } catch (Event::NoData) {
+        } catch (const Event::NoData &) {
             m_pitchSpinBox->setValue(0);
         }
 
@@ -509,10 +516,11 @@ SimpleEventEditDialog::setupForEvent()
         m_controllerLabel->setText(tr("Data length:"));
         m_metaLabel->setText(tr("Data:"));
         try {
-            SystemExclusive sysEx(m_event);
+            std::string datablock;
+            m_event.get<String>(SystemExclusive::DATABLOCK, datablock);
             m_controllerLabelValue->setText(QString("%1").
-                                            arg(sysEx.getRawData().length()));
-            m_metaEdit->setText(strtoqstr(sysEx.getHexData()));
+                    arg(SystemExclusive::toRaw(datablock).length()));
+            m_metaEdit->setText(strtoqstr(datablock));
         } catch (...) {
             m_controllerLabelValue->setText("0");
         }
@@ -544,14 +552,14 @@ SimpleEventEditDialog::setupForEvent()
         try {
             m_pitchSpinBox->setValue(m_event.get<Int>
                                      (PitchBend::MSB));
-        } catch (Event::NoData) {
+        } catch (const Event::NoData &) {
             m_pitchSpinBox->setValue(0);
         }
 
         try {
             m_velocitySpinBox->setValue(m_event.get<Int>
                                         (PitchBend::LSB));
-        } catch (Event::NoData) {
+        } catch (const Event::NoData &) {
             m_velocitySpinBox->setValue(0);
         }
 
@@ -1053,48 +1061,90 @@ SimpleEventEditDialog::slotEditPitch()
 void
 SimpleEventEditDialog::slotSysexLoad()
 {
-    QString path = FileDialog::getOpenFileName( this, tr("Load System Exclusive data in File"), QDir::currentPath(),
-                   tr("System exclusive files") + " (*.syx *.SYX)" + ";;" +
-                   tr("All files") + " (*)"); //":SYSTEMEXCLUSIVE",
+    QSettings settings;
+    settings.beginGroup(LastUsedPathsConfigGroup);
+    const QString pathKey = "load_sysex";
+    QString directory = settings.value(pathKey, QDir::homePath()).toString();
 
-    if (path.isNull())
+    QString name = FileDialog::getOpenFileName(
+            this,  // parent
+            tr("Load System Exclusive data in File"),  // caption
+            directory,  // dir
+            tr("System exclusive files") + " (*.syx *.SYX)" + ";;" +
+                tr("All files") + " (*)");  // filter
+
+    if (name.isNull())
         return ;
 
-    QFile file(path);
+    QFile file(name);
     file.open(QIODevice::ReadOnly);
     std::string s;
     char c;
-    bool ioOk;
 
-    while ((ioOk = file.getChar(&c))) {
-        if (c == static_cast<char>(0xf0)) break;
-    }
-    while (ioOk) {
-        s += c;
-        if (c == static_cast<char>(0xf7))
+    // Discard leading bytes up to and including the first SysEx Start (F0).
+    while (file.getChar(&c)) {
+        if (c == static_cast<char>(MIDI_SYSTEM_EXCLUSIVE))
             break;
-        ioOk = file.getChar(&c);
     }
+    // Copy up to but not including SysEx End (F7).
+    while (file.getChar(&c)) {
+        if (c == static_cast<char>(MIDI_END_OF_EXCLUSIVE))
+            break;
+        s += c;
+    }
+
     file.close();
+
+    if (s.empty())
+        QMessageBox::critical(this, tr("Rosegarden"), tr("Could not load SysEx file."));
+
     m_metaEdit->setText(strtoqstr(SystemExclusive::toHex(s)));
+
+    // Write the directory to the settings
+    QDir d = QFileInfo(name).dir();
+    directory = d.canonicalPath();
+    settings.setValue(pathKey, directory);
+    settings.endGroup();
 }
 
 void
 SimpleEventEditDialog::slotSysexSave()
 {
-    QString path = FileDialog::getSaveFileName( this, //":SYSTEMEXCLUSIVE",
-			tr("Save System Exclusive data to..."),
-					tr("*.syx|System exclusive files (*.syx)")
-					);
-    if (path.isNull())
-        return ;
+    QSettings settings;
+    settings.beginGroup(LastUsedPathsConfigGroup);
+    const QString pathKey = "save_sysex";
+    QString directory = settings.value(pathKey, QDir::homePath()).toString();
 
-    QFile file(path);
+    QString name = FileDialog::getSaveFileName(
+            this,  // parent
+            tr("Save System Exclusive data to..."),  // caption
+            directory,  // dir
+            "",  // defaultName
+            tr("System exclusive files") + " (*.syx *.SYX)" + ";;" +
+                tr("All files") + " (*)");  // filter
+            //tr("*.syx|System exclusive files (*.syx)"));  // filter
+    if (name.isNull())
+        return;
+
+    QFile file(name);
     file.open(QIODevice::WriteOnly);
-    SystemExclusive sysEx(m_event);
-    file.write(sysEx.getRawData().c_str(),
-               static_cast<qint64>(sysEx.getRawData().length()));
+
+    std::string datablock;
+    m_event.get<String>(SystemExclusive::DATABLOCK, datablock);
+    // Add SysEx and End SysEx status bytes.
+    datablock = "F0 " + datablock + " F7";
+    datablock = SystemExclusive::toRaw(datablock);
+    file.write(datablock.c_str(),
+               static_cast<qint64>(datablock.length()));
+
     file.close();
+
+    // Write the directory to the settings
+    QDir d = QFileInfo(name).dir();
+    directory = d.canonicalPath();
+    settings.setValue(pathKey, directory);
+    settings.endGroup();
 }
 
+
 }
