@@ -16,13 +16,16 @@
 */
 
 #define RG_MODULE_STRING "[EventView]"
+#define RG_NO_DEBUG_PRINT
 
 #include "EventView.h"
+
 #include "EventViewItem.h"
 #include "TrivialVelocityDialog.h"
 
 #include "base/BaseProperties.h"
 #include "base/Clipboard.h"
+#include "base/Composition.h"
 #include "base/Event.h"
 #include "base/MidiTypes.h"
 #include "base/NotationTypes.h"
@@ -47,11 +50,11 @@
 #include "commands/segment/SetTriggerSegmentDefaultTimeAdjustCommand.h"
 #include "misc/ConfigGroups.h"
 #include "document/RosegardenDocument.h"
+#include "document/CommandHistory.h"
 #include "gui/dialogs/EventEditDialog.h"
 #include "gui/dialogs/PitchDialog.h"
 #include "gui/dialogs/SimpleEventEditDialog.h"
 #include "gui/dialogs/AboutDialog.h"
-#include "gui/general/ListEditView.h"
 #include "gui/general/IconLoader.h"
 #include "gui/general/MidiPitchLabel.h"
 #include "gui/widgets/TmpStatusMsg.h"
@@ -65,16 +68,11 @@
 #include <QDialog>
 #include <QFrame>
 #include <QGroupBox>
-#include <QHBoxLayout>
-#include <QIcon>
 #include <QLabel>
-#include <QLayout>
 #include <QMenu>
-#include <QPixmap>
 #include <QPoint>
 #include <QPushButton>
 #include <QSettings>
-#include <QSize>
 #include <QStatusBar>
 #include <QString>
 #include <QTreeWidget>
@@ -83,7 +81,7 @@
 #include <QWidget>
 #include <QDesktopServices>
 
-#include <algorithm>
+#include <algorithm>  // std:find()
 
 
 namespace Rosegarden
@@ -91,18 +89,24 @@ namespace Rosegarden
 
 
 EventView::EventView(RosegardenDocument *doc,
-                     const std::vector<Segment *>& segments,
-                     QWidget *parent):
-        ListEditView(segments, 2, parent),
-        m_eventFilter(Note | Text | SystemExclusive | Controller |
-                      ProgramChange | PitchBend | Indication | Other |
-                      GeneratedRegion | SegmentID),
-        m_menu(nullptr)
+                     const std::vector<Segment *> &segments) :
+    EditViewBase(segments)
 {
+    setStatusBar(new QStatusBar(this));
+
+    // Connect for changes so we can update the list.
+    connect(RosegardenDocument::currentDocument,
+                &RosegardenDocument::documentModified,
+            this, &EventView::slotDocumentModified);
+
+    // For each Segment...
+    for (Segment *segment : m_segments) {
+        segment->addObserver(this);
+    }
+
     setAttribute(Qt::WA_DeleteOnClose);
 
-    m_isTriggerSegment = false;
-    m_triggerName = m_triggerPitch = m_triggerVelocity = nullptr;
+    // Note: EditView only edits the first Segment in segments.
 
     if (!segments.empty()) {
         Segment *s = *segments.begin();
@@ -116,9 +120,18 @@ EventView::EventView(RosegardenDocument *doc,
     initStatusBar();
     setupActions();
 
+    // Create frame and layout.
+    // ??? Push down to derivers.
+    m_frame = new QFrame(this);
+    m_frame->setMinimumSize(500, 300);
+    m_frame->setMaximumSize(2200, 1400);
+    m_gridLayout = new QGridLayout(m_frame);
+    m_frame->setLayout(m_gridLayout);
+    setCentralWidget(m_frame);
+
     // define some note filtering buttons in a group
     //
-    m_filterGroup = new QGroupBox( tr("Event filters"), getCentralWidget() );
+    m_filterGroup = new QGroupBox(tr("Event filters"), m_frame);
     QVBoxLayout *filterGroupLayout = new QVBoxLayout;
     m_filterGroup->setAlignment( Qt::AlignHorizontal_Mask );
 
@@ -151,13 +164,13 @@ EventView::EventView(RosegardenDocument *doc,
     filterGroupLayout->addWidget(m_otherCheckBox);
     m_filterGroup->setLayout(filterGroupLayout);
 
-    m_grid->addWidget(m_filterGroup, 2, 0);
+    m_gridLayout->addWidget(m_filterGroup, 2, 0);
 
-    m_eventList = new QTreeWidget(getCentralWidget());
+    m_eventList = new QTreeWidget(m_frame);
 
     //m_eventList->setItemsRenameable(true); //&&& use item->setFlags( Qt::ItemIsSelectable | Qt::ItemIsEditable );
 
-    m_grid->addWidget(m_eventList, 2, 1);
+    m_gridLayout->addWidget(m_eventList, 2, 1);
 
     if (m_isTriggerSegment) {
 
@@ -165,12 +178,14 @@ EventView::EventView(RosegardenDocument *doc,
         TriggerSegmentRec *rec =
             segments[0]->getComposition()->getTriggerSegmentRec(id);
 
-        QGroupBox *frame = new QGroupBox( tr("Triggered Segment Properties"), getCentralWidget() );
+        // ??? rename: groupBox
+        QGroupBox *frame = new QGroupBox(tr("Triggered Segment Properties"), m_frame);
         frame->setAlignment( Qt::AlignHorizontal_Mask );
         frame->setContentsMargins(5, 5, 5, 5);
         QGridLayout *layout = new QGridLayout(frame);
         layout->setSpacing(5);
 
+        // Label
         layout->addWidget(new QLabel(tr("Label:  "), frame), 0, 0);
         QString label = strtoqstr(segments[0]->getLabel());
         if (label == "") label = tr("<no label>");
@@ -181,6 +196,7 @@ EventView::EventView(RosegardenDocument *doc,
         connect(editButton, &QAbstractButton::clicked,
                 this, &EventView::slotEditTriggerName);
 
+        // Base pitch
         layout->addWidget(new QLabel(tr("Base pitch:  "), frame), 1, 0);
         m_triggerPitch = new QLabel(QString("%1").arg(rec->getBasePitch()), frame);
         layout->addWidget(m_triggerPitch, 1, 1);
@@ -189,6 +205,7 @@ EventView::EventView(RosegardenDocument *doc,
         connect(editButton, &QAbstractButton::clicked,
                 this, &EventView::slotEditTriggerPitch);
 
+        // Base velocity
         layout->addWidget(new QLabel(tr("Base velocity:  "), frame), 2, 0);
         m_triggerVelocity = new QLabel(QString("%1").arg(rec->getBaseVelocity()), frame);
         layout->addWidget(m_triggerVelocity, 2, 1);
@@ -233,11 +250,11 @@ EventView::EventView(RosegardenDocument *doc,
         */
 
         frame->setLayout(layout);
-        m_grid->addWidget(frame, 2, 2);
+        m_gridLayout->addWidget(frame, 2, 2);
 
     }
 
-    updateViewCaption();
+    updateWindowTitle(false);
     connect(RosegardenDocument::currentDocument, &RosegardenDocument::documentModified,
             this, &EventView::updateWindowTitle);
 
@@ -258,16 +275,16 @@ EventView::EventView(RosegardenDocument *doc,
     m_eventList->setAllColumnsShowFocus(true);
     m_eventList->setSelectionMode( QAbstractItemView::ExtendedSelection );
 
-    QStringList sl;
-    sl << tr("Time  ");
-    sl << tr("Duration  ");
-    sl << tr("Event Type  ");
-    sl << tr("Pitch  ");
-    sl << tr("Velocity  ");
-    sl << tr("Type (Data1)  ");
-    sl << tr("Type (Data1)  ");
-    sl << tr("Value (Data2)  ");
-    m_eventList->setHeaderLabels(sl);
+    QStringList columnNames;
+    columnNames << tr("Time  ");
+    columnNames << tr("Duration  ");
+    columnNames << tr("Event Type  ");
+    columnNames << tr("Pitch  ");
+    columnNames << tr("Velocity  ");
+    columnNames << tr("Type (Data1)  ");
+    columnNames << tr("Type (Data1)  ");
+    columnNames << tr("Value (Data2)  ");
+    m_eventList->setHeaderLabels(columnNames);
 
     // Make sure time columns have the right amount of space.
     // ??? We should use the font size of "000-00-00-00" as the default size.
@@ -280,33 +297,41 @@ EventView::EventView(RosegardenDocument *doc,
 
     readOptions();
     setButtonsToFilter();
-    applyLayout();
+    updateTreeWidget();
 
     // Connect the checkboxes AFTER calling setButtonsToFilter() to set up the
     // initial states.  Otherwise, the first state change triggers
     // slotModifyFilter() prematurely, and it wrecks the filter.
-    //
-    // That took an astonishing amount of time to work out.
-    //
-    //
-    connect(m_noteCheckBox, &QCheckBox::stateChanged, this, &EventView::slotModifyFilter);
-    connect(m_programCheckBox, &QCheckBox::stateChanged, this, &EventView::slotModifyFilter);
-    connect(m_controllerCheckBox, &QCheckBox::stateChanged, this, &EventView::slotModifyFilter);
-    connect(m_pitchBendCheckBox, &QCheckBox::stateChanged, this, &EventView::slotModifyFilter);
-    connect(m_sysExCheckBox, &QCheckBox::stateChanged, this, &EventView::slotModifyFilter);
-    connect(m_keyPressureCheckBox, &QCheckBox::stateChanged, this, &EventView::slotModifyFilter);
-    connect(m_channelPressureCheckBox, &QCheckBox::stateChanged, this, &EventView::slotModifyFilter);
-    connect(m_restCheckBox, &QCheckBox::stateChanged, this, &EventView::slotModifyFilter);
-    connect(m_indicationCheckBox, &QCheckBox::stateChanged, this, &EventView::slotModifyFilter);
-    connect(m_textCheckBox, &QCheckBox::stateChanged, this, &EventView::slotModifyFilter);
-    connect(m_generatedRegionCheckBox, &QCheckBox::stateChanged, this, &EventView::slotModifyFilter);
-    connect(m_segmentIDCheckBox, &QCheckBox::stateChanged, this, &EventView::slotModifyFilter);
-    connect(m_otherCheckBox, &QCheckBox::stateChanged, this, &EventView::slotModifyFilter);
+    // ??? Use clicked() instead of stateChanged() to avoid this.
+    connect(m_noteCheckBox, &QCheckBox::stateChanged,
+            this, &EventView::slotModifyFilter);
+    connect(m_programCheckBox, &QCheckBox::stateChanged,
+            this, &EventView::slotModifyFilter);
+    connect(m_controllerCheckBox, &QCheckBox::stateChanged,
+            this, &EventView::slotModifyFilter);
+    connect(m_pitchBendCheckBox, &QCheckBox::stateChanged,
+            this, &EventView::slotModifyFilter);
+    connect(m_sysExCheckBox, &QCheckBox::stateChanged,
+            this, &EventView::slotModifyFilter);
+    connect(m_keyPressureCheckBox, &QCheckBox::stateChanged,
+            this, &EventView::slotModifyFilter);
+    connect(m_channelPressureCheckBox, &QCheckBox::stateChanged,
+            this, &EventView::slotModifyFilter);
+    connect(m_restCheckBox, &QCheckBox::stateChanged,
+            this, &EventView::slotModifyFilter);
+    connect(m_indicationCheckBox, &QCheckBox::stateChanged,
+            this, &EventView::slotModifyFilter);
+    connect(m_textCheckBox, &QCheckBox::stateChanged,
+            this, &EventView::slotModifyFilter);
+    connect(m_generatedRegionCheckBox, &QCheckBox::stateChanged,
+            this, &EventView::slotModifyFilter);
+    connect(m_segmentIDCheckBox, &QCheckBox::stateChanged,
+            this, &EventView::slotModifyFilter);
+    connect(m_otherCheckBox, &QCheckBox::stateChanged,
+            this, &EventView::slotModifyFilter);
 
     makeInitialSelection(doc->getComposition().getPosition());
 
-    slotCompositionStateUpdate();
-
 
     // Restore window geometry and toolbar/dock state
     QSettings settings;
@@ -318,24 +343,17 @@ EventView::EventView(RosegardenDocument *doc,
 
 EventView::~EventView()
 {
-    for (unsigned int i = 0; i < m_segments.size(); ++i) {
-        //RG_DEBUG << "dtor - removing this observer from " << m_segments[i];
-        m_segments[i]->removeObserver(this);
+    saveOptions();
+
+    for (Segment *segment : m_segments) {
+        segment->removeObserver(this);
     }
 }
 
 void
 EventView::closeEvent(QCloseEvent *event)
 {
-    // Save m_eventFilter for next time
-    slotSaveOptions();
-
-    // Save window geometry and toolbar/dock state
-    QSettings settings;
-    settings.beginGroup(WindowGeometryConfigGroup);
-    settings.setValue("Event_List_View_Geometry", this->saveGeometry());
-    settings.setValue("Event_List_View_State", this->saveState());
-    settings.endGroup();
+    // ??? This does nothing.  Get rid of it.
 
     QWidget::closeEvent(event);
 }
@@ -346,46 +364,30 @@ EventView::eventRemoved(const Segment *, Event *e)
     m_deletedEvents.insert(e);
 }
 
-void
-EventView::segmentDeleted(const Segment *s)
-{
-    std::vector<Segment *>::iterator i = std::find(m_segments.begin(), m_segments.end(), s);
-
-    if (i != m_segments.end()) {
-        m_segments.erase(i);
-    } else {
-        RG_DEBUG << "%%% WARNING - EventView::segmentDeleted() called on non-registered segment - should not happen\n";
-    }
-
-}
-
 bool
-EventView::applyLayout()
+EventView::updateTreeWidget()
 {
-    // If no selection has already been set then we copy what's
-    // already set and try to replicate this after the rebuild
-    // of the view.
-    //
+    // ??? This selection stuff is extremely buggy.  It stores the indices,
+    //     so if anything has changed, it will re-select the wrong items.
+    //     It also completely loses the scroll position.  Working on fixing
+    //     this in TempoView.  See that for the latest.
+
+    // If no selection, copy UI selection to m_listSelection.
     if (m_listSelection.size() == 0) {
 
-        QList<QTreeWidgetItem*> selection = m_eventList->selectedItems();
-
-        if( selection.count() ){
-
-            for( int i=0; i< selection.count(); i++ ) {
+        QList<QTreeWidgetItem *> selection = m_eventList->selectedItems();
 
+        if (!selection.empty()) {
+            for (int i = 0; i < selection.count(); ++i) {
                 QTreeWidgetItem *listItem = selection.at(i);
-                m_listSelection.push_back( m_eventList->indexOfTopLevelItem(listItem) );
-
+                m_listSelection.push_back(
+                        m_eventList->indexOfTopLevelItem(listItem));
             }
-        }// end if selection.count()
-    }// end if m_listSel..
+        }
+    }
 
     // *** Create the event list.
 
-    // ??? Why is this routine called applyLayout() if it is primarily
-    //     creating the event list?
-
     m_eventList->clear();
 
     QSettings settings;
@@ -601,16 +603,19 @@ EventView::applyLayout()
                                                  timeMode);
             }
 
-            QString timeStr = makeTimeString(eventTime, timeMode);
+            const QString timeStr = RosegardenDocument::currentDocument->
+                    getComposition().makeTimeString(
+                            eventTime,
+                            static_cast<Composition::TimeMode>(timeMode));
 
             QStringList sl;
             sl << timeStr
-            << durationStr
-            << strtoqstr( (*it)->getType() )
-            << pitchStr
-            << velyStr
-            << data1Str
-            << data2Str;
+               << durationStr
+               << strtoqstr( (*it)->getType() )
+               << pitchStr
+               << velyStr
+               << data1Str
+               << data2Str;
 
             new EventViewItem(m_segments[i],
                               *it,
@@ -708,46 +713,13 @@ EventView::makeInitialSelection(timeT time)
     m_eventList->scrollToItem(goodItem);
 }
 
-QString
-EventView::makeTimeString(timeT time, int timeMode)
-{
-    switch (timeMode) {
-
-    case 0:  // musical time
-        {
-            int bar, beat, fraction, remainder;
-            RosegardenDocument::currentDocument->getComposition().getMusicalTimeForAbsoluteTime
-            (time, bar, beat, fraction, remainder);
-            ++bar;
-            return QString("%1%2%3-%4%5-%6%7-%8%9   ")
-                   .arg(bar / 100)
-                   .arg((bar % 100) / 10)
-                   .arg(bar % 10)
-                   .arg(beat / 10)
-                   .arg(beat % 10)
-                   .arg(fraction / 10)
-                   .arg(fraction % 10)
-                   .arg(remainder / 10)
-                   .arg(remainder % 10);
-        }
-
-    case 1:  // real time
-        {
-            RealTime rt =
-                RosegardenDocument::currentDocument->getComposition().getElapsedRealTime(time);
-            //    return QString("%1  ").arg(rt.toString().c_str());
-            return QString("%1  ").arg(rt.toText().c_str());
-        }
-
-    default:
-        return QString("%1  ").arg(time);
-    }
-}
-
 QString
 EventView::makeDurationString(timeT time,
                               timeT duration, int timeMode)
 {
+    // ??? Same as TriggerSegmentManager::makeDurationString().  Move to
+    //     Composition like makeTimeString().
+
     switch (timeMode) {
 
     case 0:  // musical time
@@ -781,15 +753,6 @@ EventView::makeDurationString(timeT time,
     }
 }
 
-void
-EventView::refreshSegment(Segment * /*segment*/,
-                          timeT /*startTime*/,
-                          timeT /*endTime*/)
-{
-    RG_DEBUG << "EventView::refreshSegment";
-    applyLayout();
-}
-
 void
 EventView::updateView()
 {
@@ -811,7 +774,7 @@ EventView::slotEditTriggerName()
         SegmentSelection selection;
         selection.insert(m_segments[0]);
         SegmentLabelCommand *cmd = new SegmentLabelCommand(selection, newLabel);
-        addCommandToHistory(cmd);
+        CommandHistory::getInstance()->addCommand(cmd);
         m_triggerName->setText(newLabel);
     }
 }
@@ -827,8 +790,11 @@ EventView::slotEditTriggerPitch()
     PitchDialog *dlg = new PitchDialog(this, tr("Base pitch"), rec->getBasePitch());
 
     if (dlg->exec() == QDialog::Accepted) {
-        addCommandToHistory(new SetTriggerSegmentBasePitchCommand
-                            (&RosegardenDocument::currentDocument->getComposition(), id, dlg->getPitch()));
+        CommandHistory::getInstance()->addCommand(
+                new SetTriggerSegmentBasePitchCommand(
+                        &RosegardenDocument::currentDocument->getComposition(),
+                        id,
+                        dlg->getPitch()));
         m_triggerPitch->setText(QString("%1").arg(dlg->getPitch()));
     }
 }
@@ -845,8 +811,11 @@ EventView::slotEditTriggerVelocity()
                                  (this, tr("Base velocity"), rec->getBaseVelocity());
 
     if (dlg->exec() == QDialog::Accepted) {
-        addCommandToHistory(new SetTriggerSegmentBaseVelocityCommand
-                            (&RosegardenDocument::currentDocument->getComposition(), id, dlg->getVelocity()));
+        CommandHistory::getInstance()->addCommand(
+                new SetTriggerSegmentBaseVelocityCommand(
+                        &RosegardenDocument::currentDocument->getComposition(),
+                        id,
+                        dlg->getVelocity()));
         m_triggerVelocity->setText(QString("%1").arg(dlg->getVelocity()));
     }
 }
@@ -942,8 +911,8 @@ EventView::slotEditCut()
             m_listSelection.push_back(itemIndex);
         }
 
-        addCommandToHistory(new CutCommand(cutSelection,
-                                           getClipboard()));
+        CommandHistory::getInstance()->addCommand(
+                new CutCommand(cutSelection, Clipboard::mainClipboard()));
     }
 }
 
@@ -986,16 +955,16 @@ EventView::slotEditCopy()
     }
 
     if (copySelection) {
-        addCommandToHistory(new CopyCommand(copySelection,
-                                            getClipboard()));
+        CommandHistory::getInstance()->addCommand(
+                new CopyCommand(copySelection, Clipboard::mainClipboard()));
     }
 }
 
 void
 EventView::slotEditPaste()
 {
-    if (getClipboard()->isEmpty()) {
-        slotStatusHelpMsg(tr("Clipboard is empty"));
+    if (Clipboard::mainClipboard()->isEmpty()) {
+        showStatusBarMessage(tr("Clipboard is empty"));
         return ;
     }
 
@@ -1028,13 +997,13 @@ EventView::slotEditPaste()
 
 
     PasteEventsCommand *command = new PasteEventsCommand
-                                  (*m_segments[0], getClipboard(),
+                                  (*m_segments[0], Clipboard::mainClipboard(),
                                    insertionTime, PasteEventsCommand::MatrixOverlay);
 
     if (!command->isPossible()) {
-        slotStatusHelpMsg(tr("Couldn't paste at this point"));
+        showStatusBarMessage(tr("Couldn't paste at this point"));
     } else
-        addCommandToHistory(command);
+        CommandHistory::getInstance()->addCommand(command);
 
     RG_DEBUG << "EventView::slotEditPaste - pasting "
     << selection.count() << " items";
@@ -1087,7 +1056,8 @@ EventView::slotEditDelete()
             m_listSelection.push_back(itemIndex);
         }
 
-        addCommandToHistory(new EraseCommand(deleteSelection));
+        CommandHistory::getInstance()->addCommand(
+                new EraseCommand(deleteSelection));
         updateView();
     }
 }
@@ -1136,7 +1106,7 @@ EventView::slotEditInsert()
                     *m_segments[0],
                     new Event(dialog.getEvent()));
 
-    addCommandToHistory(command);
+    CommandHistory::getInstance()->addCommand(command);
 }
 
 void
@@ -1186,7 +1156,7 @@ EventView::slotEditEvent()
                                  event,
                                  dialog.getEvent());
 
-    addCommandToHistory(command);
+    CommandHistory::getInstance()->addCommand(command);
 }
 
 void
@@ -1231,7 +1201,7 @@ EventView::slotEditEventAdvanced()
                                  event,
                                  dialog.getEvent());
 
-    addCommandToHistory(command);
+    CommandHistory::getInstance()->addCommand(command);
 }
 
 void
@@ -1258,7 +1228,11 @@ EventView::slotClearSelection()
 void
 EventView::setupActions()
 {
-    ListEditView::setupActions("eventlist.rc");
+    setupBaseActions();
+
+    createAction("edit_cut", SLOT(slotEditCut()));
+    createAction("edit_copy", SLOT(slotEditCopy()));
+    createAction("edit_paste", SLOT(slotEditPaste()));
 
     createAction("insert", SLOT(slotEditInsert()));
     createAction("delete", SLOT(slotEditDelete()));
@@ -1278,7 +1252,7 @@ EventView::setupActions()
     QAction *raw = createAction("time_raw", SLOT(slotRawTime()));
     raw->setCheckable(true);
 
-    createMenusAndToolbars(getRCFileName());
+    createMenusAndToolbars("eventlist.rc");
 
     QSettings settings;
     settings.beginGroup(EventViewConfigGroup);
@@ -1326,26 +1300,31 @@ void
 EventView::readOptions()
 {
     QSettings settings;
+
     settings.beginGroup(EventViewConfigGroup);
 
-    EditViewBase::readOptions();
     m_eventFilter = settings.value("event_list_filter", m_eventFilter).toInt();
 
-    QByteArray qba = settings.value(EventViewLayoutConfigGroupName).toByteArray();
+    const QByteArray qba = settings.value(EventViewLayoutConfigGroupName).toByteArray();
     m_eventList->restoreGeometry(qba);
 
     settings.endGroup();
 }
 
 void
-EventView::slotSaveOptions()
+EventView::saveOptions()
 {
     QSettings settings;
-    settings.beginGroup(EventViewConfigGroup);
 
+    settings.beginGroup(EventViewConfigGroup);
     settings.setValue("event_list_filter", m_eventFilter);
     settings.setValue(EventViewLayoutConfigGroupName, m_eventList->saveGeometry());
+    settings.endGroup();
 
+    // Save window geometry and toolbar/dock state
+    settings.beginGroup(WindowGeometryConfigGroup);
+    settings.setValue("Event_List_View_Geometry", this->saveGeometry());
+    settings.setValue("Event_List_View_State", this->saveState());
     settings.endGroup();
 }
 
@@ -1389,7 +1368,7 @@ EventView::slotModifyFilter()
 
     if (m_otherCheckBox->isChecked()) m_eventFilter |= EventView::Other;
 
-    applyLayout();
+    updateTreeWidget();
 }
 
 void
@@ -1420,7 +1399,7 @@ EventView::slotMusicalTime()
     findAction("time_musical")->setChecked(true);
     findAction("time_real")->setChecked(false);
     findAction("time_raw")->setChecked(false);
-    applyLayout();
+    updateTreeWidget();
 
     settings.endGroup();
 }
@@ -1435,7 +1414,7 @@ EventView::slotRealTime()
     findAction("time_musical")->setChecked(false);
     findAction("time_real")->setChecked(true);
     findAction("time_raw")->setChecked(false);
-    applyLayout();
+    updateTreeWidget();
 
     settings.endGroup();
 }
@@ -1450,7 +1429,7 @@ EventView::slotRawTime()
     findAction("time_musical")->setChecked(false);
     findAction("time_real")->setChecked(false);
     findAction("time_raw")->setChecked(true);
-    applyLayout();
+    updateTreeWidget();
 
     settings.endGroup();
 }
@@ -1507,7 +1486,7 @@ EventView::slotPopupEventEditor(QTreeWidgetItem *item, int /* column */)
                                  event,
                                  dialog.getEvent());
 
-    addCommandToHistory(command);
+    CommandHistory::getInstance()->addCommand(command);
 }
 
 void
@@ -1535,7 +1514,6 @@ EventView::slotPopupMenu(const QPoint& pos)
 void
 EventView::createMenu()
 {
-    // cppcheck-suppress publicAllocationError
     m_menu = new QMenu(this);
 
     QAction *eventEditorAction =
@@ -1588,7 +1566,7 @@ EventView::slotOpenInEventEditor(bool /* checked */)
                                  event,
                                  dialog.getEvent());
 
-    addCommandToHistory(command);
+    CommandHistory::getInstance()->addCommand(command);
 }
 
 void
@@ -1626,22 +1604,13 @@ EventView::slotOpenInExpertEventEditor(bool /* checked */)
                                  event,
                                  dialog.getEvent());
 
-    addCommandToHistory(command);
+    CommandHistory::getInstance()->addCommand(command);
 }
 
 void
-EventView::updateViewCaption()
+EventView::updateWindowTitle(bool modified)
 {
-    // err on the side of not showing modified status here, rather than showing
-    // a false positive, since we're kind of kludging this together with the
-    // existing virtual updateViewCaption() method
-    updateWindowTitle();
-}
-
-void
-EventView::updateWindowTitle(bool m)
-{
-    QString indicator = (m ? "*" : "");
+    QString indicator = (modified ? "*" : "");
 
     if (m_isTriggerSegment) {
 
@@ -1689,5 +1658,21 @@ EventView::slotHelpAbout()
     new AboutDialog(this);
 }
 
+void
+EventView::segmentDeleted(const Segment *s)
+{
+    // ??? Bit of a design flaw.  Cast away const...
+    const_cast<Segment *>(s)->removeObserver(this);
+
+    // This editor cannot handle Segments that go away.  So just close.
+    close();
+}
+
+void
+EventView::slotDocumentModified(bool /*modified*/)
+{
+    updateTreeWidget();
+}
+
 
 }
