@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -16,6 +16,7 @@
 */
 
 #define RG_MODULE_STRING "[MatrixScene]"
+#define RG_NO_DEBUG_PRINT 1
 
 #include "MatrixScene.h"
 
@@ -24,6 +25,7 @@
 #include "MatrixWidget.h"
 #include "MatrixElement.h"
 
+#include "gui/application/RosegardenMainWindow.h"
 #include "document/RosegardenDocument.h"
 #include "document/CommandHistory.h"
 #include "misc/ConfigGroups.h"
@@ -45,6 +47,8 @@
 #include <QPointF>
 #include <QRectF>
 
+#include <algorithm>  // for std::sort
+
 //#define DEBUG_MOUSE
 
 namespace Rosegarden
@@ -56,21 +60,22 @@ using namespace BaseProperties;
 MatrixScene::MatrixScene() :
     m_widget(nullptr),
     m_document(nullptr),
+    m_currentSegmentIndex(0),
     m_scale(nullptr),
     m_referenceScale(nullptr),
     m_snapGrid(nullptr),
     m_resolution(8),
     m_selection(nullptr),
-    m_currentSegmentIndex(0)
+    m_highlightType(HT_BlackKeys)
 {
-    connect(CommandHistory::getInstance(), SIGNAL(commandExecuted()),
-            this, SLOT(slotCommandExecuted()));
+    connect(CommandHistory::getInstance(), &CommandHistory::commandExecuted,
+            this, &MatrixScene::slotCommandExecuted);
 }
 
 MatrixScene::~MatrixScene()
 {
     RG_DEBUG << "MatrixScene::~MatrixScene() - start";
-    
+
     if (m_document) {
         if (!isCompositionDeleted()) { // implemented in CompositionObserver
             m_document->getComposition().removeObserver(this);
@@ -87,6 +92,31 @@ MatrixScene::~MatrixScene()
     RG_DEBUG << "MatrixScene::~MatrixScene() - end";
 }
 
+namespace
+{
+    // Functor for std::sort that compares the track positions of two Segments.
+    struct TrackPositionLess {
+        TrackPositionLess() :
+            m_composition(RosegardenDocument::currentDocument->
+                              getComposition())
+        {
+        }
+
+        bool operator()(const Segment *lhs, const Segment *rhs) const
+        {
+            // ??? Could also sort by Segment name and Segment start time.
+            const int lPos =
+                    m_composition.getTrackById(lhs->getTrack())->getPosition();
+            const int rPos =
+                    m_composition.getTrackById(rhs->getTrack())->getPosition();
+            return (lPos < rPos);
+        }
+
+    private:
+        const Composition &m_composition;
+    };
+}
+
 void
 MatrixScene::setSegments(RosegardenDocument *document,
                          std::vector<Segment *> segments)
@@ -98,6 +128,11 @@ MatrixScene::setSegments(RosegardenDocument *document,
     m_document = document;
     m_segments = segments;
 
+    // Sort the Segments into TrackPosition order.  This makes the
+    // Segment changer wheel in the Matrix editor
+    // (MatrixWidget::m_segmentChanger) easier to understand.
+    std::sort(m_segments.begin(), m_segments.end(), TrackPositionLess());
+
     m_document->getComposition().addObserver(this);
 
     SegmentSelection selection;
@@ -122,7 +157,7 @@ MatrixScene::setSegments(RosegardenDocument *document,
     // We should show diamonds instead of bars whenever we are in
     // "drum mode" (i.e. whenever we were invoked using the percussion
     // matrix menu option instead of the normal matrix one).
-    
+
     // The question of whether to show the key names instead of the
     // piano keyboard is a separate one, handled in MatrixWidget, and
     // it depends solely on whether a key mapping exists for the
@@ -130,15 +165,15 @@ MatrixScene::setSegments(RosegardenDocument *document,
     // matrix or not).
 
     // Nevertheless, if the key names are shown, we need a little more space
-    // between horizontal lines. That's why m_resolution depends from 
+    // between horizontal lines. That's why m_resolution depends from
     // keyMapping.
 
-    // But since several segments may be edited in the same matrix, we 
+    // But since several segments may be edited in the same matrix, we
     // have to deal with simultaneous display of segments using piano keyboard
     // and segments using key mapping.
     // Key mapping may be displayed with piano keyboard resolution (even if
     // space is a bit short for the text) but the opposite is not possible.
-    // So the only (easy) way I found is to use the resolution fitting with 
+    // So the only (easy) way I found is to use the resolution fitting with
     // piano keyboard when at least one segment needs it.
 
     bool drumMode = false;
@@ -188,7 +223,7 @@ Segment *
 MatrixScene::getCurrentSegment()
 {
     if (m_segments.empty()) return nullptr;
-    if (m_currentSegmentIndex >= int(m_segments.size())) {
+    if (m_currentSegmentIndex >= m_segments.size()) {
         m_currentSegmentIndex = int(m_segments.size()) - 1;
     }
     return m_segments[m_currentSegmentIndex];
@@ -202,6 +237,12 @@ MatrixScene::setCurrentSegment(Segment *s)
             m_currentSegmentIndex = i;
             recreatePitchHighlights();
             updateCurrentSegment();
+
+            // ??? All callers call m_widget->updateSegmentChangerBackground()
+            //     next.  We should just call it here.
+            //if (m_widget)
+            //    m_widget->updateSegmentChangerBackground();
+
             return;
         }
     }
@@ -225,8 +266,19 @@ MatrixScene::getNextSegment()
 MatrixViewSegment *
 MatrixScene::getCurrentViewSegment()
 {
-    if (m_viewSegments.empty()) return nullptr;
-    return m_viewSegments[0];
+    if (m_viewSegments.empty())
+        return nullptr;
+
+    // ??? Why doesn't this use m_currentSegmentIndex?
+    // return m_viewSegments[0];
+
+    // It should. Otherwise these callers work incorrectly
+    //      MatrixView::slotExtendSelectionBackward(bool)
+    //      MatrixView::slotExtendSelectionForward(bool)
+    //      MatrixWidget::slotKeyPressed(unsigned, bool)
+    //      MatrixWidget::slotKeySelected(unsigned, bool)
+    //      MatrixWidget::slotKeyReleased(unsigned, bool)
+    return m_viewSegments[m_currentSegmentIndex];
 }
 
 bool
@@ -270,30 +322,30 @@ MatrixScene::recreateLines()
     double endPos = m_scale->getXForTime(end);
 
     // Draw horizontal lines
-    int i = 0; 	   	 
-    while (i < 127) { 	 
-         int y = (i + 1) * (m_resolution + 1); 	 
-         QGraphicsLineItem *line; 	 
-         if (i < (int)m_horizontals.size()) { 	 
-             line = m_horizontals[i]; 	 
-         } else { 	 
-             line = new QGraphicsLineItem; 	 
-             line->setZValue(-9); 	 
-             line->setPen(QPen(GUIPalette::getColour 	 
-                               (GUIPalette::MatrixHorizontalLine), pw)); 	 
-             addItem(line); 	 
-             m_horizontals.push_back(line); 	 
-         } 	 
-         line->setLine(startPos, y, endPos, y); 	 
-         line->show(); 	 
-         ++i; 	 
-     } 	 
+    int i = 0;
+    while (i < 127) {
+         int y = (i + 1) * (m_resolution + 1);
+         QGraphicsLineItem *line;
+         if (i < (int)m_horizontals.size()) {
+             line = m_horizontals[i];
+         } else {
+             line = new QGraphicsLineItem;
+             line->setZValue(MatrixElement::HORIZONTAL_LINE_Z);
+             line->setPen(QPen(GUIPalette::getColour
+                               (GUIPalette::MatrixHorizontalLine), pw));
+             addItem(line);
+             m_horizontals.push_back(line);
+         }
+         line->setLine(startPos, y, endPos, y);
+         line->show();
+         ++i;
+     }
 
 
      // Hide the other lines, if there are any.  Just a double check.
-     while (i < (int)m_horizontals.size()) { 	 
-         m_horizontals[i]->hide(); 	 
-         ++i; 	 
+     while (i < (int)m_horizontals.size()) {
+         m_horizontals[i]->hide();
+         ++i;
     }
 
     setSceneRect(QRectF(startPos, 0, endPos - startPos, 128 * (m_resolution + 1)));
@@ -326,6 +378,9 @@ MatrixScene::recreateLines()
             gridLines = timeSig.getBeatsPerBar();
         }
 
+        double beatLines = timeSig.getBeatsPerBar();
+        double dxbeats = width / beatLines;
+
         double dx = width / gridLines;
         double x = x0;
 
@@ -336,7 +391,7 @@ MatrixScene::recreateLines()
                 x += dx;
                 continue;
             }
-            
+
             // Exit if we have passed the end of last segment end time.
             if (x > endPos) {
                 break;
@@ -356,12 +411,21 @@ MatrixScene::recreateLines()
               // index 0 is the bar line
                 line->setPen(QPen(GUIPalette::getColour(GUIPalette::MatrixBarLine), pw));
             } else {
-                line->setPen(QPen(GUIPalette::getColour(GUIPalette::BeatLine), pw));
+                // check if we are on a a beat
+                double br = x / dxbeats;
+                int ibr = br + 0.5;
+                double delta = br - ibr;
+                if (fabs(delta) > 1.0e-6) {
+                    line->setPen(QPen(GUIPalette::getColour(GUIPalette::SubBeatLine), pw));
+                } else {
+                    line->setPen(QPen(GUIPalette::getColour(GUIPalette::BeatLine), pw));
+                }
             }
 
-            line->setZValue(index > 0 ? -10 : -8);
+            line->setZValue(index > 0 ? MatrixElement::VERTICAL_BEAT_LINE_Z
+                                      : MatrixElement::VERTICAL_BAR_LINE_Z);
             line->setLine(x, 0, x, 128 * (m_resolution + 1));
-            
+
             line->show();
             x += dx;
             ++i;
@@ -375,13 +439,15 @@ MatrixScene::recreateLines()
     }
 
     recreatePitchHighlights();
-    
-    // Force update so all vertical lines are drawn correctly
-    update();
+
+    // Force update so all vertical lines are drawn correctly.
+    // ??? Works fine without.  Seems like update() isn't needed in this
+    //     class.  In fact it might be harmful.
+    //update();
 }
 
 void
-MatrixScene::recreatePitchHighlights()
+MatrixScene::recreateTriadHighlights()
 {
     Segment *segment = getCurrentSegment();
     if (!segment) return;
@@ -445,7 +511,7 @@ MatrixScene::recreatePitchHighlights()
                     rect = m_highlights[i];
                 } else {
                     rect = new QGraphicsRectItem;
-                    rect->setZValue(-11);
+                    rect->setZValue(MatrixElement::HIGHLIGHT_Z);
                     rect->setPen(Qt::NoPen);
                     addItem(rect);
                     m_highlights.push_back(rect);
@@ -478,6 +544,110 @@ MatrixScene::recreatePitchHighlights()
     }
 }
 
+void
+MatrixScene::recreateBlackkeyHighlights()
+{
+    Segment *segment = getCurrentSegment();
+    if (!segment) return;
+
+    timeT k0 = segment->getClippedStartTime();
+    timeT k1 = segment->getEndMarkerTime();
+
+    int i = 0;
+
+    double x0 = m_scale->getXForTime(k0);
+    double x1 = m_scale->getXForTime(k1);
+
+    int bkcount = 5;
+    int bksteps[bkcount];
+    bksteps[0] = 1;
+    bksteps[1] = 3;
+    bksteps[2] = 6;
+    bksteps[3] = 8;
+    bksteps[4] = 10;
+    for (int j = 0; j < bkcount; ++j) {
+
+        int pitch = bksteps[j];
+        while (pitch < 128) {
+
+            QGraphicsRectItem *rect;
+
+            if (i < (int)m_highlights.size()) {
+                rect = m_highlights[i];
+            } else {
+                rect = new QGraphicsRectItem;
+                rect->setZValue(MatrixElement::HIGHLIGHT_Z);
+                rect->setPen(Qt::NoPen);
+                addItem(rect);
+                m_highlights.push_back(rect);
+            }
+
+            rect->setBrush(GUIPalette::getColour
+                           (GUIPalette::MatrixPitchHighlight));
+
+            rect->setRect(0, 0, x1 - x0, m_resolution + 1);
+            rect->setPos(x0, (127 - pitch) * (m_resolution + 1));
+            rect->show();
+
+            pitch += 12;
+
+            ++i;
+        }
+    }
+
+    while (i < (int)m_highlights.size()) {
+        m_highlights[i]->hide();
+        ++i;
+    }
+}
+
+void
+MatrixScene::recreatePitchHighlights()
+{
+    Segment *segment = getCurrentSegment();
+    if (!segment) return;
+
+    QSettings settings;
+    settings.beginGroup(MatrixViewConfigGroup);
+    HighlightType chosenHighlightType = static_cast<HighlightType>(
+        settings.value("highlight_type", HT_BlackKeys).toInt());
+    settings.endGroup();
+
+    if (chosenHighlightType == HT_BlackKeys) {
+        RG_DEBUG << "highlight the black notes";
+        // highlight the black notes
+        if (m_highlightType != chosenHighlightType) {
+            // hide all highlights from triad highlight
+            RG_DEBUG << "hide all old triad highlights";
+            int i = 0;
+            while (i < (int)m_highlights.size()) {
+                m_highlights[i]->hide();
+                ++i;
+            }
+        }
+        m_highlightType = HT_BlackKeys;
+        recreateBlackkeyHighlights();
+        return;
+    }
+
+    // Not highlighting black notes so highlight the major/minor triad
+
+    RG_DEBUG << "highlight key triad";
+    if (m_highlightType != HT_Triads) {
+        // hide all highlights of black notes
+        RG_DEBUG << "hide all old blacknote highlights";
+        int i = 0;
+        while (i < (int)m_highlights.size()) {
+            m_highlights[i]->hide();
+            ++i;
+        }
+        m_highlightType = HT_BlackKeys;
+    }
+
+    recreateTriadHighlights();
+
+}
+
 void
 MatrixScene::setupMouseEvent(QGraphicsSceneMouseEvent *e,
                              MatrixMouseEvent &mme) const
@@ -496,10 +666,10 @@ MatrixScene::setupMouseEvent(QGraphicsSceneMouseEvent *e,
     mme.element = nullptr;
 
     QList<QGraphicsItem *> l = items(e->scenePos());
-//    MATRIX_DEBUG << "Found " << l.size() << " items at " << e->scenePos();
+//   MATRIX_DEBUG << "Found " << l.size() << " items at " << e->scenePos();
     for (int i = 0; i < l.size(); ++i) {
         MatrixElement *element = MatrixElement::getMatrixElement(l[i]);
-        if (element) {
+        if (element && ! element->isPreview()) {
             // items are in z-order from top, so this is most salient
             mme.element = element;
             break;
@@ -603,7 +773,11 @@ MatrixScene::checkUpdate()
         SegmentRefreshStatus &rs = m_viewSegments[i]->getRefreshStatus();
 
         if (rs.needsRefresh()) {
+            // Refresh the required range.
+            // Note that updateElements() does not handle deleted
+            // ViewElements.  See MatrixViewSegment::eventRemoved().
             m_viewSegments[i]->updateElements(rs.from(), rs.to());
+
             if (!updateSelectionElementStatus && m_selection) {
                 updateSelectionElementStatus =
                     (m_viewSegments[i]->getSegment() == m_selection->getSegment());
@@ -626,32 +800,52 @@ MatrixScene::segmentEndMarkerTimeChanged(const Segment *, bool)
 }
 
 void
-MatrixScene::timeSignatureChanged(const Composition *c)
+MatrixScene::segmentRemoved(const Composition *, Segment *removedSegment)
 {
-    if (!m_document || !c || (c != &m_document->getComposition())) return;
-}
+    if (!removedSegment)
+        return;
+    if (m_segments.empty())
+        return;
 
-void
-MatrixScene::segmentRemoved(const Composition *c, Segment *s)
-{
-    MATRIX_DEBUG << "MatrixScene::segmentRemoved(" << c << "," << s << ")";
+    const int removedSegmentIndex = findSegmentIndex(removedSegment);
 
-    if (!m_document || !c || (c != &m_document->getComposition())) return;
+    // Not found?  Bail.
+    if (removedSegmentIndex == -1)
+        return;
+
+    // If we're about to remove the one they are looking at and
+    // there is another to switch to...
+    if (removedSegmentIndex == static_cast<int>(m_currentSegmentIndex) &&
+        m_segments.size() > 1) {
+
+        // Switch to another Segment.
+
+        // Try the next.
+        size_t newSegmentIndex = m_currentSegmentIndex + 1;
+        // No next, go with the previous.
+        if (newSegmentIndex == m_segments.size())
+            newSegmentIndex = m_currentSegmentIndex - 1;
+
+        setCurrentSegment(m_segments[newSegmentIndex]);
+        if (m_widget)
+            m_widget->updateSegmentChangerBackground();
 
-    for (std::vector<MatrixViewSegment *>::iterator i = m_viewSegments.begin();
-         i != m_viewSegments.end(); ++i) {
-        if (s == &(*i)->getSegment()) {
-            emit segmentDeleted(s);
-            delete *i;
-            m_viewSegments.erase(i);
-            break;
-        }
     }
 
-    if (m_viewSegments.empty()) {
-        MATRIX_DEBUG << "(Scene is now empty)";
+    emit segmentDeleted(removedSegment);
+
+    delete m_viewSegments[removedSegmentIndex];
+    m_viewSegments.erase(m_viewSegments.cbegin() + removedSegmentIndex);
+
+    m_segments.erase(m_segments.cbegin() + removedSegmentIndex);
+
+    // Adjust m_currentSegmentIndex
+    if (static_cast<int>(m_currentSegmentIndex) > removedSegmentIndex)
+        --m_currentSegmentIndex;
+
+    // No more Segments?
+    if (m_segments.empty())
         emit sceneDeleted();
-    }
 }
 
 void
@@ -665,10 +859,21 @@ MatrixScene::handleEventAdded(Event *e)
 void
 MatrixScene::handleEventRemoved(Event *e)
 {
-    if (m_selection && m_selection->contains(e)) m_selection->removeEvent(e);
-    if (e->getType() == Rosegarden::Key::EventType) {
-        recreatePitchHighlights();
-    }
+    if (m_selection && m_selection->contains(e))
+        m_selection->removeEvent(e);
+
+    // we can not use e here (already deleted) but if it was a
+    // Rosegarden::Key::EventType we must recreatePitchHighlights
+
+    recreatePitchHighlights();
+
+    // ??? Oddly, this causes refresh failures that leave deleted notes
+    //     up on the display (only when doing toolbar undo!?).  Removing
+    //     it seems to result in solid and correct updates in all cases.
+    //     Why?!  See discussion on mailing list early June 2022.
+    //update();
+
+    // Notify MatrixToolBox.
     emit eventRemoved(e);
 }
 
@@ -696,42 +901,36 @@ MatrixScene::setSelection(EventSelection *s, bool preview)
 
     if (m_selection) {
         setSelectionElementStatus(m_selection, true);
+        // ??? But we are going to do this at the end of this routine.
+        //     Is this needed?  Notation only does this at the end.
         emit QGraphicsScene::selectionChanged();
+        emit selectionChangedES(m_selection);
     }
 
     if (preview) previewSelection(m_selection, oldSelection);
     delete oldSelection;
     emit QGraphicsScene::selectionChanged();
+    emit selectionChangedES(m_selection);
 }
 
 void
-MatrixScene::slotRulerSelectionChanged(EventSelection *s)
-{
-    RG_DEBUG << "MatrixScene: caught " << (s ? "useful" : "null" ) << " selection change from ruler";
-    if (m_selection) {
-        if (s) m_selection->addFromSelection(s);
-        setSelectionElementStatus(m_selection, true);
-    }
-}
-
-void
-MatrixScene::setSingleSelectedEvent(MatrixViewSegment *vs,
+MatrixScene::setSingleSelectedEvent(MatrixViewSegment *viewSegment,
                                     MatrixElement *e,
                                     bool preview)
 {
-    if (!vs || !e) return;
-    EventSelection *s = new EventSelection(vs->getSegment());
+    if (!viewSegment || !e) return;
+    EventSelection *s = new EventSelection(viewSegment->getSegment());
     s->addEvent(e->event());
     setSelection(s, preview);
 }
 
 void
-MatrixScene::setSingleSelectedEvent(Segment *seg,
+MatrixScene::setSingleSelectedEvent(Segment *segment,
                                     Event *e,
                                     bool preview)
 {
-    if (!seg || !e) return;
-    EventSelection *s = new EventSelection(*seg);
+    if (!segment || !e) return;
+    EventSelection *s = new EventSelection(*segment);
     s->addEvent(e);
     setSelection(s, preview);
 }
@@ -760,27 +959,30 @@ MatrixScene::setSelectionElementStatus(EventSelection *s, bool set)
 
     MatrixViewSegment *vs = nullptr;
 
-    for (std::vector<MatrixViewSegment *>::iterator i = m_viewSegments.begin();
-         i != m_viewSegments.end(); ++i) {
+    // Find the MatrixViewSegment for the EventSelection's Segment.
+    for (MatrixViewSegment *currentViewSegment : m_viewSegments) {
 
-        if (&(*i)->getSegment() == &s->getSegment()) {
-            vs = *i;
+        if (&currentViewSegment->getSegment() == &s->getSegment()) {
+            vs = currentViewSegment;
             break;
         }
+
     }
 
     if (!vs) return;
 
-    for (EventSelection::eventcontainer::iterator i = s->getSegmentEvents().begin();
-         i != s->getSegmentEvents().end(); ++i) {
+    for (const Event *e : s->getSegmentEvents()) {
 
-        Event *e = *i;
+        ViewElementList::iterator viewElementIter = vs->findEvent(e);
+        // Not in the view?  Try the next.
+        if (viewElementIter == vs->getViewElementList()->end())
+            continue;
 
-        ViewElementList::iterator vsi = vs->findEvent(e);
-        if (vsi == vs->getViewElementList()->end()) continue;
+        MatrixElement *element =
+                dynamic_cast<MatrixElement *>(*viewElementIter);
+        if (element)
+            element->setSelected(set);
 
-        MatrixElement *el = static_cast<MatrixElement *>(*vsi);
-        el->setSelected(set);
     }
 }
 
@@ -791,7 +993,7 @@ MatrixScene::previewSelection(EventSelection *s,
     if (!s) return;
     if (!m_document->isSoundEnabled()) return;
 
-    for (EventSelection::eventcontainer::iterator i = s->getSegmentEvents().begin();
+    for (EventContainer::iterator i = s->getSegmentEvents().begin();
          i != s->getSegmentEvents().end(); ++i) {
 
         Event *e = *i;
@@ -813,7 +1015,7 @@ void
 MatrixScene::updateCurrentSegment()
 {
     MATRIX_DEBUG << "MatrixScene::updateCurrentSegment: current is " << m_currentSegmentIndex;
-    for (int i = 0; i < (int)m_viewSegments.size(); ++i) {
+    for (unsigned i = 0; i < m_viewSegments.size(); ++i) {
         bool current = (i == m_currentSegmentIndex);
         ViewElementList *vel = m_viewSegments[i]->getViewElementList();
         for (ViewElementList::const_iterator j = vel->begin();
@@ -847,6 +1049,7 @@ MatrixScene::setSnap(timeT t)
     recreateLines();
 }
 
+/* unused
 bool
 MatrixScene::constrainToSegmentArea(QPointF &scenePos)
 {
@@ -879,6 +1082,7 @@ MatrixScene::constrainToSegmentArea(QPointF &scenePos)
 
     return ok;
 }
+*/
 
 void
 MatrixScene::playNote(Segment &segment, int pitch, int velocity)
@@ -895,6 +1099,44 @@ MatrixScene::playNote(Segment &segment, int pitch, int velocity)
                                    RealTime(0, 250000000));
 }
 
+void
+MatrixScene::setHorizontalZoomFactor(double factor)
+{
+    for (Segment *segment : m_segments) {
+        segment->matrixHZoomFactor = factor;
+    }
+}
+
+void
+MatrixScene::setVerticalZoomFactor(double factor)
+{
+    for (Segment *segment : m_segments) {
+        segment->matrixVZoomFactor = factor;
+    }
+}
+
+void
+MatrixScene::updateAll()
+{
+    for (std::vector<MatrixViewSegment *>::iterator i = m_viewSegments.begin();
+         i != m_viewSegments.end(); ++i) {
+        (*i)->updateAll();
+    }
+    recreatePitchHighlights();
+    updateCurrentSegment();
+}
+
+int
+MatrixScene::findSegmentIndex(const Segment *segment) const
+{
+    for (int i = 0; i < static_cast<int>(m_segments.size()); ++i) {
+        if (m_segments[i] == segment)
+            return i;
+    }
+
+    // Not found.
+    return -1;
 }
 
 
+}
