@@ -1097,11 +1097,13 @@ MatrixWidget::addControlRuler(QAction *action)
         const QString hexValue =
             QString::asprintf("(0x%x)", it->getControllerNumber());
 
-        // strings extracted from data files must be QObject::tr()
-        QString itemStr = QObject::tr("%1 Controller %2 %3")
-                                     .arg(QObject::tr(it->getName().c_str()))
-                                     .arg(it->getControllerNumber())
-                                     .arg(hexValue);
+        // strings extracted from data files and related to MIDI
+        // controller are in MIDI_CONTROLLER translation context
+        QString itemStr = tr("%1 Controller %2 %3")
+                        .arg(QCoreApplication::translate("MIDI_CONTROLLER",
+                                                        it->getName().c_str()))
+                        .arg(it->getControllerNumber())
+                        .arg(hexValue);
 
         if (name != itemStr)
             continue;
