@@ -167,6 +167,11 @@ NotationStaff::insertTimeSignature(double layoutX,
     getScene()->addItem(item);
     item->setPos(sigCoords.first, (double)sigCoords.second);
     item->show();
+    if (m_highlight) {
+        item->setOpacity(1.0);
+    } else {
+        item->setOpacity(NONHIGHLIGHTOPACITY);
+    }
     m_timeSigs.insert(item);
 }
 
@@ -226,6 +231,11 @@ NotationStaff::insertRepeatedClefAndKey(double layoutX, int barNo)
         getScene()->addItem(item);
         item->setPos(coords.first, coords.second);
         item->show();
+        if (m_highlight) {
+            item->setOpacity(1.0);
+        } else {
+            item->setOpacity(NONHIGHLIGHTOPACITY);
+        }
         m_repeatedClefsAndKeys.insert(item);
 
         dx += item->boundingRect().width() +
@@ -243,6 +253,11 @@ NotationStaff::insertRepeatedClefAndKey(double layoutX, int barNo)
         getScene()->addItem(item);
         item->setPos(coords.first, coords.second);
         item->show();
+        if (m_highlight) {
+            item->setOpacity(1.0);
+        } else {
+            item->setOpacity(NONHIGHLIGHTOPACITY);
+        }
         m_repeatedClefsAndKeys.insert(item);
 
         dx += item->boundingRect().width();
@@ -804,6 +819,8 @@ NotationStaff::renderSingleElement(ViewElementList::iterator &vli,
     static NotePixmapParameters restParams(Note::Crotchet, 0);
 
     NotationElement* elt = static_cast<NotationElement*>(*vli);
+    // set the highlight status of the element
+    elt->setHighlight(m_highlight);
 
     bool invisible = false;
     if (elt->event()->get
@@ -1962,7 +1979,7 @@ NotationStaff::makeViewElement(Rosegarden::Event* e)
 }
 
 bool
-NotationStaff::includesTime(timeT t)
+NotationStaff::includesTime(timeT t) const
 {
     Composition *composition = getSegment().getComposition();
 
@@ -1993,4 +2010,41 @@ timeT NotationStaff::getEndTime() const
         (getSegment().getEndMarkerTime() - 1);
 }
 
+void NotationStaff::setHighlight(bool highlight)
+{
+    if (highlight == m_highlight) return;
+    RG_DEBUG << "set staff highlight" << highlight << m_segment.getLabel();
+    m_highlight = highlight;
+    NotationElementList *elems = getViewElementList();
+
+    for(NotationElementList::iterator it = elems->begin();
+        it != elems->end();
+        ++it) {
+        NotationElement *el = static_cast<NotationElement*>(*it);
+        el->setHighlight(highlight);
+    }
+    for(ItemSet::iterator i = m_timeSigs.begin();
+        i != m_timeSigs.end();
+        ++i) {
+        QGraphicsItem* item = (*i);
+        if (highlight) {
+            item->setOpacity(1.0);
+        } else {
+            item->setOpacity(NONHIGHLIGHTOPACITY);
+        }
+    }
+    for(ItemSet::iterator i = m_repeatedClefsAndKeys.begin();
+        i != m_repeatedClefsAndKeys.end();
+        ++i) {
+        QGraphicsItem* item = (*i);
+        if (highlight) {
+            item->setOpacity(1.0);
+        } else {
+            item->setOpacity(NONHIGHLIGHTOPACITY);
+        }
+    }
+    // and pass on to the StaffLayout
+    StaffLayout::setHighlight(highlight);
+}
+
 }
