@@ -58,8 +58,7 @@ public:
     typedef std::vector<Segment *> SegmentVector;
     typedef void (NotationView::*opOnEvent) (Event* e, Segment *containing);
     NotationView(RosegardenDocument *doc,
-                 const std::vector<Segment *>& segments,
-                 QWidget *parent = nullptr);
+                 const std::vector<Segment *>& segments);
 
     ~NotationView() override;
 
@@ -71,16 +70,11 @@ public:
 
     virtual void initLayoutToolbar();
     void initRulersToolbar();
-    void initStatusBar() override;
+    void initStatusBar();
     timeT getInsertionTime(bool allowEndTime = false) const;
 
     bool hasSegment(Segment * seg) const;
 
-    /** This turns out to be cruft that is rather annoying to eliminate.  We
-     * don't use this for anything, and provide an empty implementation.
-     */
-    void updateViewCaption() override { }
-
     // Adopt a segment that doesn't live in Composition.
     void adoptSegment(Segment *s);
     // Unadopt a segment that we previously adopted.
@@ -104,9 +98,6 @@ signals:
     void editTriggerSegment(int);
     void stepByStepTargetRequested(QObject *);
 
-protected:
-    void readOptions() override;
-
 protected slots:
     /// Some change occurs and the whole scene have to be redrawn.
     /// First remove segments from our list when they are deleted from the
@@ -123,9 +114,9 @@ protected slots:
     /// Preview with LilyPond (via Okular or the like)
     void slotPreviewLilyPond();
 
-    void slotEditCut() override;
-    void slotEditCopy() override;
-    void slotEditPaste() override;
+    void slotEditCut();
+    void slotEditCopy();
+    void slotEditPaste();
     void slotEditDelete();
     void slotEditCutAndClose();
     void slotEditGeneralPaste();
@@ -223,6 +214,8 @@ protected slots:
     void slotContinuousPageMode();
     void slotMultiPageMode();
 
+    void slotHighlight();
+
     void slotShowHeadersGroup();
 
     void slotChangeFontFromAction();
@@ -492,6 +485,8 @@ private:
     void ForAllSelection(opOnEvent op);
     void setCurrentStaff(NotationStaff *staff);
 
+    void readOptions();
+
 // FIXME: likely to be debated. --gp     Used for subclassing in pitchtracker
 protected:
     // !!! Duplicates m_doc in base class
