@@ -3,11 +3,11 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
- 
+    Copyright 2000-2024 the Rosegarden development team.
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -15,10 +15,11 @@
     COPYING included with this distribution for more information.
 */
 
+#define RG_MODULE_STRING "[NoteRestInserter]"
+#define RG_NO_DEBUG_PRINT 1
+
 #include "NoteRestInserter.h"
 #include "misc/Debug.h"
-
-
 #include "base/BaseProperties.h"
 #include "misc/Strings.h"
 #include "misc/Debug.h"
@@ -33,7 +34,6 @@
 #include "commands/notation/TupletCommand.h"
 #include "document/CommandHistory.h"
 #include "gui/general/GUIPalette.h"
-#include "gui/general/IconLoader.h"
 #include "gui/widgets/Panned.h"
 #include "NotationProperties.h"
 #include "NotationMouseEvent.h"
@@ -50,7 +50,7 @@
 #include <QAction>
 #include <QSettings>
 #include <QIcon>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QString>
 #include <QMenu>
 
@@ -127,7 +127,8 @@ NoteRestInserter::NoteRestInserter(NotationWidget* widget) :
     m_isaRestInserter(false),
     m_wheelIndex(0),
     m_processingWheelTurned(false),
-    m_ready(false)
+    m_ready(false),
+    m_previousPreviewStaff(nullptr)
 {
     QIcon icon;
 
@@ -183,8 +184,9 @@ NoteRestInserter::NoteRestInserter(NotationWidget* widget) :
     synchronizeWheel();
 }
 
-NoteRestInserter::NoteRestInserter(QString rcFileName, QString menuName,
-                           NotationWidget* widget) :
+NoteRestInserter::NoteRestInserter(const QString& rcFileName,
+                                   const QString& menuName,
+                                   NotationWidget* widget) :
     NotationTool(rcFileName, menuName, widget),
     m_noteType(Note::Quaver),  //OverRide value with NotationView::initializeNoteRestInserter.
     m_noteDots(0),
@@ -221,14 +223,13 @@ void NoteRestInserter::ready()
     m_ready = true;
     m_clickHappened = false;
     m_clickStaff = nullptr;
-    
+
     // The pencil tool uses the wheel for selecting note values.
     // Disable Panned's handling of the wheel.
     m_widget->getView()->setWheelZoomPan(false);
 
     if (m_alwaysPreview) {
         setCursorShape();
-        m_widget->getView()->setMouseTracking(true);
     } else {
         m_widget->setCanvasCursor(Qt::CrossCursor);
     }
@@ -239,6 +240,10 @@ void NoteRestInserter::ready()
 
 void NoteRestInserter::stow()
 {
+    // This method is called if a segment has vanished. Clear
+    // m_clickStaff in case it is no longer valid
+    m_clickStaff = nullptr;
+
     // Fix bug #1528: NotationScene::clearPreviewNote() crash
     // This is a hack to avoid calling stow() twice, which causes this crash
     // when notation scene has been removed before the second call to stow().
@@ -248,7 +253,6 @@ void NoteRestInserter::stow()
 
     if (m_alwaysPreview) {
         clearPreview();
-        m_widget->getView()->setMouseTracking(false);
     }
     m_ready = false;
 }
@@ -265,7 +269,7 @@ void
 NoteRestInserter::handleMidButtonPress(const NotationMouseEvent *)
 {
     if (!m_quickEdit) return;
-    
+
     if (isaRestInserter()) {
         slotNotesSelected();
     } else {
@@ -273,17 +277,17 @@ NoteRestInserter::handleMidButtonPress(const NotationMouseEvent *)
     }
 }
 
-NoteRestInserter::FollowMode
+FollowMode
 NoteRestInserter::handleMouseMove(const NotationMouseEvent *e)
 {
-    if (m_alwaysPreview) { 
+    if (m_alwaysPreview) {
         computeLocationAndPreview(e, (e->buttons & Qt::LeftButton));
     } else {
         if (m_clickHappened) {
             showPreview(false);
         }
     }
-    return NoFollow;
+    return NO_FOLLOW;
 }
 
 Accidental
@@ -292,12 +296,9 @@ NoteRestInserter::getAccidentalFromModifierKeys(Qt::KeyboardModifiers modifiers)
     Accidental accidental = Accidentals::NoAccidental;
 
     if (!m_quickEdit) return accidental;
-    
-//     Qt::KeyboardModifiers modifiers;
-//     modifiers = QApplication::queryKeyboardModifiers();
-    
+
     // Use Maj or Ctrl keys to add sharp or flat on the fly
-    // Use Maj + Ctrl to add natural  
+    // Use Maj + Ctrl to add natural
     if (modifiers == Qt::ShiftModifier) {
         accidental = Accidentals::Sharp;
     } else if (modifiers == Qt::ControlModifier) {
@@ -316,7 +317,7 @@ NoteRestInserter::handleMouseRelease(const NotationMouseEvent *e)
     NOTATION_DEBUG << "NoteRestInserter::handleMouseRelease: staff = " <<
         m_clickStaff << ", clicked = " << m_clickHappened;
 
-        NotationStaff *staff = m_clickStaff;
+    NotationStaff *staff = m_clickStaff;
     if (!m_clickHappened || !staff) return;
 
     bool okay = computeLocationAndPreview(e, true);
@@ -352,15 +353,20 @@ NoteRestInserter::handleMouseRelease(const NotationMouseEvent *e)
     if (lastInsertedEvent) {
 
         m_scene->setSingleSelectedEvent(&segment, lastInsertedEvent, false);
+        // we need a copy of the time here as setCurrentStaff may
+        // cause m_clickTime to change
+        timeT m_clickTimeCopy = m_clickTime;
+        // and select the staff
+        m_scene->setCurrentStaff(staff);
 
         if (!m_widget->isInChordMode()) {
             // Since a note could have been split and tied, we need to rely on
             // the full duration of the original note calculate the position of
             // the pointer.
-            timeT nextLocation = m_clickTime + note.getDuration();
+            timeT nextLocation = m_clickTimeCopy + note.getDuration();
             m_widget->setPointerPosition(nextLocation);
         } else {
-            m_widget->setPointerPosition(m_clickTime);
+            m_widget->setPointerPosition(m_clickTimeCopy);
         }
     }
 }
@@ -376,7 +382,7 @@ NoteRestInserter::setCursorShape()
     NotePixmapParameters params(Note::QuarterNote,
                          0,  // dots
                          Accidentals::NoAccidental);
-    
+
     NotePixmapFactory * pixmapFactory = m_scene->getNotePixmapFactory();
     NOTATION_DEBUG << "pixmap factory =" << pixmapFactory;
 
@@ -407,19 +413,19 @@ NoteRestInserter::setCursorShape()
 void
 NoteRestInserter::handleWheelTurned(int delta, const NotationMouseEvent *e)
 {
-    if (!m_scene) return; 
+    if (!m_scene) return;
 
     if (m_quickEdit) {
         // Set tool according to the new wheel position
 
         // Prevent synchronizeWheel() from modifying m_wheelIndex
         m_processingWheelTurned = true;
-    
+
         // Uncheck current tool
         QAction * action =
             findActionInParentView(wheelActions[m_wheelIndex].action);
         action->setChecked(false);
-        
+
         // Select new tool
         if (delta > 0) {
             m_wheelIndex++;
@@ -504,10 +510,12 @@ void NoteRestInserter::showMenu()
 }
 
 void
-NoteRestInserter::insertNote(Segment &segment, timeT insertionTime,
-                         int pitch, Accidental accidental,
-                         int velocity,
-                         bool suppressPreview)
+NoteRestInserter::insertNote(Segment &segment,
+                             timeT insertionTime,
+                             int pitch,
+                             const Accidental& accidental,
+                             int velocity,
+                             bool suppressPreview)
 {
     Note note(m_noteType, m_noteDots);
     timeT endTime = insertionTime + note.getDuration();
@@ -549,17 +557,27 @@ bool
 NoteRestInserter::computeLocationAndPreview(const NotationMouseEvent *e,
                                             bool play)
 {
+    // check for valid staffs
+    std::vector<NotationStaff *>* allStaffs = m_scene->getStaffs();
+    std::vector<NotationStaff *>::iterator staffIter =
+        std::find(allStaffs->begin(), allStaffs->end(), e->staff);
+    if (staffIter == allStaffs->end()) return false;
+    if (m_clickStaff != nullptr) {
+        staffIter =
+            std::find(allStaffs->begin(), allStaffs->end(), m_clickStaff);
+        if (staffIter == allStaffs->end()) return false;
+    }
+
     if (!e->staff || !e->element) {
         NOTATION_DEBUG << "computeLocationAndPreview: staff and/or element not supplied";
         clearPreview();
         return false;
     }
 
-    if (m_clickHappened && (e->staff != m_clickStaff)) {
-        NOTATION_DEBUG << "computeLocationAndPreview: staff changed from originally clicked one (" << e->staff << " vs " << m_clickStaff << ")";
-        // abandon
+    if (e->staff != m_previousPreviewStaff) {
+        NOTATION_DEBUG << "computeLocationAndPreview: preview staff changed";
         clearPreview();
-        return false;
+        m_previousPreviewStaff = e->staff;
     }
 
     double x = e->sceneX;
@@ -716,7 +734,7 @@ void NoteRestInserter::showPreview(bool play)
             (m_accidental == Accidentals::NoAccidental && m_followAccidental)
                 ? m_lastAccidental : m_accidental;
     }
-    
+
 
     // Get the start time of the bar where the insertion time is
     timeT startOfBar = segment.getBarStartForTime(m_clickTime);
@@ -726,7 +744,7 @@ void NoteRestInserter::showPreview(bool play)
     Key currentKey = segment.getKeyAtTime(m_clickTime, currentKeyTime);
     timeT currentClefTime;
     Clef currentClef = segment.getClefAtTime(m_clickTime, currentClefTime);
-    
+
     // Pitch related to the cursor position
     Pitch cursorPitch(pitch, cursorAccidental);
     int cursorHeight = cursorPitch.getHeightOnStaff(currentClef, currentKey);
@@ -740,13 +758,12 @@ void NoteRestInserter::showPreview(bool play)
             cursorAccidental = Accidentals::NoAccidental;
         }
     }
-    
-    
+
+
     // Get an iterator of the current event at m_clickTime
     Segment::iterator it = segment.findNearestTime(m_clickTime);
 
     bool cursorCautious = false;
-    bool lookForNoteOnSameOctave = false;
 
     // If the insertion point is immediately following a key change
     // there is no need to look at accidentals of previous notes
@@ -758,7 +775,7 @@ void NoteRestInserter::showPreview(bool play)
 
         // Get an iterator of the first event of the bar
         Segment::iterator itFirst = segment.findTime(startOfBar);
-        
+
         // Prepare to get the elements of the bar in reverse order
         typedef std::reverse_iterator<Segment::iterator> RevIt;
         RevIt rit(it);
@@ -771,6 +788,7 @@ void NoteRestInserter::showPreview(bool play)
         // Walk through the bar
         for ( ; rit != last; ++rit) {
             Event *ev = *rit;
+            bool lookForNoteOnSameOctave = false;
 
             if (ev->isa(Key::EventType)) {
                 if (lookForNoteOnSameOctave) {
@@ -781,7 +799,7 @@ void NoteRestInserter::showPreview(bool play)
 
                         // Select a default accidental related to the current
                         // key signature
-                        Accidental keyAccidental = 
+                        Accidental keyAccidental =
                             cursorPitch.getDisplayAccidental(currentKey);
                         if (keyAccidental == Accidentals::Natural) {
                             // Don't use natural if not needed
@@ -794,10 +812,10 @@ void NoteRestInserter::showPreview(bool play)
 
                         if (cursorAccidental == keyAccidental) {
                             cursorCautious = false;
-                        } 
+                        }
                     }
                 }
-                
+
                 // Stop looking for notes as soon as a key signature is found
                 done = true;
                 break;
@@ -846,7 +864,7 @@ void NoteRestInserter::showPreview(bool play)
                                 }
                             }
                         }
-                            
+
                         if (!cursorCautious) {
                             if (p == pitch) {
                                 // If they have the same pitch, the accidental is
@@ -866,17 +884,17 @@ void NoteRestInserter::showPreview(bool play)
                     done = true;
                     break;
                 }
-                
+
                 // If a note is found with the same name in another octave (the
                 // octave is different otherwise we should have break in the
                 // preceding if)
                 if (cursorPitch.getNoteName(currentKey) ==
                             notePitch.getNoteName(currentKey)) {
-                    
+
                     if (lookForNoteOnSameOctave) continue;
 
                     if (m_octaveType == AccidentalTable::OctavesCautionary) {
-                        
+
                         if (cursorPitch.getPitchInOctave() ==
                                 notePitch.getPitchInOctave()) {
                             // If they have the same pitch in octave, the
@@ -891,7 +909,7 @@ void NoteRestInserter::showPreview(bool play)
                         } else {
                             // Else use the accidental the key signature
                             // requires
-                            cursorAccidental = 
+                            cursorAccidental =
                                 cursorPitch.getAccidental(currentKey);
 
                             // Display it as cautionary if any accidental
@@ -920,7 +938,7 @@ void NoteRestInserter::showPreview(bool play)
                         // We don't break here because we have to look for
                         // another note with the same height in the same octave
                         lookForNoteOnSameOctave = true;
-                        
+
                         // Nevertheless a preview related to the current bar
                         // is already found : no need to look at the previous
                         // bar in the next step.
@@ -1063,7 +1081,7 @@ void NoteRestInserter::showPreview(bool play)
 void NoteRestInserter::clearPreview()
 {
     if (m_scene) {
-        m_scene->clearPreviewNote(m_clickStaff);
+        m_scene->clearPreviewNote();
     }
 }
 
@@ -1213,7 +1231,7 @@ NoteRestInserter::doAddCommand(Segment &segment, timeT time, timeT endTime,
         Segment::iterator i(segment.findTime(time));
         if (i != segment.end() &&
             !(*i)->has(BaseProperties::BEAMED_GROUP_TUPLET_BASE)) {
-            
+
             MacroCommand *command = new MacroCommand(insertionCommand->getName());
             //## Attempted fix to bug reported on rg-user by SlowPic
             //## <slowpic@web.de> 28/02/2005 22:32:56 UTC: Triplet input error
@@ -1227,13 +1245,24 @@ NoteRestInserter::doAddCommand(Segment &segment, timeT time, timeT endTime,
                                  time + note.getDuration() * 2,
                                  Note::getNearestNote(note.getDuration() * 2))); // have to find out what these 2 mean
             //## }
-            //# These comments should probably be deleted.
 
-            command->addCommand(new TupletCommand
-                                (segment, time, note.getDuration(),
-                                 m_widget->getUntupledCount(),
-                                 m_widget->getTupledCount(), true)); // #1046934: "has timing already"
+            // ??? History of the groupHasTimingAlready field...
+            //     Bug #629: Changed to true to fix.
+            //     Bug #1464: Changed back to false which re-introduced the
+            //                problems with tuplets eating following notes.
+            //     November 26, 2021 changing this back to true to fix the
+            //     re-introduced problems.  This breaks entering 7 in 4.
+            //     Leaving it this way for 21.12.
+            command->addCommand(new TupletCommand(
+                    segment,
+                    time,  // startTime
+                    note.getDuration(),  // unit
+                    m_widget->getUntupledCount(),
+                    m_widget->getTupledCount(),
+                    true));  // groupHasTimingAlready
+
             command->addCommand(insertionCommand);
+
             activeCommand = command;
         }
     }
@@ -1256,8 +1285,8 @@ void NoteRestInserter::slotSetDots(unsigned int dots)
     m_noteDots = dots;
 }
 
-void NoteRestInserter::slotSetAccidental(Accidental accidental,
-                                     bool follow)
+void NoteRestInserter::slotSetAccidental(const Accidental& accidental,
+                                         bool follow)
 {
     NOTATION_DEBUG << "NoteRestInserter::setAccidental: accidental is "
                    << accidental;
@@ -1269,7 +1298,7 @@ void NoteRestInserter::slotToggleDot()
 {
     QObject *s = sender();
     QString actionName = s->objectName();
-    
+
     // Use fact that switch_dots_on/_off is same name
     // in parent view.  If changes, then a check
     // will need to be made.
@@ -1299,7 +1328,7 @@ void NoteRestInserter::slotRestsSelected()
 {
     Note note(m_noteType, m_noteDots);
     QString actionName(NotationStrings::getReferenceName(note, true));
-    actionName.replace(QRegExp("-"), "_");
+    actionName.replace(QRegularExpression("-"), "_");
 
     QAction* action = findActionInParentView(actionName);
 
@@ -1317,7 +1346,7 @@ void NoteRestInserter::slotNotesSelected()
 {
     Note note(m_noteType, m_noteDots);
     QString actionName(NotationStrings::getReferenceName(note));
-    actionName.replace(QRegExp("-"), "_");
+    actionName.replace(QRegularExpression("-"), "_");
 
     QAction *action = findActionInParentView(actionName);
 
@@ -1346,4 +1375,3 @@ void NoteRestInserter::slotNotesSelected()
 QString NoteRestInserter::ToolName() { return "noterestinserter"; }
 
 }
-
