@@ -370,14 +370,12 @@ public:
     virtual QRect getBarExtents(double x, int y) const;
 
     /**
-     * Set whether this is the current staff or not.  A staff that is
-     * current will differ visually from non-current staffs.
+     * Set whether this staff is highlighted or not.  A staff that is
+     * highlighted will differ visually from non-highlighted staffs.
      *
-     * The owner of the staffs should normally ensure that one staff
-     * is current (the default is non-current, even if there only is
-     * one staff) and that only one staff is current at once.
+     * The owner of the staffs is responsible for the highlighting.
      */
-    virtual void setCurrent(bool current);
+    virtual void setHighlight(bool highlight);
 
     /**
      * Query the given horizontal layout object (which is assumed to
@@ -645,7 +643,7 @@ protected:
     double   m_startLayoutX;
     double   m_endLayoutX;
 
-    bool     m_current;
+    bool     m_highlight;
 
     typedef std::vector<QGraphicsItem *> ItemList;
     typedef std::vector<ItemList> ItemMatrix;
