@@ -37,7 +37,6 @@
 #include "misc/ConfigGroups.h"
 #include "gui/dialogs/TimeDialog.h"
 #include "gui/general/MidiPitchLabel.h"
-#include "gui/widgets/TmpStatusMsg.h"
 #include "gui/dialogs/AboutDialog.h"
 #include "document/Command.h"
 
@@ -465,7 +464,8 @@ QString
 TriggerSegmentManager::makeDurationString(timeT startTime,
         timeT duration, int timeMode)
 {
-    //!!! duplication with EventView::makeDurationString -- merge somewhere?
+    // ??? Same as EventView::makeDurationString().  Move to Composition
+    //     like makeTimeString().
 
     switch (timeMode) {
 
