@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -105,7 +105,7 @@ SegmentSelector::mousePressEvent(QMouseEvent *e)
 
     // We only care about the left and middle mouse buttons.
     if (e->button() != Qt::LeftButton  &&
-        e->button() != Qt::MidButton)
+        e->button() != Qt::MiddleButton)
         return;
 
     // No need to propagate.
@@ -117,7 +117,7 @@ SegmentSelector::mousePressEvent(QMouseEvent *e)
     ChangingSegmentPtr item = m_canvas->getModel()->getSegmentAt(pos);
 
     // If middle button...
-    if (e->button() == Qt::MidButton) {
+    if (e->button() == Qt::MiddleButton) {
         // If clicked on the background, create a new segment.
         if (!item) {
             m_dispatchTool = m_canvas->getToolBox()->getTool(SegmentPencil::ToolName());
@@ -135,6 +135,21 @@ SegmentSelector::mousePressEvent(QMouseEvent *e)
     // ??? Should we split this into a midPress(e) and a leftPress(e)?
     //     Might improve readability a little.
 
+    // *** Resize
+
+    // if the Segment was clicked near the edge, resize
+    if (item  &&  isNearEdge(item->rect(), pos)) {
+        SegmentResizer *segmentResizer = dynamic_cast<SegmentResizer *>(
+                m_canvas->getToolBox()->getTool(SegmentResizer::ToolName()));
+
+        // Turn it over to SegmentResizer.
+        m_dispatchTool = segmentResizer;
+        m_dispatchTool->ready(); // set mouse cursor
+        m_dispatchTool->mousePressEvent(e);
+
+        return;
+    }
+
     // *** Adjust Selection
 
     // Shift key adds to selection.
@@ -167,23 +182,6 @@ SegmentSelector::mousePressEvent(QMouseEvent *e)
     // if a segment was clicked
     if (item) {
 
-        // * Resize
-
-        // if only one segment is selected and clicked near the edge, resize
-        if (m_canvas->getModel()->getSelectedSegments().size() == 1  &&
-            isNearEdge(item->rect(), pos)) {
-
-            SegmentResizer *segmentResizer = dynamic_cast<SegmentResizer *>(
-                m_canvas->getToolBox()->getTool(SegmentResizer::ToolName()));
-
-            // Turn it over to SegmentResizer.
-            m_dispatchTool = segmentResizer;
-            m_dispatchTool->ready(); // set mouse cursor
-            m_dispatchTool->mousePressEvent(e);
-
-            return;
-        }
-
         // * Move
 
         // We don't dispatch to SegmentMover because SegmentMover
@@ -247,7 +245,7 @@ SegmentSelector::mouseReleaseEvent(QMouseEvent *e)
 {
     // We only care about the left and middle mouse buttons.
     if (e->button() != Qt::LeftButton  &&
-        e->button() != Qt::MidButton)
+        e->button() != Qt::MiddleButton)
         return;
 
     // No need to propagate.
@@ -425,7 +423,7 @@ SegmentSelector::mouseMoveEvent(QMouseEvent *e)
     //       QWidget::setMouseTracking().
     if (e->buttons() == Qt::NoButton) {
         setContextHelpFor(pos, e->modifiers());
-        return RosegardenScrollView::NoFollow;
+        return NO_FOLLOW;
     }
 
     // If another tool has taken over, delegate.
@@ -435,22 +433,21 @@ SegmentSelector::mouseMoveEvent(QMouseEvent *e)
     // We only handle the left button.  The middle button is handled by
     // the dispatch tool (segment pencil) or ignored.
     if (e->buttons() != Qt::LeftButton)
-        return RosegardenScrollView::NoFollow;
+        return NO_FOLLOW;
 
     // If we aren't moving anything, rubber band.
     if (!getChangingSegment()) {
         m_canvas->drawSelectionRectPos2(pos);
         m_canvas->getModel()->selectionHasChanged();
 
-        return RosegardenScrollView::FollowHorizontal |
-               RosegardenScrollView::FollowVertical;
+        return FOLLOW_HORIZONTAL | FOLLOW_VERTICAL;
     }
 
     // Moving
 
     // If the segment that was clicked on isn't selected, bail.
     if (!m_canvas->getModel()->isSelected(getChangingSegment()->getSegment()))
-        return RosegardenScrollView::NoFollow;
+        return NO_FOLLOW;
 
     const int dx = pos.x() - m_clickPoint.x();
     const int dy = pos.y() - m_clickPoint.y();
@@ -461,7 +458,7 @@ SegmentSelector::mouseMoveEvent(QMouseEvent *e)
     if (!m_passedInertiaEdge  &&
         abs(dx) < inertiaDistance  &&
         abs(dy) < inertiaDistance) {
-        return RosegardenScrollView::NoFollow;
+        return NO_FOLLOW;
     }
 
     m_passedInertiaEdge = true;
@@ -601,8 +598,7 @@ SegmentSelector::mouseMoveEvent(QMouseEvent *e)
     const timeT guideTime = m_canvas->grid().snapX(guideX);
 
     RealTime time = comp.getElapsedRealTime(guideTime);
-    QString msecs;
-    msecs.sprintf("%03d", time.msec());
+    const QString msecs = QString::asprintf("%03d", time.msec());
 
     int bar;
     int beat;
@@ -617,8 +613,7 @@ SegmentSelector::mouseMoveEvent(QMouseEvent *e)
 
     m_canvas->update();
 
-    return RosegardenScrollView::FollowHorizontal |
-           RosegardenScrollView::FollowVertical;
+    return FOLLOW_HORIZONTAL | FOLLOW_VERTICAL;
 }
 
 void SegmentSelector::keyPressEvent(QKeyEvent *e)
