@@ -482,9 +482,9 @@ ActionFileParser::setActionShortcut(QString actionName, QString shortcut, bool i
     // shortcuts get all from ActionData
     ActionData* adata = ActionData::getInstance();
     QString key = basefile + ":" + actionName;
-    std::set<QKeySequence> shortcutSet = adata->getShortcuts(key);
+    KeyList shortcuts = adata->getShortcuts(key);
     QList<QKeySequence> shortcutList;
-    foreach(auto ks, shortcutSet) {
+    foreach(auto ks, shortcuts) {
         shortcutList.append(ks);
     }
     RG_DEBUG << "setActionShortcut default shortcut for" << actionName <<
