@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
 
     This file originally from Sonic Visualiser, copyright 2007 Queen
     Mary, University of London.
@@ -26,6 +26,7 @@
 #include <QDir>
 #include <QCoreApplication>
 #include <QThreadStorage>
+#include <QRegularExpression>
 
 #include <iostream>
 #include <cstdlib>
@@ -95,7 +96,7 @@ FileSource::FileSource(QString fileOrUrl,
     if (m_url.toString() == "") {
         m_url = QUrl(fileOrUrl, QUrl::TolerantMode);
     }
- 
+
 #ifdef DEBUG_FILE_SOURCE
     std::cerr << "FileSource::FileSource(" << fileOrUrl << "): url <" << m_url.toString() << ">" << std::endl;
     incCount(m_url.toString());
@@ -278,8 +279,8 @@ FileSource::init()
         std::cerr << "FileSource::init: Is a resource" << std::endl;
 #endif
         QString resourceFile = m_url.toString();
-        resourceFile.replace(QRegExp("^qrc:"), ":");
-        
+        resourceFile.replace(QRegularExpression("^qrc:"), ":");
+
         if (!QFileInfo(resourceFile).exists()) {
 #ifdef DEBUG_FILE_SOURCE
             std::cerr << "FileSource::init: Resource file of this name does not exist, switching to non-resource URL" << std::endl;
@@ -332,7 +333,6 @@ FileSource::init()
                 // Again, QUrl may have been mistreating us --
                 // e.g. dropping a part that looks like query data
                 m_localFilename = m_rawFileOrUrl;
-                literal = true;
                 if (!QFileInfo(m_localFilename).exists()) {
                     m_lastStatus = 404;
                 }
@@ -368,11 +368,11 @@ FileSource::init()
         // is the successful case
 
         QString resourceFileName = m_url.toString();
-        resourceFileName.replace(QRegExp("^qrc:"), ":");
+        resourceFileName.replace(QRegularExpression("^qrc:"), ":");
         QFile resourceFile(resourceFileName);
         resourceFile.open(QFile::ReadOnly);
         QByteArray ba(resourceFile.readAll());
-        
+
 #ifdef DEBUG_FILE_SOURCE
         std::cerr << "Copying " << ba.size() << " bytes from resource file to cache file" << std::endl;
 #endif
@@ -415,7 +415,7 @@ FileSource::init()
     }
 
     if (m_ok) {
-        
+
         QMutexLocker locker(&m_mapMutex);
 
         if (m_refCountMap[m_url] > 0) {
@@ -457,7 +457,7 @@ FileSource::initRemote()
 
     QNetworkRequest req;
     req.setUrl(m_url);
-    
+
     if (m_preferredContentType != "") {
 #ifdef DEBUG_FILE_SOURCE
         std::cerr << "FileSource: indicating preferred content type of \""
@@ -588,11 +588,13 @@ FileSource::waitForData()
     }
 }
 
+/* unused
 void
 FileSource::setLeaveLocalFile(bool leave)
 {
     m_leaveLocalFile = leave;
 }
+*/
 
 bool
 FileSource::isOK() const
@@ -618,11 +620,13 @@ FileSource::isRemote() const
     return m_remote;
 }
 
+/* unused
 QString
 FileSource::getLocation() const
 {
     return m_url.toString();
 }
+*/
 
 QString
 FileSource::getLocalFilename() const
@@ -630,18 +634,23 @@ FileSource::getLocalFilename() const
     return m_localFilename;
 }
 
+/* unused
 QString
 FileSource::getBasename() const
 {
     return QFileInfo(m_localFilename).fileName();
 }
+*/
 
+/* unused
 QString
 FileSource::getContentType() const
 {
     return m_contentType;
 }
+*/
 
+/* unused
 QString
 FileSource::getExtension() const
 {
@@ -651,12 +660,15 @@ FileSource::getExtension() const
         return QFileInfo(m_url.toLocalFile()).suffix().toLower();
     }
 }
+*/
 
+/* unused
 QString
 FileSource::getErrorString() const
 {
     return m_errorString;
 }
+*/
 
 void
 FileSource::readyRead()
@@ -894,8 +906,8 @@ FileSource::createCacheFile()
 
     QDir dir;
     try {
-        dir = TempDirectory::getInstance()->getSubDirectoryPath("download");
-    } catch (DirectoryCreationFailed f) {
+        dir.setPath(TempDirectory::getInstance()->getSubDirectoryPath("download"));
+    } catch (const DirectoryCreationFailed &f) {
 #ifdef DEBUG_FILE_SOURCE
         std::cerr << "FileSource::createCacheFile: ERROR: Failed to create temporary directory: " << f.what() << std::endl;
 #endif
@@ -968,11 +980,9 @@ FileSource::createCacheFile()
               << m_url.toString() << " -> local filename "
               << filepath << std::endl;
 #endif
-    
+
     m_localFilename = filepath;
     return false;
 }
 
 }
-
-
