@@ -16,6 +16,7 @@
 */
 
 #define RG_MODULE_STRING "[TempoRuler]"
+#define RG_NO_DEBUG_PRINT
 
 #include "TempoRuler.h"
 
@@ -70,8 +71,6 @@ TempoRuler::TempoRuler(RulerScale *rulerScale,
         m_small(small),
         m_illuminate( -1),
         m_illuminatePoint(false),
-        m_illuminateTarget(false),
-        m_refreshLinesOnly(false),
         m_dragVert(false),
         m_dragTarget(false),
         m_dragHoriz(false),
@@ -372,26 +371,12 @@ TempoRuler::mouseMoveEvent(QMouseEvent *e)
 
         m_illuminate = tcn;
         m_illuminatePoint = false;
-        m_illuminateTarget = false;
-        //!!!    m_refreshLinesOnly = true;
-
         //!!! merge this test with the one in mousePressEvent as
         //isCloseToStart or equiv, and likewise for close to end
 
         int px = m_rulerScale->getXForTime(tc.first) + m_currentXOffset;
         if (x >= px && x < px + 5) {
             m_illuminatePoint = true;
-        } else {
-            timeT nt = m_composition->getEndMarker();
-            if (tcn < m_composition->getTempoChangeCount() - 1) {
-                nt = m_composition->getTempoChange(tcn + 1).first;
-            }
-            int nx = m_rulerScale->getXForTime(nt) + m_currentXOffset;
-            if (x > px + 5 && x > nx - 5) {
-                m_illuminateTarget = true;
-            }
-
-            //        std::cerr << "nt = " << nt << ", nx = " << nx << ", x = " << x << ", m_illuminateTarget = " << m_illuminateTarget << std::endl;
         }
 
         showTextFloat(tc.second, tr.first ? tr.second : -1,
@@ -423,7 +408,6 @@ TempoRuler::leaveEvent(QEvent *)
         setMouseTracking(false);
         m_illuminate = -1;
         m_illuminatePoint = false;
-        //!!!    m_refreshLinesOnly = true;
         TextFloat::getTextFloat()->hide();
 
         update();
@@ -445,31 +429,13 @@ TempoRuler::showTextFloat(tempoT tempo, tempoT target,
 
     if (time >= 0) {
 
+        // ??? This is always false.
         if (showTime) {
-            int bar, beat, fraction, remainder;
-            m_composition->getMusicalTimeForAbsoluteTime
-            (time, bar, beat, fraction, remainder);
-            RealTime rt = m_composition->getElapsedRealTime(time);
-
-            // bars in user space start at 1, not 0
-            bar++;
-
-            // blargh -- duplicated with TempoView::makeTimeString
-            timeText = QString("%1%2%3-%4%5-%6%7-%8%9")
-                       .arg(bar / 100)
-                       .arg((bar % 100) / 10)
-                       .arg(bar % 10)
-                       .arg(beat / 10)
-                       .arg(beat % 10)
-                       .arg(fraction / 10)
-                       .arg(fraction % 10)
-                       .arg(remainder / 10)
-                       .arg(remainder % 10);
-
-            timeText = QString("%1\n%2")
-                       .arg(timeText)
-                       //        .arg(rt.toString().c_str());
-                       .arg(rt.toText(true).c_str());
+            timeText = m_composition->makeTimeString(
+                    time, Composition::TimeMode::MusicalTime);
+            timeText += "\n";
+            timeText += m_composition->makeTimeString(
+                    time, Composition::TimeMode::RealTime);
         }
 
         TimeSignature sig =
@@ -595,9 +561,9 @@ TempoRuler::paintEvent(QPaintEvent* e)
     // nothing in this part of the ruler that means anything anyway.  If we're
     // using Thorn, use a nice dark gray that just contrasts with the black
     // horizontal line here
-    QColor kuller(0x40, 0x40, 0x40);
-    if (!m_Thorn) kuller = palette().window().color();
-    m_buffer.fill(kuller);
+    QColor backgroundColor(0x40, 0x40, 0x40);
+    if (!m_Thorn) backgroundColor = palette().window().color();
+    m_buffer.fill(backgroundColor);
 
     QPainter paint(&m_buffer);
     paint.setPen(GUIPalette::getColour
@@ -606,9 +572,9 @@ TempoRuler::paintEvent(QPaintEvent* e)
     paint.setClipRegion(e->region());
     paint.setClipRect(clipRect);
 
-    timeT from = m_rulerScale->getTimeForX
+    const timeT from = m_rulerScale->getTimeForX
                  (clipRect.x() - m_currentXOffset - 100);
-    timeT to = m_rulerScale->getTimeForX
+    const timeT to = m_rulerScale->getTimeForX
                (clipRect.x() + clipRect.width() - m_currentXOffset + 100);
 
     QRect boundsForHeight = m_fontMetrics.boundingRect("019");
@@ -617,13 +583,12 @@ TempoRuler::paintEvent(QPaintEvent* e)
     // bmp text aligns better in temporuler now - is this font dependent?
     int textY = fontHeight - 3;
 
-    double prevEndX = -1000.0;
-    double prevTempo = 0.0;
-    long prevBpm = 0;
+    // Assemble a map of timePoints.
 
-    typedef std::map<timeT, int> TimePoints;
-    int tempoChangeHere = 1;
-    int timeSigChangeHere = 2;
+    typedef std::map<timeT, int /*changeMask*/> TimePoints;
+    // changeMask values.
+    constexpr int tempoChangeHere = 1;
+    constexpr int timeSigChangeHere = 2;
     TimePoints timePoints;
 
     for (int tempoNo = m_composition->getTempoChangeNumberAt(from);
@@ -650,20 +615,25 @@ TempoRuler::paintEvent(QPaintEvent* e)
         }
     }
 
-    int lastx = 0, lasty = 0, lastx1 = 0;
+    // Draw the points, lines, and colored backgrounds.
+
+    // Keep track of whether we actually have any points.
     bool haveSome = false;
     //    tempoT minTempo = m_composition->getMinTempo();
     //    tempoT maxTempo = m_composition->getMaxTempo();
-    bool illuminate = false;
 
-    if (m_illuminate >= 0) {
-        int tcn = m_composition->getTempoChangeNumberAt(from);
-        illuminate = (m_illuminate == tcn);
-    }
+    //if (m_illuminate >= 0) {
+    //    int tcn = m_composition->getTempoChangeNumberAt(from);
+    //  illuminate = (m_illuminate == tcn);
+    //}
+
+    RG_DEBUG << "paintEvent" << from << to;
 
     for (TimePoints::iterator i = timePoints.begin(); ; ++i) {
 
-        timeT t0, t1;
+        // Compute the time of the previous point (t0).
+
+        timeT t0;
 
         if (i == timePoints.begin()) {
             t0 = from;
@@ -673,6 +643,10 @@ TempoRuler::paintEvent(QPaintEvent* e)
             t0 = j->first;
         }
 
+        // Compute the time of the current point (t1).
+
+        timeT t1;
+
         if (i == timePoints.end()) {
             t1 = to;
         } else {
@@ -682,13 +656,13 @@ TempoRuler::paintEvent(QPaintEvent* e)
         if (t1 <= t0)
             t1 = to;
 
-        int tcn = m_composition->getTempoChangeNumberAt(t0);
-        tempoT tempo = m_composition->getTempoAtTime(t0);
+        const int tcn = m_composition->getTempoChangeNumberAt(t0);
+        bool illuminate = (m_illuminate == tcn);
+        const tempoT tempo0 = m_composition->getTempoAtTime(t0);
+        const tempoT tempo1 = m_composition->getTempoAtTime(t1 - 1);
 
-        std::pair<bool, tempoT> ramping(false, tempo);
-        if (tcn > 0 && tcn < m_composition->getTempoChangeCount() + 1) {
-            ramping = m_composition->getTempoRamping(tcn - 1, true);
-        }
+        RG_DEBUG << "time point" << t0 << t1 << tempo0 << tempo1 <<
+            tcn << m_illuminate;
 
         double x0, x1;
         x0 = m_rulerScale->getXForTime(t0) + m_currentXOffset;
@@ -699,57 +673,32 @@ TempoRuler::paintEvent(QPaintEvent* e)
                        paletteBackgroundColor());
             }
         */
-        QColor colour = TempoColour::getColour(m_composition->getTempoQpm(tempo));
+        QColor colour =
+            TempoColour::getColour(m_composition->getTempoQpm(tempo0));
         paint.setPen(colour);
         paint.setBrush(colour);
 
-        if (!m_refreshLinesOnly) {
-            //         RG_DEBUG << "TempoRuler: draw rect from " << x0 << " to " << x1;
-            paint.drawRect(int(x0), 0, int(x1 - x0) + 1, height());
-        }
+        RG_DEBUG << "TempoRuler: draw rect from " << x0 << " to " << x1;
+        paint.drawRect(int(x0), 0, int(x1 - x0) + 1, height());
 
-        int y = getYForTempo(tempo);
-        /*!!!
-            int drawh = height() - 4;
-            int y = drawh / 2;
-            if (maxTempo > minTempo) {
-                y = drawh -
-                int((double(tempo - minTempo) / double(maxTempo - minTempo))
-                    * drawh + 0.5);
-            }
-        */
+        int y = getYForTempo(tempo0);
         y += 2;
 
+        // If we've determined that we have points, draw them.
         if (haveSome) {
 
             int x = int(x0) + 1;
-            int ry = lasty;
+            int ry = y;
 
-            bool illuminateLine = (illuminate &&
-                                   !m_illuminatePoint && !m_illuminateTarget);
+            bool illuminateLine = (illuminate && !m_illuminatePoint);
 
             paint.setPen(illuminateLine ? QColor(Qt::white) : QColor(Qt::black));
 
-            if (ramping.first) {
-                ry = getYForTempo(ramping.second);
-                ry += 2;
-                /*!!!
-                        ry = drawh -
-                            int((double(ramping.second - minTempo) /
-                             double(maxTempo - minTempo))
-                            * drawh + 0.5);
-                */
-            }
+            ry = getYForTempo(tempo1);
+            ry += 2;
+            RG_DEBUG << "drawLine1" << x0 + 1 << y << x1 - 1 << ry;
+            paint.drawLine(x0 + 1, y, x1 - 1, ry);
 
-            paint.drawLine(lastx + 1, lasty, x - 2, ry);
-
-            if (!illuminateLine && illuminate && m_illuminateTarget) {
-                if (x > lastx) {
-                    paint.setPen(QColor(Qt::white));
-                    paint.drawLine(x - 6, ry - ((ry - lasty) * 6) / (x - lastx),
-                                   x - 2, ry);
-                }
-            }
 
             if (m_illuminate >= 0) {
                 illuminate = (m_illuminate == tcn);
@@ -764,27 +713,20 @@ TempoRuler::paintEvent(QPaintEvent* e)
             paint.drawPoint(x, y);
         }
 
-        lastx = int(x0) + 1;
-        lastx1 = int(x1) + 1;
-        lasty = y;
+        // We want to go through this loop at least once.  Check for end here.
         if (i == timePoints.end())
             break;
+
+        // We have more than zero points to plot.  Go ahead and start
+        // plotting them.
         haveSome = true;
     }
 
-    if (lastx1 < e->rect().x() + e->rect().width()) {
-        /*!!!
-            paint.fillRect(lastx1, 0,
-                       e->rect().x() + e->rect().width() - lastx1, height(),
-                       paletteBackgroundColor());
-        */
-    }
-
-    if (haveSome) {
-        bool illuminateLine = (illuminate && !m_illuminatePoint);
-        paint.setPen(illuminateLine ? QColor(Qt::white) : QColor(Qt::black));
-        paint.drawLine(lastx + 1, lasty, width(), lasty);
-    } else if (!m_refreshLinesOnly) {
+    // If there were no points to draw, just fill the ruler with the
+    // appropriate tempo color.
+    // ??? Seems like the code above would have already done this.  Is this
+    //     really necessary?
+    if (!haveSome) {
         tempoT tempo = m_composition->getTempoAtTime(from);
         QColor colour = TempoColour::getColour(m_composition->getTempoQpm(tempo));
         paint.setPen(colour);
@@ -792,24 +734,23 @@ TempoRuler::paintEvent(QPaintEvent* e)
         paint.drawRect(e->rect());
     }
 
+    // Draw the labels.
+
     paint.setPen(QColor(Qt::black));
     paint.setBrush(QColor(Qt::black));
     paint.drawLine(0, 0, width(), 0);
 
+    double prevEndX = -1000.0;
+    double prevTempo = 0.0;
+    long prevBpm = 0;
+
     for (TimePoints::iterator i = timePoints.begin();
             i != timePoints.end(); ++i) {
 
         timeT time = i->first;
         double x = m_rulerScale->getXForTime(time) + m_currentXOffset;
 
-        /*
-            paint.drawLine(static_cast<int>(x),
-                       height() - (height()/4),
-                       static_cast<int>(x),
-                       height());
-        */
-
-        if ((i->second & timeSigChangeHere) && !m_refreshLinesOnly) {
+        if ((i->second & timeSigChangeHere)) {
 
             TimeSignature sig =
                 m_composition->getTimeSignatureAt(time);
@@ -822,7 +763,7 @@ TempoRuler::paintEvent(QPaintEvent* e)
             paint.drawText(static_cast<int>(x) + 2, m_height - 2, str);
         }
 
-        if ((i->second & tempoChangeHere) && !m_refreshLinesOnly) {
+        if ((i->second & tempoChangeHere)) {
 
             double tempo = m_composition->getTempoQpm(m_composition->getTempoAtTime(time));
             long bpm = long(tempo);
@@ -872,8 +813,6 @@ TempoRuler::paintEvent(QPaintEvent* e)
                        clipRect.width(), clipRect.height());
 
     dbpaint.end();
-
-    m_refreshLinesOnly = false;
 }
 
 void
