@@ -20,44 +20,70 @@
 
 #include <QDialog>
 
-
 class QWidget;
 class QGroupBox;
 class QDialogButtonBox;
+class QCheckBox;
 
 
 namespace Rosegarden
 {
 
+
 class RosegardenDocument;
 
 
+/// The Modify MIDI Filters dialog.  Studio > Modify MIDI Filters...
+/**
+ * This dialog controls thru and record filtering.
+ */
 class MidiFilterDialog : public QDialog
 {
     Q_OBJECT
 public:
+
     MidiFilterDialog(QWidget *parent,
                      RosegardenDocument *doc);
 
-    void setModified(bool value);
-
-public slots:
+private slots:
 
+    void slotClicked(bool);
     void accept() override;
     void help();
     void slotApply();
-    void slotSetModified(int foo = 42);
 
-protected:
+private:
 
     RosegardenDocument *m_doc;
 
-    QGroupBox        *m_thruBox;
-    QGroupBox        *m_recordBox;
+    // Widgets
+
+    QGroupBox *m_thruBox;
+    QGroupBox *m_recordBox;
+
+    QCheckBox *m_noteThru;
+    QCheckBox *m_progThru;
+    QCheckBox *m_keyThru;
+    QCheckBox *m_chanThru;
+    QCheckBox *m_pitchThru;
+    QCheckBox *m_contThru;
+    QCheckBox *m_sysThru;
+
+    QCheckBox *m_noteRecord;
+    QCheckBox *m_progRecord;
+    QCheckBox *m_keyRecord;
+    QCheckBox *m_chanRecord;
+    QCheckBox *m_pitchRecord;
+    QCheckBox *m_contRecord;
+    QCheckBox *m_sysRecord;
 
-    bool              m_modified;
     QDialogButtonBox *m_buttonBox;
-    QPushButton      *m_applyButton;
+    QPushButton *m_applyButton;
+
+
+    // Used to enable/disable the apply button.
+    bool m_modified{false};
+    void setModified(bool modified);
 
 };
 
