@@ -55,6 +55,7 @@
 #include "sound/MappedEventList.h"
 #include "sound/MappedEvent.h"
 #include "sound/MappedInstrument.h"
+#include "sound/WAVExporter.h"
 #include "misc/Preferences.h"
 
 #include "rosegarden-version.h"  // for VERSION
@@ -95,8 +96,13 @@ SequenceManager::SequenceManager() :
     m_recordTime(new QElapsedTimer()),
     m_lastTransportStartPosition(0),
     m_sampleRate(0),
-    m_tempo(0)
+    m_tempo(0),
+    m_wavExporter(nullptr),
+    m_exportTimer(new QTimer(this))
 {
+    // The timer is started when required
+    connect(m_exportTimer, &QTimer::timeout,
+            this, &SequenceManager::slotExportUpdate);
 }
 
 SequenceManager::~SequenceManager()
@@ -105,6 +111,10 @@ SequenceManager::~SequenceManager()
 
     if (m_doc)
         m_doc->getComposition().removeObserver(this);
+
+    if (m_wavExporter) {
+        delete m_wavExporter;
+    }
 }
 
 void
@@ -735,12 +745,15 @@ SequenceManager::processAsynchronousMidi(const MappedEventList &mC,
         break;
     }
 
+    // For each MappedEvent...
     for (i = mC.begin(); i != mC.end(); ++i ) {
-        if ((*i)->getType() >= MappedEvent::Audio) {
+        // Skip MIDI events.  Handle only non-MIDI events.
+        // ??? Use "continue" to reduce code walk/indent.
+        if (!(*i)->isMidi()) {
             if ((*i)->getType() == MappedEvent::AudioStopped) {
                 //RG_DEBUG << "AUDIO FILE ID = " << int((*i)->getData1()) << " - FILE STOPPED - " << "INSTRUMENT = " << (*i)->getInstrument();
 
-                if (audioManagerDialog && (*i)->getInstrument() ==
+                if (audioManagerDialog && (*i)->getInstrumentId() ==
                         m_doc->getStudio().getAudioPreviewInstrument()) {
                     audioManagerDialog->
                     closePlayingDialog(
@@ -753,7 +766,7 @@ SequenceManager::processAsynchronousMidi(const MappedEventList &mC,
                 RG_DEBUG << "processAsynchronousMidi(): Received AudioGeneratePreview: data1 is "
                          << int((*i)->getData1()) << ", data2 "
                          << int((*i)->getData2()) << ", instrument is "
-                         << (*i)->getInstrument();
+                         << (*i)->getInstrumentId();
                 m_doc->finalizeAudioFile((int)(*i)->getData1() +
                                          (int)(*i)->getData2() * 256);
             }
@@ -1077,6 +1090,19 @@ void SequenceManager::slotLoopChanged()
     }
 }
 
+void SequenceManager::slotExportUpdate()
+{
+    // The timer is only run when the m_compositionExportManager is set
+    m_wavExporter->update();
+    if (m_wavExporter->isComplete()) {
+        RG_DEBUG << "deleting completed export manager";
+        delete m_wavExporter;
+        m_wavExporter = nullptr;
+        // timer no longer needed
+        m_exportTimer->stop();
+    }
+}
+
 bool SequenceManager::inCountIn(const RealTime &time) const
 {
     if (m_transportStatus == RECORDING  ||
@@ -1200,8 +1226,11 @@ SequenceManager::reinitialiseSequencerStudio()
     if (submasterOuts)
         ports |= MappedEvent::SubmasterOuts;
 
-    MappedEvent mEports(
-            MidiInstrumentBase, MappedEvent::SystemAudioPorts, ports);
+    MappedEvent mEports;
+    mEports.setInstrumentId(MidiInstrumentBase);  // ??? needed?
+    mEports.setType(MappedEvent::SystemAudioPorts);
+    mEports.setData1(ports);
+
     StudioControl::sendMappedEvent(mEports);
 
     // Audio File Format
@@ -1209,9 +1238,11 @@ SequenceManager::reinitialiseSequencerStudio()
     unsigned int audioFileFormat =
             settings.value("audiorecordfileformat", 1).toUInt() ;
 
-    MappedEvent mEff(
-            MidiInstrumentBase, MappedEvent::SystemAudioFileFormat,
-            audioFileFormat);
+    MappedEvent mEff;
+    mEff.setInstrumentId(MidiInstrumentBase);  // ??? needed?
+    mEff.setType(MappedEvent::SystemAudioFileFormat);
+    mEff.setData1(audioFileFormat);
+
     StudioControl::sendMappedEvent(mEff);
 
     settings.endGroup();
@@ -1224,7 +1255,9 @@ SequenceManager::panic()
 
     stop();
 
-    MappedEvent mE(MidiInstrumentBase, MappedEvent::Panic, 0, 0);
+    MappedEvent mE;
+    mE.setInstrumentId(MidiInstrumentBase);  // ??? needed?
+    mE.setType(MappedEvent::Panic);
     StudioControl::sendMappedEvent(mE);
 }
 
@@ -1767,7 +1800,7 @@ SequenceManager::sendTransportControlStatuses()
 
     // Send JACK transport
     //
-    int jackValue = 0;
+    MidiByte jackValue{0};
     if (jackTransport && jackMaster)
         jackValue = 2;
     else {
@@ -1777,44 +1810,50 @@ SequenceManager::sendTransportControlStatuses()
             jackValue = 0;
     }
 
-    MappedEvent mEjackValue(MidiInstrumentBase,  // InstrumentId
-                            MappedEvent::SystemJackTransport,
-                            MidiByte(jackValue));
+    MappedEvent mEjackValue;
+    mEjackValue.setInstrumentId(MidiInstrumentBase);  // ??? needed?
+    mEjackValue.setType(MappedEvent::SystemJackTransport);
+    mEjackValue.setData1(jackValue);
+
     StudioControl::sendMappedEvent(mEjackValue);
 
 
     // Send MMC transport
     //
-    MappedEvent mEmmcValue(MidiInstrumentBase,  // InstrumentId
-                           MappedEvent::SystemMMCTransport,
-                           MidiByte(mmcMode));
+    MappedEvent mEmmcValue;
+    mEmmcValue.setInstrumentId(MidiInstrumentBase);  // ??? needed?
+    mEmmcValue.setType(MappedEvent::SystemMMCTransport);
+    mEmmcValue.setData1(mmcMode);
 
     StudioControl::sendMappedEvent(mEmmcValue);
 
 
     // Send MTC transport
     //
-    MappedEvent mEmtcValue(MidiInstrumentBase,  // InstrumentId
-                           MappedEvent::SystemMTCTransport,
-                           MidiByte(mtcMode));
+    MappedEvent mEmtcValue;
+    mEmtcValue.setInstrumentId(MidiInstrumentBase);  // ??? needed?
+    mEmtcValue.setType(MappedEvent::SystemMTCTransport);
+    mEmtcValue.setData1(mtcMode);
 
     StudioControl::sendMappedEvent(mEmtcValue);
 
 
     // Send MIDI Clock
     //
-    MappedEvent mEmidiClock(MidiInstrumentBase,  // InstrumentId
-                            MappedEvent::SystemMIDIClock,
-                            MidiByte(midiClock));
+    MappedEvent mEmidiClock;
+    mEmidiClock.setInstrumentId(MidiInstrumentBase);  // ??? needed?
+    mEmidiClock.setType(MappedEvent::SystemMIDIClock);
+    mEmidiClock.setData1(midiClock);
 
     StudioControl::sendMappedEvent(mEmidiClock);
 
 
     // Send MIDI Sync Auto-Connect
     //
-    MappedEvent mEmidiSyncAuto(MidiInstrumentBase,  // InstrumentId
-                               MappedEvent::SystemMIDISyncAuto,
-                               MidiByte(midiSyncAuto ? 1 : 0));
+    MappedEvent mEmidiSyncAuto;
+    mEmidiSyncAuto.setInstrumentId(MidiInstrumentBase);  // ??? needed?
+    mEmidiSyncAuto.setType(MappedEvent::SystemMIDISyncAuto);
+    mEmidiSyncAuto.setData1(midiSyncAuto ? 1 : 0);
 
     StudioControl::sendMappedEvent(mEmidiSyncAuto);
 
@@ -1850,6 +1889,25 @@ SequenceManager::getSampleRate() const
     return m_sampleRate;
 }
 
+void
+SequenceManager::setExportWavFile(const QString& fileName)
+{
+    RG_DEBUG << "setExportWavFile" << fileName;
+    if (m_wavExporter) {
+        RG_DEBUG << "replacing previous export manager";
+        delete m_wavExporter;
+    }
+    m_wavExporter = new WAVExporter(fileName);
+    // If creation of the WAVExporter has failed, bail.
+    if (!m_wavExporter->isOK())
+        return;
+
+    // and install in the driver
+    RosegardenSequencer::getInstance()->installExporter(m_wavExporter);
+    // and start the timer
+    m_exportTimer->start(50);
+}
+
 bool
 SequenceManager::shouldWarnForImpreciseTimer()
 {
