@@ -64,6 +64,15 @@ public slots:
      */
     virtual void slotNameChanged(const QString &) = 0;
 
+    /// Handler for edit completion in any of the line edit widgets.
+    /**
+     * Connected to LineEdit::editingFinished() for all line edits.
+     *
+     * This is virtual because NameSetEditor does the connect and wants
+     * the derived version.
+     */
+    virtual void slotEditingFinished() = 0;
+
     /// Handler for presses of any of the key map buttons.
     /**
      * Connected to QToolButton::clicked() for all key map buttons.
@@ -85,6 +94,8 @@ protected:
                   QWidget *parent,
                   bool showKeyMapButtons = false);
 
+    // ??? Key mappings are only used by one deriver (MidiProgramsEditor).
+    //     Push this down to there.
     QToolButton *getKeyMapButton(int n) { return m_keyMapButtons[n]; }
     const QToolButton *getKeyMapButton(int n) const { return m_keyMapButtons[n]; }
 
@@ -111,7 +122,8 @@ protected:
     QLabel *m_librarianEmail;
 
     std::vector<LineEdit *> m_names;
-    QStringList m_completions;
+
+    virtual void clearAll();
 
 private:
     QPushButton *m_numberingBaseButton;
