@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -15,6 +15,7 @@
     COPYING included with this distribution for more information.
 */
 
+#define RG_MODULE_STRING "[Rotary]"
 
 #include "Rotary.h"
 
@@ -145,6 +146,7 @@ Rotary::setMaximum(float max)
     update();
 }
 
+/* unused
 void
 Rotary::setStep(float step)
 {
@@ -154,6 +156,7 @@ Rotary::setStep(float step)
     m_step = step;
     update();
 }
+*/
 
 void
 Rotary::setPageStep(float step)
@@ -292,7 +295,7 @@ Rotary::paintEvent(QPaintEvent *)
     int pos = indent + (width - 2 * indent) / 8;
     int darkWidth = (width - 2 * indent) * 2 / 3;
     while (darkWidth) {
-        c = c.light(101);
+        c = c.lighter(101);
         pen.setColor(c);
         paint.setPen(pen);
         paint.drawEllipse(pos, pos, darkWidth, darkWidth);
@@ -464,9 +467,9 @@ Rotary::mousePressEvent(QMouseEvent *e)
 {
     if (e->button() == Qt::LeftButton) {
         m_buttonPressed = true;
-        m_lastY = e->y();
-        m_lastX = e->x();
-    } else if (e->button() == Qt::MidButton) {  // reset to centre position
+        m_lastY = e->pos().y();
+        m_lastX = e->pos().x();
+    } else if (e->button() == Qt::MiddleButton) {  // reset to centre position
         m_position = (m_maximum + m_minimum) / 2.0;
         snapPosition();
         update();
@@ -493,7 +496,7 @@ Rotary::mousePressEvent(QMouseEvent *e)
 //    std::cerr << "Rotary::mousePressEvent: logarithmic = " << m_logarithmic
 //              << ", position = " << m_position << std::endl;
 
-    if (e->button() == Qt::RightButton || e->button() == Qt::MidButton) {
+    if (e->button() == Qt::RightButton || e->button() == Qt::MiddleButton) {
         // wait 500ms then hide text float
         textFloat->hideAfterDelay(500);
     }
@@ -585,7 +588,8 @@ Rotary::mouseMoveEvent(QMouseEvent *e)
         // Dragging by x or y axis when clicked modifies value
         //
         float newValue = m_position +
-                         (m_lastY - float(e->y()) + float(e->x()) - m_lastX) * m_step;
+            (m_lastY - float(e->pos().y()) + float(e->pos().x()) - m_lastX)
+            * m_step;
 
         if (newValue > m_maximum)
             m_position = m_maximum;
@@ -595,8 +599,8 @@ Rotary::mouseMoveEvent(QMouseEvent *e)
             else
                 m_position = newValue;
 
-        m_lastY = e->y();
-        m_lastX = e->x();
+        m_lastY = e->pos().y();
+        m_lastX = e->pos().x();
 
         snapPosition();
 
@@ -620,9 +624,12 @@ Rotary::mouseMoveEvent(QMouseEvent *e)
 void
 Rotary::wheelEvent(QWheelEvent *e)
 {
-    if (e->delta() > 0)
+    // We'll handle this.  Don't pass to parent.
+    e->accept();
+
+    if (e->angleDelta().y() > 0)
         m_position -= m_pageStep;
-    else
+    else if (e->angleDelta().y() < 0)
         m_position += m_pageStep;
 
     if (m_position > m_maximum)
@@ -654,7 +661,11 @@ Rotary::wheelEvent(QWheelEvent *e)
 }
 
 void
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+Rotary::enterEvent(QEnterEvent *)
+#else
 Rotary::enterEvent(QEvent *)
+#endif
 {
     TextFloat::getTextFloat()->attach(this);
 }
