@@ -38,6 +38,7 @@ namespace Rosegarden {
 
 class MappedInstrument;
 class SoundDriver;
+class WAVExporter;
 
 
 /// MIDI and Audio recording and playback
@@ -120,7 +121,7 @@ public:
     void setMappedInstrument(int type, unsigned int id);
 
     /// Puts a mapped event on the m_asyncOutQueue
-    void processMappedEvent(MappedEvent mE);
+    void processMappedEvent(const MappedEvent &mE);
 
 
     // --- DEVICES ---
@@ -435,6 +436,8 @@ public:
     /// Initialise the virtual studio at this end of the link.
     void initialiseStudio();
 
+    void installExporter(WAVExporter* wavExporter);
+
 
     // --------- Transport Interface --------
     //
