@@ -350,6 +350,8 @@ public:
     void claimUnwantedPlugin(void *plugin) override;
     void scavengePlugins() override;
 
+    void installExporter(WAVExporter* wavExporter) override;
+
     /// Update Ports and Connections
     /**
      * Updates m_alsaPorts and m_devicePortMap to match the ports and
@@ -659,7 +661,7 @@ private:
                                const QString& connection,
                                const ClientPortPair &pair);
     /// Return whether the client/port is in m_devicePortMap.
-    bool portInUse(int client, int port) const;
+    //bool portInUse(int client, int port) const;
     /// Is the given deviceId within m_devicePortMap connected?
     bool isConnected(DeviceId deviceId) const;
 
