@@ -3,11 +3,11 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
- 
+    Copyright 2000-2024 the Rosegarden development team.
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -21,6 +21,7 @@
 
 #include <string>
 #include <sstream>  // std::stringstream
+#include <unistd.h>
 
 #include <QMessageBox>
 #include <QPixmap>
@@ -29,27 +30,50 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QDir>
+#include <QRegularExpression>
 
+#include "gui/dialogs/AudioFileLocationDialog.h"
 #include "gui/general/FileSource.h"
 #include "AudioFile.h"
 #include "WAVAudioFile.h"
 #include "BWFAudioFile.h"
 #include "misc/Debug.h"
+#include "misc/Preferences.h"
 #include "misc/Strings.h"  // qstrtostr() and friends
 #include "sequencer/RosegardenSequencer.h"
+#include "document/RosegardenDocument.h"
+#include "gui/application/RosegardenMainWindow.h"
 #include "sound/audiostream/AudioReadStream.h"
 #include "sound/audiostream/AudioReadStreamFactory.h"
 #include "sound/audiostream/AudioWriteStream.h"
 #include "sound/audiostream/AudioWriteStreamFactory.h"
+#include "gui/application/SetWaitCursor.h"
 
 #include "AudioFileManager.h"
 
-// #define DEBUG_AUDIOFILEMANAGER
-// #define DEBUG_AUDIOFILEMANAGER_INSERT_FILE
+namespace
+{
+
+    QString addTrailingSlash(const QString &path)
+    {
+        if (path.isEmpty())
+            return "/";
+
+        QString path2 = path;
+
+        // Add a trailing "/" if needed.
+        if (!path2.endsWith('/'))
+            path2 += "/";
+
+        return path2;
+    }
+
+}
 
 namespace Rosegarden
 {
 
+
 static pthread_mutex_t audioFileManagerLock;
 
 // ??? Why not use QMutexLocker and QMutex?  Probably need to go through
@@ -57,7 +81,7 @@ static pthread_mutex_t audioFileManagerLock;
 class MutexLock
 {
 public:
-    MutexLock(pthread_mutex_t *mutex) : m_mutex(mutex)
+    explicit MutexLock(pthread_mutex_t *mutex) : m_mutex(mutex)
     {
         pthread_mutex_lock(m_mutex);
     }
@@ -70,8 +94,10 @@ private:
 };
 
 
-AudioFileManager::AudioFileManager() :
+AudioFileManager::AudioFileManager(RosegardenDocument *doc) :
+    m_document(doc),
     m_lastAudioFileID(0),
+    m_audioLocationConfirmed(false),
     m_expectedSampleRate(0)
 {
     pthread_mutexattr_t attr;
@@ -81,7 +107,7 @@ AudioFileManager::AudioFileManager() :
     pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
 #else
 #if defined(PTHREAD_MUTEX_RECURSIVE) || defined(__FreeBSD__)
-
+    // cppcheck-suppress ConfigurationNotChecked
     pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
 #else
 
@@ -91,10 +117,6 @@ AudioFileManager::AudioFileManager() :
 
     pthread_mutex_init(&audioFileManagerLock, &attr);
 
-    // Set this through the set method so that the tilde gets
-    // shaken out.
-    //
-    setAudioPath("~/rosegarden");
 }
 
 AudioFileManager::~AudioFileManager()
@@ -131,20 +153,16 @@ AudioFileManager::addFile(const QString &filePath)
         AudioFileType subType = RIFFAudioFile::identifySubType(filePath);
 
         if (subType == BWF) {
-#ifdef DEBUG_AUDIOFILEMANAGER
-            RG_DEBUG << "FOUND BWF";
-#endif
-
             try {
                 aF = new BWFAudioFile(id, qstrtostr(getShortFilename(filePath)), filePath);
-            } catch (SoundFile::BadSoundFileException e) {
+            } catch (const SoundFile::BadSoundFileException &e) {
                 delete aF;
                 throw BadAudioPathException(e);
             }
         } else if (subType == WAV) {
             try {
                 aF = new WAVAudioFile(id, qstrtostr(getShortFilename(filePath)), filePath);
-            } catch (SoundFile::BadSoundFileException e) {
+            } catch (const SoundFile::BadSoundFileException &e) {
                 delete aF;
                 throw BadAudioPathException(e);
             }
@@ -164,7 +182,7 @@ AudioFileManager::addFile(const QString &filePath)
                 RG_WARNING << "addFile(): Malformed audio file in " << filePath;
                 throw BadAudioPathException(filePath, __FILE__, __LINE__);
             }
-        } catch (SoundFile::BadSoundFileException e) {
+        } catch (const SoundFile::BadSoundFileException &e) {
             delete aF;
             throw BadAudioPathException(e);
         }
@@ -210,62 +228,6 @@ AudioFileManager::getDirectory(const QString &path) const
     return rS;
 }
 
-#if 0
-// Create a new AudioFile with unique ID and label - insert from
-// our RG4 file
-//
-AudioFileId
-AudioFileManager::insertFile(const std::string &name,
-                             const QString &fileName)
-{
-    MutexLock lock (&audioFileManagerLock)
-        ;
-
-    // first try to expand any beginning tilde
-    //
-    QString foundFileName = tildeToHome(fileName);
-
-    // If we've expanded and we can't find the file
-    // then try to find it in audio file directory.
-    //
-    QFileInfo info(foundFileName);
-    if (!info.exists())
-        foundFileName = getFileInPath(foundFileName);
-
-#ifdef DEBUG_AUDIOFILEMANAGER_INSERT_FILE
-    RG_DEBUG << "insertFile() - expanded fileName = \"" << foundFileName << "\"";
-#endif
-
-    // bail if we haven't found any reasonable filename
-    if (foundFileName == "")
-        return false;
-
-    AudioFileId id = getUniqueAudioFileID();
-
-    WAVAudioFile *aF = 0;
-
-    try {
-
-        aF = new WAVAudioFile(id, name, foundFileName);
-
-        // if we don't recognise the file then don't insert it
-        //
-        if (aF->open() == false) {
-            delete aF;
-            RG_WARNING << "insertFile() - don't recognise file type in " << foundFileName;
-            throw BadAudioPathException(foundFileName, __FILE__, __LINE__);
-        }
-        m_audioFiles.push_back(aF);
-
-    } catch (SoundFile::BadSoundFileException e) {
-        delete aF;
-        throw BadAudioPathException(e);
-    }
-
-    return id;
-}
-#endif
-
 bool
 AudioFileManager::removeFile(AudioFileId id)
 {
@@ -273,17 +235,24 @@ AudioFileManager::removeFile(AudioFileId id)
         ;
 
     // For each AudioFile
-    for (std::vector<AudioFile *>::iterator it = m_audioFiles.begin();
-         it != m_audioFiles.end();
-         ++it) {
-        if ((*it)->getId() == id) {
-            m_peakManager.removeAudioFile(*it);
-            m_recordedAudioFiles.erase(*it);
-            m_derivedAudioFiles.erase(*it);
-            delete(*it);
-            m_audioFiles.erase(it);
-            return true;
-        }
+    for (AudioFileVector::iterator audioFileIter = m_audioFiles.begin();
+         audioFileIter != m_audioFiles.end();
+         ++audioFileIter) {
+        AudioFile *audioFile = (*audioFileIter);
+
+        // Not the one we're looking for?  Try the next.
+        if (audioFile->getId() != id)
+            continue;
+
+        // Found it
+
+        m_peakManager.removeAudioFile(audioFile);
+        m_recordedAudioFiles.erase(audioFile);
+        m_derivedAudioFiles.erase(audioFile);
+        delete(audioFile);
+        m_audioFiles.erase(audioFileIter);
+
+        return true;
     }
 
     return false;
@@ -311,33 +280,32 @@ AudioFileManager::insertFile(const std::string &name,
     MutexLock lock (&audioFileManagerLock)
         ;
 
-    // first try to expand any beginning tilde
-    QString foundFileName = tildeToHome(fileName);
+    // Normally, the file will be found in the audio path.
+    QString absoluteFilePath = getAbsoluteAudioPath() + fileName;
 
-    // If we've expanded and we can't find the file
-    // then try to find it in audio file directory.
-    //
-    QFileInfo info(foundFileName);
-    if (!info.exists())
-        foundFileName = getFileInPath(foundFileName);
+    QFileInfo fileInfo(absoluteFilePath);
+    // If it isn't there...
+    if (!fileInfo.exists()) {
 
-#ifdef DEBUG_AUDIOFILEMANAGER_INSERT_FILE
-    RG_DEBUG << "insertFile() - expanded fileName = \"" << foundFileName << "\"";
-#endif
+        // ...see if the name is already an absolute or relative path.
 
-    // If no joy here then we can't find this file
-    if (foundFileName == "")
-        return false;
+        // Try expanding any beginning tilde or dot.
+        absoluteFilePath = toAbsolute(fileName);
 
-    // make sure we don't have a file of this ID hanging around already
+        fileInfo.setFile(absoluteFilePath);
+        if (!fileInfo.exists())
+            return false;
+
+    }
+
+    // Make sure we don't have a file of this ID hanging around already.
     removeFile(id);
 
-    // and insert
     WAVAudioFile *aF = nullptr;
 
     try {
 
-        aF = new WAVAudioFile(id, name, foundFileName);
+        aF = new WAVAudioFile(id, name, absoluteFilePath);
 
         // Test the file
         if (aF->open() == false) {
@@ -348,7 +316,7 @@ AudioFileManager::insertFile(const std::string &name,
         m_audioFiles.push_back(aF);
         updateAudioFileID(id);
 
-    } catch (SoundFile::BadSoundFileException e) {
+    } catch (const SoundFile::BadSoundFileException &e) {
         delete aF;
         throw BadAudioPathException(e);
     }
@@ -357,85 +325,121 @@ AudioFileManager::insertFile(const std::string &name,
 }
 
 void
-AudioFileManager::setAudioPath(const QString &path)
+AudioFileManager::setRelativeAudioPath(
+        const QString &newPath,
+        bool doMoveFiles)
 {
-    MutexLock lock (&audioFileManagerLock)
-        ;
+    QString newRelativePath = newPath;
 
-    if (path.size() != 0) {
-        QString hPath = path;
-        QString homePath = getenv("HOME");
-    
-        // add a trailing / if we don't have one
-        if (hPath[hPath.size() - 1] != '/')
-            hPath += "/";
+    if (newRelativePath.isEmpty())
+        newRelativePath = ".";
 
-        // get the home directory
-        // ??? Use tildeToHome().
-        if (hPath[0] == '~') {
-            hPath.remove(0, 1);
-            hPath = homePath + hPath;
-        }
-
-        m_audioPath = hPath;
-    } else {
-#ifdef DEBUG_AUDIOFILEMANAGER
-        RG_DEBUG << "setAudioPath() - zero length path, do nothing";
-#endif
+    // If the path doesn't start with "~", "/", or "."...
+    if (!newRelativePath.startsWith('/') &&
+        !newRelativePath.startsWith('~') &&
+        !newRelativePath.startsWith('.')) {
+        // Use the document path.
+        newRelativePath = "./" + newRelativePath;
     }
 
+    QString newAbsolutePath = toAbsolute(newRelativePath);
+    newAbsolutePath = addTrailingSlash(newAbsolutePath);
+
+    // ??? This is probably only needed if the directory does not
+    //     exist in the first place and we have no files to move.
+    //     The issue here is that the user should know that if they
+    //     keep changing this, they will leave a trail of empty
+    //     directories.
+    //QMessageBox::information(
+    //        RosegardenMainWindow::self(),
+    //        tr("Audio File Location"),
+    //        tr("Creating the new directory for audio files:<br />%1").
+    //            arg(newAbsolutePath));
+
+    QString originalLocation;
+    // If the files are moving, provide the user with some additional
+    // information in case there is a problem.
+    if (doMoveFiles)
+        originalLocation = tr("<br />Audio files will remain in their original location.<br />(%1)").
+            arg(getAbsoluteAudioPath());
+
+    // Make the path if needed.
+    // We need to make the path even if we are not moving files into it to
+    // make sure it is there for recording.  Otherwise we will end up back
+    // here and the user will be stuck.
+    const bool success = QDir().mkpath(newAbsolutePath);
+    if (!success) {
+        QMessageBox::warning(
+                RosegardenMainWindow::self(),
+                tr("Audio File Location"),
+                tr("Cannot create audio path.<br />%1").
+                    arg(newAbsolutePath) + originalLocation);
+        return;
+    }
+
+    // Is the new path writable?
+    // (We could do this only when moving to allow for opening and working
+    // with read-only audio repositories.  But then we put off the
+    // unpleasant news to recording time.)
+    if (access(qstrtostr(newAbsolutePath).c_str(), W_OK) != 0) {
+        QMessageBox::warning(
+                RosegardenMainWindow::self(),
+                tr("Audio File Location"),
+                tr("Audio path is not writable.<br />%1").
+                    arg(newAbsolutePath) + originalLocation);
+        return;
+    }
+
+    if (doMoveFiles) {
+        // Physically move the files, and adjust their paths to
+        // point to the new location.
+        moveFiles(newAbsolutePath);
+    }
+
+    {
+        MutexLock lock (&audioFileManagerLock);
+
+        m_relativeAudioPath = newRelativePath;
+    }
+
+    if (doMoveFiles) {
+        // Force a save.
+        RosegardenMainWindow::self()->slotFileSave();
+    }
+
+}
+
+QString
+AudioFileManager::getAbsoluteAudioPath() const
+{
+    QString absoluteAudioPath = toAbsolute(m_relativeAudioPath);
+    absoluteAudioPath = addTrailingSlash(absoluteAudioPath);
+    return absoluteAudioPath;
 }
 
 void
 AudioFileManager::testAudioPath()
 {
-    QFileInfo info(m_audioPath);
+    QFileInfo info(getAbsoluteAudioPath());
     if (!(info.exists() && info.isDir() && !info.isRelative() &&
             info.isWritable() && info.isReadable()))
-        throw BadAudioPathException(m_audioPath);
-}
-
-QString
-AudioFileManager::getFileInPath(const QString &file)
-{
-    MutexLock lock (&audioFileManagerLock)
-        ;
-
-    QFileInfo info(file);
-
-    if (info.exists())
-        return file;
-
-    // Build the search filename from the audio path and
-    // the file basename.
-    //
-    QString searchFile = m_audioPath + info.fileName();
-    QFileInfo searchInfo(searchFile);
-
-    if (searchInfo.exists())
-        return searchFile.toLatin1().data();
-
-    RG_DEBUG << "getFileInPath() - searchInfo = " << searchFile;
-
-    return "";
+        throw BadAudioPathException(getAbsoluteAudioPath());
 }
 
 int
-AudioFileManager::fileExists(const QString &path)
+AudioFileManager::fileExists(const QString &absoluteFilePath)
 {
     MutexLock lock (&audioFileManagerLock)
         ;
 
     // For each AudioFile
-    for (std::vector<AudioFile *>::const_iterator it = m_audioFiles.begin();
-         it != m_audioFiles.end();
-         ++it) {
-        if ((*it)->getFilename() == path)
-            return (*it)->getId();
+    for (const AudioFile *audioFile : m_audioFiles) {
+        if (audioFile->getAbsoluteFilePath() == absoluteFilePath)
+            return audioFile->getId();
     }
 
+    // Not found.
     return -1;
-
 }
 
 bool
@@ -445,15 +449,12 @@ AudioFileManager::fileExists(AudioFileId id)
         ;
 
     // For each AudioFile
-    for (std::vector<AudioFile *>::const_iterator it = m_audioFiles.begin();
-         it != m_audioFiles.end();
-         ++it) {
-        if ((*it)->getId() == id)
+    for (const AudioFile *audioFile : m_audioFiles) {
+        if (audioFile->getId() == id)
             return true;
     }
 
     return false;
-
 }
 
 void
@@ -463,12 +464,10 @@ AudioFileManager::clear()
         ;
 
     // For each AudioFile
-    for (std::vector<AudioFile *>::const_iterator it = m_audioFiles.begin();
-         it != m_audioFiles.end();
-         ++it) {
-        m_recordedAudioFiles.erase(*it);
-        m_derivedAudioFiles.erase(*it);
-        delete(*it);
+    for (AudioFile *audioFile : m_audioFiles) {
+        m_recordedAudioFiles.erase(audioFile);
+        m_derivedAudioFiles.erase(audioFile);
+        delete audioFile;
     }
 
     m_audioFiles.erase(m_audioFiles.begin(), m_audioFiles.end());
@@ -482,10 +481,8 @@ AudioFileManager::createRecordingAudioFile(QString projectName, QString instrume
     MutexLock lock (&audioFileManagerLock)
         ;
 
-    RG_DEBUG << "createRecordingAudioFile(): " << projectName;
-
     // Replace invalid filename characters with "_".
-    instrumentAlias.replace(QRegExp("[&\\\\\\/%\\*\\?\"'><\\|~: ]"), "_");
+    instrumentAlias.replace(QRegularExpression("[&\\\\\\/%\\*\\?\"'><\\|~: ]"), "_");
 
     if (instrumentAlias.isEmpty()) instrumentAlias = "not_specified";
 
@@ -500,7 +497,7 @@ AudioFileManager::createRecordingAudioFile(QString projectName, QString instrume
                    .arg(QDateTime::currentDateTime().toString("yyyy-MM-dd_hh.mm.ss"))
                    .arg(newId + 1);
 
-        if (QFile(m_audioPath + fileName).exists()) {
+        if (QFile(getAbsoluteAudioPath() + fileName).exists()) {
             fileName = "";
             ++newId;
         }
@@ -509,15 +506,15 @@ AudioFileManager::createRecordingAudioFile(QString projectName, QString instrume
     // insert file into vector
     WAVAudioFile *aF = nullptr;
 
-    QString aup( m_audioPath );
-    QString fnm(fileName);
-    const QString fpath = m_audioPath + fileName;
+    //QString aup( getAbsoluteAudioPath() );
+    //QString fnm(fileName);
+    const QString fpath = getAbsoluteAudioPath() + fileName;
     try {
-        aF = new WAVAudioFile( static_cast<const unsigned int>(newId), qstrtostr(fileName), fpath );
-        //aF = new WAVAudioFile(newId, fileName.data(), m_audioPath + qstrtostr(fileName) );
+        aF = new WAVAudioFile(newId, qstrtostr(fileName), fpath);
+        //aF = new WAVAudioFile(newId, fileName.data(), getAbsoluteAudioPath() + qstrtostr(fileName) );
         m_audioFiles.push_back(aF);
         m_recordedAudioFiles.insert(aF);
-    } catch (SoundFile::BadSoundFileException e) {
+    } catch (const SoundFile::BadSoundFileException &e) {
         delete aF;
         throw BadAudioPathException(e);
     }
@@ -565,7 +562,7 @@ AudioFileManager::createDerivedAudioFile(AudioFileId source,
     AudioFileId newId = getUniqueAudioFileID();
     QString fileName = "";
 
-    QString sourceBase = sourceFile->getShortFilename();
+    QString sourceBase = sourceFile->getFileName();
     if (sourceBase.length() > 4 && sourceBase.mid(0, 3) == "rg-") {
         sourceBase = sourceBase.mid(3);
     }
@@ -579,7 +576,7 @@ AudioFileManager::createDerivedAudioFile(AudioFileId source,
             .arg(QDateTime::currentDateTime().toString("yyyyMMdd-hhmmss"))
             .arg(newId + 1);
 
-        if (QFile(m_audioPath + fileName).exists()) {
+        if (QFile(getAbsoluteAudioPath() + fileName).exists()) {
             fileName = "";
             ++newId;
         }
@@ -591,10 +588,10 @@ AudioFileManager::createDerivedAudioFile(AudioFileId source,
     try {
         aF = new WAVAudioFile(newId,
                               qstrtostr(fileName),
-                              m_audioPath + fileName );
+                              getAbsoluteAudioPath() + fileName );
         m_audioFiles.push_back(aF);
         m_derivedAudioFiles.insert(aF);
-    } catch (SoundFile::BadSoundFileException e) {
+    } catch (const SoundFile::BadSoundFileException &e) {
         delete aF;
         throw BadAudioPathException(e);
     }
@@ -603,7 +600,7 @@ AudioFileManager::createDerivedAudioFile(AudioFileId source,
 }
 
 AudioFileId
-AudioFileManager::importURL(const QUrl &url, int sampleRate)
+AudioFileManager::importURL(const QUrl &url, int targetSampleRate)
 {
     if (m_progressDialog) {
         m_progressDialog->setLabelText(tr("Adding audio file..."));
@@ -621,14 +618,12 @@ AudioFileManager::importURL(const QUrl &url, int sampleRate)
 
     source.waitForData();
 
-    return importFile(source.getLocalFilename(), sampleRate);
+    return importFile(source.getLocalFilename(), targetSampleRate);
 }
 
 AudioFileId
-AudioFileManager::importFile(const QString &fileName, int sampleRate)
+AudioFileManager::importFile(const QString &fileName, int targetSampleRate)
 {
-    RG_DEBUG << "importFile("<< fileName << ", " << sampleRate << ")";
-
     if (m_progressDialog)
         m_progressDialog->setLabelText(tr("Importing audio file..."));
 
@@ -654,7 +649,7 @@ AudioFileManager::importFile(const QString &fileName, int sampleRate)
                 .arg(QDateTime::currentDateTime().toString("yyyyMMdd-hhmmss"))
                 .arg(newId + 1);
 
-            if (QFile(m_audioPath + targetName).exists()) {
+            if (QFile(getAbsoluteAudioPath() + targetName).exists()) {
                 targetName = "";
                 ++newId;
             }
@@ -667,7 +662,7 @@ AudioFileManager::importFile(const QString &fileName, int sampleRate)
     if (m_progressDialog)
         m_progressDialog->setLabelText(tr("Converting audio file..."));
 
-    QString outFileName = m_audioPath + targetName;
+    QString outFileName = getAbsoluteAudioPath() + targetName;
     int ec = convertAudioFile(fileName, outFileName);
 
     if (ec) {
@@ -680,16 +675,15 @@ AudioFileManager::importFile(const QString &fileName, int sampleRate)
             ;
 
         // insert file into vector
-        WAVAudioFile *aF = nullptr;
-
-        aF = new WAVAudioFile(newId,
-                              qstrtostr(targetName),
-                              m_audioPath + targetName);
+        WAVAudioFile *aF =
+            new WAVAudioFile(newId,
+                             qstrtostr(targetName),
+                             getAbsoluteAudioPath() + targetName);
         m_audioFiles.push_back(aF);
         m_derivedAudioFiles.insert(aF);
         // Don't catch SoundFile::BadSoundFileException
 
-        m_expectedSampleRate = sampleRate;
+        m_expectedSampleRate = targetSampleRate;
 
         return aF->getId();
     }
@@ -697,8 +691,6 @@ AudioFileManager::importFile(const QString &fileName, int sampleRate)
 
 int AudioFileManager::convertAudioFile(const QString &inFile, const QString &outFile)
 {
-    RG_DEBUG << "convertAudioFile(): inFile = " << inFile << ", outFile = " << outFile;
-
     AudioReadStream *rs = AudioReadStreamFactory::createReadStream( inFile);
     if (!rs || !rs->isOK()) {
         RG_WARNING << "convertAudioFile(): ERROR: Failed to read audio file";
@@ -773,58 +765,6 @@ int AudioFileManager::convertAudioFile(const QString &inFile, const QString &out
     return 0;
 }
 
-#if 0
-AudioFile *
-AudioFileManager::getLastAudioFile()
-{
-    MutexLock lock (&audioFileManagerLock)
-        ;
-
-    std::vector<AudioFile *>::iterator it = m_audioFiles.begin();
-    AudioFile * audioFile = 0;
-
-    while (it != m_audioFiles.end()) {
-        audioFile = (*it);
-        ++it;
-    }
-
-    return audioFile;
-}
-#endif
-
-QString
-AudioFileManager::homeToTilde(const QString &path) const
-{
-    QString rS = path;
-    QString homePath = getenv("HOME");
-
-    // if path length is less than homePath then just return unchanged
-    if (rS.length() < homePath.length())
-        return rS;
-
-    // if the first section matches the path then substitute
-    if (rS.mid(0, homePath.length()) == homePath) {
-        rS.remove(0, homePath.length());
-        rS = "~" + rS;
-    }
-
-    return rS;
-}
-
-QString
-AudioFileManager::tildeToHome(const QString &path) const
-{
-    QString rS = path;
-    const QString homePath = QDir::homePath();
-
-    if (rS.mid(0, 2) == "~/") {
-        rS.remove(0, 1); // erase tilde and prepend HOME env
-        rS = homePath + rS;
-    }
-
-    return rS;
-}
-
 std::string
 AudioFileManager::toXmlString() const
 {
@@ -832,41 +772,28 @@ AudioFileManager::toXmlString() const
         ;
 
     std::stringstream audioFiles;
-    QString audioPath = homeToTilde(m_audioPath);
 
     audioFiles << "<audiofiles";
     if (m_expectedSampleRate != 0) {
         audioFiles << " expectedRate=\"" << m_expectedSampleRate << "\"";
     }
     audioFiles << ">" << std::endl;
-    audioFiles << "    <audioPath value=\"" << audioPath << "\"/>" << std::endl;
+    audioFiles << "    <audioPath value=\"" << m_relativeAudioPath << "\"/>" << std::endl;
 
     QString fileName;
 
     // For each AudioFile
-    for (std::vector<AudioFile *>::const_iterator it = m_audioFiles.begin();
-         it != m_audioFiles.end();
-         ++it) {
-        fileName = (*it)->getFilename();
+    for (const AudioFile *audioFile : m_audioFiles) {
+        fileName = audioFile->getAbsoluteFilePath();
 
-        // attempt two substitutions - If the prefix to the filename
-        // is the same as the audio path then we can dock the prefix
-        // as it'll be added again next time.  If the path doesn't
-        // have the audio path in it but has our home directory in it
-        // then swap this out for a tilde '~'
-        //
-#ifdef DEBUG_AUDIOFILEMANAGER
-        RG_DEBUG << "toXmlString(): DIR = " << getDirectory(fileName) << " :  PATH = " << m_audioPath;
-#endif
-
-        if (getDirectory(fileName) == m_audioPath)
+        // If the absolute audio path is here, remove it.
+        // ??? insertFile() is the other side of this.
+        if (getDirectory(fileName) == getAbsoluteAudioPath())
             fileName = getShortFilename(fileName);
-        else
-            fileName = homeToTilde(fileName);
 
-        audioFiles << "    <audio id=\"" << (*it)->getId()
+        audioFiles << "    <audio id=\"" << audioFile->getId()
                    << "\" file=\"" << fileName
-                   << "\" label=\"" << encode((*it)->getLabel())
+                   << "\" label=\"" << encode(audioFile->getLabel())
                    << "\"/>" << std::endl;
     }
 
@@ -891,19 +818,12 @@ AudioFileManager::generatePreviews()
 
     m_peakManager.setProgressDialog(m_progressDialog);
 
-#ifdef DEBUG_AUDIOFILEMANAGER
-    RG_DEBUG << "generatePreviews() - for " << m_audioFiles.size() << " files";
-#endif
-
-
     // Generate peaks if we need to
 
     // For each AudioFile
-    for (std::vector<AudioFile *>::const_iterator it = m_audioFiles.begin();
-         it != m_audioFiles.end();
-         ++it) {
-        if (!m_peakManager.hasValidPeaks(*it))
-            m_peakManager.generatePeaks(*it);
+    for (AudioFile *audioFile : m_audioFiles) {
+        if (!m_peakManager.hasValidPeaks(audioFile))
+            m_peakManager.generatePeaks(audioFile);
 
         if (m_progressDialog  &&  m_progressDialog->wasCanceled())
             break;
@@ -946,13 +866,15 @@ AudioFileManager::getAudioFile(AudioFileId id)
     MutexLock lock (&audioFileManagerLock)
         ;
 
+    // ??? A std::map<AudioFileId, AudioFile *> would be faster.
+
     // For each AudioFile
-    for (std::vector<AudioFile *>::const_iterator it = m_audioFiles.begin();
-         it != m_audioFiles.end();
-         ++it) {
-        if ((*it)->getId() == id)
-            return (*it);
+    for (AudioFile *audioFile : m_audioFiles) {
+        if (audioFile->getId() == id)
+            return audioFile;
     }
+
+    // Not found
     return nullptr;
 }
 
@@ -967,15 +889,17 @@ AudioFileManager::getPreview(AudioFileId id,
         ;
 
     AudioFile *audioFile = getAudioFile(id);
-
-    if (audioFile == nullptr) {
+    if (!audioFile)
         return std::vector<float>();
-    }
 
     if (!m_peakManager.hasValidPeaks(audioFile)) {
-        RG_WARNING << "getPreview(): No peaks for audio file " << audioFile->getFilename();
+        // ??? This happens a lot when recording audio.  Need to detect
+        //     that we are recording and suppress this.  Or just don't
+        //     call this when recording.  The caller has comments in
+        //     its catch() to this effect.
+        //RG_WARNING << "getPreview(): No peaks for audio file" << audioFile->getAbsoluteFilePath() << "(this is probably OK when recording)";
         throw PeakFileManager::BadPeakFileException(
-                audioFile->getFilename(), __FILE__, __LINE__);
+                audioFile->getAbsoluteFilePath(), __FILE__, __LINE__);
     }
 
     return m_peakManager.getPreview(audioFile,
@@ -999,9 +923,9 @@ AudioFileManager::drawPreview(AudioFileId id,
         return;
 
     if (!m_peakManager.hasValidPeaks(audioFile)) {
-        RG_WARNING << "drawPreview(): No peaks for audio file " << audioFile->getFilename();
+        RG_WARNING << "drawPreview(): No peaks for audio file " << audioFile->getAbsoluteFilePath();
         throw PeakFileManager::BadPeakFileException(
-                audioFile->getFilename(), __FILE__, __LINE__);
+                audioFile->getAbsoluteFilePath(), __FILE__, __LINE__);
     }
 
     std::vector<float> values = m_peakManager.getPreview
@@ -1017,25 +941,15 @@ AudioFileManager::drawPreview(AudioFileId id,
 //    painter.setPen(qApp->palette().color(QPalette::Active,
 //                                         QColorGroup::Mid));
 
-    if (values.size() == 0) {
-#ifdef DEBUG_AUDIOFILEMANAGER
-        RG_WARNING << "drawPreview() - no preview values returned!";
-#endif
-
+    if (values.empty())
         return;
-    }
 
     float yStep = pixmap->height() / 2;
     int channels = audioFile->getChannels();
     float ch1Value, ch2Value;
 
-    if (channels == 0) {
-#ifdef DEBUG_AUDIOFILEMANAGER
-        RG_WARNING << "drawPreview() - no channels in audio file!";
-#endif
-
+    if (channels == 0)
         return;
-    }
 
 
     // Render pixmap
@@ -1073,9 +987,9 @@ AudioFileManager::drawHighlightedPreview(AudioFileId id,
         return;
 
     if (!m_peakManager.hasValidPeaks(audioFile)) {
-        RG_WARNING << "getPreview(): No peaks for audio file " << audioFile->getFilename();
+        RG_WARNING << "drawHighlightedPreview(): No peaks for audio file " << audioFile->getAbsoluteFilePath();
         throw PeakFileManager::BadPeakFileException
-        (audioFile->getFilename(), __FILE__, __LINE__);
+        (audioFile->getAbsoluteFilePath(), __FILE__, __LINE__);
     }
 
     std::vector<float> values = m_peakManager.getPreview
@@ -1116,13 +1030,14 @@ AudioFileManager::drawHighlightedPreview(AudioFileId id,
             ch2Value = values[i * channels + 1];
         }
 
-        if (i < startWidth || i > endWidth) painter.setPen(Qt::gray);
-//            painter.setPen(qApp->palette().color(QPalette::Active,
-//                                                 QColorGroup::Mid));
+        if (i < startWidth || i > endWidth)
+            painter.setPen(Qt::gray);
+            //painter.setPen(qApp->palette().color(QPalette::Active,
+            //                                     QColorGroup::Mid));
         else
             painter.setPen(Qt::black);
-//            painter.setPen(qApp->palette().color(QPalette::Active,
-//                                                 QColorGroup::Dark));
+            //painter.setPen(qApp->palette().color(QPalette::Active,
+            //                                     QColorGroup::Dark));
 
         painter.drawLine(i, static_cast<int>(yStep - ch1Value * yStep),
                          i, static_cast<int>(yStep + ch2Value * yStep));
@@ -1131,21 +1046,20 @@ AudioFileManager::drawHighlightedPreview(AudioFileId id,
 
 
 void
+// cppcheck-suppress unusedFunction
 AudioFileManager::print()
 {
     MutexLock lock (&audioFileManagerLock)
         ;
 
-#ifdef DEBUG_AUDIOFILEMANAGER
     RG_DEBUG << "print():" << m_audioFiles.size() << "entries";
 
     // For each AudioFile
-    for (std::vector<AudioFile *>::const_iterator it = m_audioFiles.begin();
-         it != m_audioFiles.end();
-         ++it) {
-        RG_DEBUG << "  " << (*it)->getId() << " : " << (*it)->getLabel() << " : \"" << (*it)->getFilename() << "\"";
+    for (AudioFile *audioFile : m_audioFiles) {
+        RG_DEBUG << "  " << audioFile->getId() << " : " <<
+                            audioFile->getLabel() << " : \"" <<
+                            audioFile->getAbsoluteFilePath() << "\"";
     }
-#endif
 }
 
 std::vector<SplitPointPair>
@@ -1176,17 +1090,160 @@ AudioFileManager::getActualSampleRates() const
     std::set<int> rates;
 
     // For each AudioFile
-    for (std::vector<AudioFile *>::const_iterator i = m_audioFiles.begin();
-         i != m_audioFiles.end();
-         ++i) {
-
-        unsigned int sr = (*i)->getSampleRate();
-        if (sr != 0) rates.insert(int(sr));
+    for (const AudioFile *audioFile : m_audioFiles) {
+        int sampleRate = audioFile->getSampleRate();
+        if (sampleRate != 0)
+            rates.insert(sampleRate);
     }
 
     return rates;
 }
 
+QString
+AudioFileManager::toAbsolute(const QString &relativePath) const
+{
+    if (relativePath.isEmpty())
+        return relativePath;
+
+    QString absolutePath = relativePath;
+
+    // Convert tilde to home dir.
+    if (absolutePath.left(1) == "~") {
+        absolutePath.remove(0, 1);
+        absolutePath = QDir::homePath() + absolutePath;
+    }
+
+    // Handle double-dot.  A bit messy, but should work.
+    if (absolutePath.left(2) == "..")
+        absolutePath = "./" + absolutePath;
+
+    // Convert dot to .rg file location.
+    if (absolutePath.left(1) == "."  &&  m_document) {
+        absolutePath.remove(0, 1);
+        QString absFilePath = m_document->getAbsFilePath();
+        QFileInfo fileInfo(absFilePath);
+        absolutePath = fileInfo.canonicalPath() + absolutePath;
+    }
+
+    return absolutePath;
+}
+
+void
+AudioFileManager::moveFiles(const QString &newPath)
+{
+    MutexLock lock (&audioFileManagerLock)
+        ;
+
+    SetWaitCursor setWaitCursor;
+
+    QString newPath2 = toAbsolute(newPath);
+    newPath2 = addTrailingSlash(newPath2);
+
+    // for each audio file
+    for (AudioFile *audioFile : m_audioFiles)
+    {
+        const QString oldName = audioFile->getAbsoluteFilePath();
+
+        QFileInfo fileInfo(oldName);
+        const QString newName = newPath2 + fileInfo.fileName();
+
+        // If there is no actual change, try the next.
+        if (newName == oldName)
+            continue;
+
+        // Delete the old peak file.
+        // ??? It would be more clever to just move the .pk file.
+        //     Might want to look into doing that instead.
+        m_peakManager.deletePeakFile(audioFile);
+
+        // Close the old file.
+        audioFile->close();
+
+        // Move it to the new path.
+        const bool success = QFile::rename(oldName, newName);
+
+        if (!success) {
+            RG_WARNING << "moveFiles(): rename failed for:";
+            RG_WARNING << "  oldName:" << oldName;
+            RG_WARNING << "  newName:" << newName;
+        }
+
+        // Adjust the stored path for this file.
+        audioFile->setAbsoluteFilePath(newName);
+
+        // Open the file in its new location.
+        audioFile->open();
+
+        // Create the peak file in the new location.
+        m_peakManager.generatePeaks(audioFile);
+    }
+
+    // Reset sequencer audio so that we can hear the audio files again.
+    m_document->prepareAudio();
+}
+
+void
+AudioFileManager::save()
+{
+    // We've saved, so we don't want to delete the audio files that
+    // have been created up to now.
+    resetRecentlyCreatedFiles();
+
+    // If the user has already confirmed the audio location, bail.
+    if (m_audioLocationConfirmed)
+        return;
+
+    // No audio files?  No need to prompt for save location.  Bail.
+    if (m_audioFiles.empty())
+        return;
+
+    QFileInfo fileInfo(m_document->getAbsFilePath());
+    const QString documentNameDir = "./" + fileInfo.completeBaseName();
+
+    // If the preferences indicate prompting
+    if (!Preferences::getAudioFileLocationDlgDontShow())
+    {
+
+        // Ask the user to pick an audio file path.
+        // Results go to the Preferences.
+        AudioFileLocationDialog audioFileLocationDialog(
+                RosegardenMainWindow::self(),
+                documentNameDir);
+        audioFileLocationDialog.exec();
+
+    }
+
+    const AudioFileLocationDialog::Location location =
+            static_cast<AudioFileLocationDialog::Location>(
+                    Preferences::getDefaultAudioLocation());
+
+    // Indicate audio location was confirmed by the user.
+    // Also avoid recursion loop as the second save will end up here again.
+    m_audioLocationConfirmed = true;
+
+    QString audioPath = "./audio";
+
+    switch (location) {
+    case AudioFileLocationDialog::AudioDir:
+        audioPath = "./audio";
+        break;
+    case AudioFileLocationDialog::DocumentNameDir:
+        audioPath = documentNameDir;
+        break;
+    case AudioFileLocationDialog::DocumentDir:
+        audioPath = ".";
+        break;
+    case AudioFileLocationDialog::CentralDir:
+        audioPath = "~/rosegarden-audio";
+        break;
+    case AudioFileLocationDialog::CustomDir:
+        audioPath = Preferences::getCustomAudioLocation();
+        break;
+    }
+
+    // Set the new location, move the files, and save.
+    setRelativeAudioPath(audioPath, true);
 }
 
 
+}
