@@ -26,6 +26,7 @@
 #include "Audit.h"
 #include "PluginFactory.h"
 #include "SequencerDataBlock.h"
+#include "sound/WAVExporter.h"
 
 #include "misc/ConfigGroups.h"
 #include "misc/Debug.h"
@@ -73,7 +74,9 @@ JackDriver::JackDriver(AlsaDriver *alsaDriver) :
         m_haveAsyncAudioEvent(false),
         m_kickedOutAt(0),
         m_framesProcessed(0),
-        m_ok(false)
+        m_ok(false),
+        m_playing(false),
+        m_exportManager(nullptr)
 {
     initialise();
 }
@@ -854,6 +857,22 @@ JackDriver::jackProcess(jack_nframes_t nframes)
     // receiving midi input so always process async audio
     bool asyncAudio = m_haveAsyncAudioEvent || (synthCount > 0);
 
+    if (m_exportManager) {
+        // Transitioning to play.
+        if (playing  &&  !m_playing) {
+            RG_DEBUG << "export start playing";
+            m_exportManager->start();
+        }
+        // Transitioning to stop.
+        if (!playing  &&  m_playing) {
+            RG_DEBUG << "export stop playing";
+            m_exportManager->stop();
+            // finished with the exportManager - it is deleted elsewhere
+            m_exportManager = nullptr;
+        }
+        m_playing = playing;
+    }
+
 #ifdef DEBUG_JACK_PROCESS
     Profiler profiler("jackProcess", true);
 #else
@@ -1289,6 +1308,11 @@ JackDriver::jackProcess(jack_nframes_t nframes)
         }
     }
 
+
+    if (m_exportManager && playing) {
+        m_exportManager->addSamples(master[0], master[1], m_bufferSize);
+    }
+
     if (playing) {
         if (!lowLatencyMode) {
             if (m_bussMixer->getBussCount() == 0) {
@@ -2536,6 +2560,12 @@ JackDriver::reportFailure(MappedEvent::FailureCode code)
         m_alsaDriver->reportFailure(code);
 }
 
+void
+JackDriver::installExporter(WAVExporter* wavExporter)
+{
+    m_exportManager = wavExporter;
+}
+
 
 }
 
