@@ -149,10 +149,11 @@ LV2PluginInstance::LV2PluginInstance(
     setupFeatures();
 
     instantiate(sampleRate);
-    if (isOK()) {
-        connectPorts();
-        activate();
-    }
+    if (! isOK()) return;
+
+    connectPorts();
+    activate();
+
     m_workerInterface = (LV2_Worker_Interface*)
         lilv_instance_get_extension_data(m_instance, LV2_WORKER__interface);
     RG_DEBUG << "worker interface" << m_workerInterface;
@@ -240,7 +241,7 @@ LV2PluginInstance::init(int idealChannelCount)
                 if (portData.isInput) {
                     RG_DEBUG << "LV2PluginInstance::init: port" <<
                         i << "is control in";
-                    m_controlPortsIn[i] = 0.0;
+                    m_controlPortsIn[i] = portData.def;
                 } else {
                     RG_DEBUG << "LV2PluginInstance::init: port" <<
                         i << "is control out";
@@ -864,6 +865,7 @@ LV2PluginInstance::setPortByteArray(unsigned int port,
 {
     RG_DEBUG << "setPortByteArray" << port << protocol;
     if (protocol == m_atomTransferUrid) {
+        QMutexLocker lock(&m_atomInputMutex);
         for (const AtomPort& ap : m_atomInputPorts) {
             if (ap.index == port) {
                 RG_DEBUG << "setPortByteArray send bytes" << ba.size() <<
@@ -1216,7 +1218,23 @@ LV2PluginInstance::run(const RealTime &rt)
     //
     //     See the "if" above for m_instance->lv2_descriptor.  Remove it
     //     to see the crashes.
-    lilv_instance_run(m_instance, m_blockSize);
+    {
+        QMutexLocker lock(&m_atomInputMutex);
+        lilv_instance_run(m_instance, m_blockSize);
+        // clear atom in buffers
+        for (const AtomPort &ap : m_atomInputPorts) {
+            lv2_atom_sequence_clear(ap.atomSeq);
+        }
+    }
+
+    for (const AtomPort &ap : m_atomOutputPorts) {
+        if (ap.atomSeq->atom.size == 8 * ABUFSIZED - 8) {
+            // if the plugin has not touched the output buffer it
+            // should be reset
+            RG_DEBUG << "run resetting unused buffer" << ap.index;
+            lv2_atom_sequence_clear(ap.atomSeq);
+        }
+    }
 
     /*
     // debug
@@ -1256,11 +1274,6 @@ LV2PluginInstance::run(const RealTime &rt)
         if (m_workerInterface->end_run) m_workerInterface->end_run(m_instance);
     }
 
-    // clear atom in buffers
-    for (const AtomPort &ap : m_atomInputPorts) {
-        lv2_atom_sequence_clear(ap.atomSeq);
-    }
-
     // get atom out data
     for (const AtomPort &ap : m_atomOutputPorts) {
         //RG_DEBUG << "check atom out" << ap.index;
@@ -1398,6 +1411,9 @@ void LV2PluginInstance::sendMidiData(const QByteArray& rawMidi,
         midiBuf[ebs + ib] = rawMidi[ib];
     }
 
+    // Guard writing to m_atomInputPorts.
+    QMutexLocker lock(&m_atomInputMutex);
+
     for (const AtomPort &aip : m_atomInputPorts) {
         if (aip.isMidi) {
             LV2_Atom_Event* atom =
