@@ -260,7 +260,7 @@ insertCopy(const MappedEvent &evt)
                     m_ramping = (evt.getData1() > 0) ? true : false;
                     // Yes, we fetch it from "instrument" because
                     // that's what TempoSegmentMapper puts it in.
-                    tempoT tempo = evt.getInstrument();
+                    tempoT tempo = evt.getInstrumentId();
                     RG_DEBUG << "insertCopy tempo" << evt.getEventTime() <<
                         midiEventAbsoluteTime << tempo;
                     trackData.insertTempo(midiEventAbsoluteTime, tempo);
@@ -417,6 +417,22 @@ insertCopy(const MappedEvent &evt)
                     break;
                 }
 
+            case MappedEvent::MidiRPN:
+                {
+                    // ??? How do we implement this?  As a series of
+                    //     trackData.insertMidiEvent() calls for each piece?
+
+                    break;
+                }
+
+            case MappedEvent::MidiNRPN:
+                {
+                    // ??? How do we implement this?  As a series of
+                    //     trackData.insertMidiEvent() calls for each piece?
+
+                    break;
+                }
+
             case MappedEvent::Marker:
                 {
                     std::string metaMessage =
