@@ -3,9 +3,9 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2024 the Rosegarden development team.
     See the AUTHORS file for more details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -17,7 +17,6 @@
 
 #include "RIFFAudioFile.h"
 #include "base/RealTime.h"
-#include "base/Profiler.h"
 #include "misc/Strings.h"
 #include "misc/Debug.h"
 
@@ -35,20 +34,20 @@ namespace Rosegarden
 
 RIFFAudioFile::RIFFAudioFile(unsigned int id,
                              const std::string &name,
-                             const QString &fileName):
-    AudioFile(id, name, fileName),
+                             const QString &absoluteFilePath):
+    AudioFile(id, name, absoluteFilePath),
     m_subFormat(PCM),
     m_bytesPerSecond(0),
     m_bytesPerFrame(0)
 {}
 
-RIFFAudioFile::RIFFAudioFile(const QString &fileName,
+RIFFAudioFile::RIFFAudioFile(const QString &absoluteFilePath,
                              unsigned int channels = 1,
                              unsigned int sampleRate = 48000,
                              unsigned int bytesPerSecond = 6000,
                              unsigned int bytesPerFrame = 2,
                              unsigned int bitsPerSample = 16):
-        AudioFile(0, "", fileName)
+        AudioFile(0, "", absoluteFilePath)
 {
     m_bitsPerSample = bitsPerSample;
     m_sampleRate = sampleRate;
@@ -61,7 +60,7 @@ RIFFAudioFile::RIFFAudioFile(const QString &fileName,
     else if (bitsPerSample == 32)
         m_subFormat = FLOAT;
     else
-        throw(BadSoundFileException(m_fileName, qstrtostr(QObject::tr("Rosegarden currently only supports 16 or 32-bit PCM or IEEE floating-point RIFF files for writing"))));
+        throw(BadSoundFileException(m_absoluteFilePath, qstrtostr(tr("Rosegarden currently only supports 16 or 32-bit PCM or IEEE floating-point RIFF files for writing"))));
 
 }
 
@@ -74,7 +73,7 @@ RIFFAudioFile::~RIFFAudioFile()
 void
 RIFFAudioFile::printStats()
 {
-    RG_DEBUG << "filename         : " << m_fileName << '\n'
+    RG_DEBUG << "filename         : " << m_absoluteFilePath << '\n'
     << "channels         : " << m_channels << '\n'
     << "sample rate      : " << m_sampleRate << '\n'
     << "bytes per second : " << m_bytesPerSecond << '\n'
@@ -172,7 +171,7 @@ RIFFAudioFile::scanTo(std::ifstream *file, const RealTime &time)
 
         // check we've got data chunk start
 	std::string chunkName;
-	int chunkLength = 0;
+        int chunkLength;
 
         while ((chunkName = getBytes(file, 4)) != "data") {
 	    if (file->eof()) {
@@ -192,12 +191,13 @@ RIFFAudioFile::scanTo(std::ifstream *file, const RealTime &time)
         }
 
         // get the length of the data chunk, and scan past it as a side-effect
+        // cppcheck-suppress unreadVariable
 	chunkLength = getIntegerFromLittleEndian(getBytes(file, 4));
 #ifdef DEBUG_RIFF
         RG_DEBUG << "RIFFAudioFile::scanTo() - data chunk size =" << chunkLength;
 #endif
 
-    } catch (BadSoundFileException s) {
+    } catch (const BadSoundFileException &s) {
 #ifdef DEBUG_RIFF
         RG_WARNING << "RIFFAudioFile::scanTo - EXCEPTION - \"" << s.getMessage() << "\"";
 #endif
@@ -254,7 +254,7 @@ RIFFAudioFile::getSampleFrames(std::ifstream *file, unsigned int frames)
 
     try {
         return getBytes(file, totalBytes);
-    } catch (BadSoundFileException s) {
+    } catch (const BadSoundFileException &s) {
         return "";
     }
 }
@@ -267,7 +267,7 @@ RIFFAudioFile::getSampleFrames(std::ifstream *file, char *buf,
         return 0;
     try {
         return getBytes(file, buf, frames * m_bytesPerFrame) / m_bytesPerFrame;
-    } catch (BadSoundFileException s) {
+    } catch (const BadSoundFileException &s) {
         return 0;
     }
 }
@@ -296,7 +296,7 @@ RIFFAudioFile::getSampleFrameSlice(std::ifstream *file, const RealTime &time)
 
     try {
         return getBytes(file, totalBytes);
-    } catch (BadSoundFileException s) {
+    } catch (const BadSoundFileException &s) {
         return "";
     }
 }
@@ -325,7 +325,8 @@ RIFFAudioFile::getLength()
         headerLength += (16 + 8);
     }
 
-    if (!m_bytesPerFrame || !m_sampleRate) return RealTime::zeroTime;
+    if (!m_bytesPerFrame || !m_sampleRate)
+        return RealTime::zero();
 
     double frames = (m_fileSize - headerLength) / m_bytesPerFrame;
     double seconds = frames / ((double)m_sampleRate);
@@ -371,7 +372,7 @@ RIFFAudioFile::readFormatChunk()
         << "can't find RIFF identifier\n";
 #endif
 
-        throw(BadSoundFileException(m_fileName, qstrtostr(QObject::tr("Can't find RIFF identifier"))));
+        throw(BadSoundFileException(m_absoluteFilePath, qstrtostr(tr("Can't find RIFF identifier"))));
     }
 
     // Look for the WAV identifier
@@ -381,7 +382,7 @@ RIFFAudioFile::readFormatChunk()
         RG_WARNING << "Can't find WAV identifier\n";
 #endif
 
-        throw(BadSoundFileException(m_fileName, qstrtostr(QObject::tr("Can't find WAV identifier"))));
+        throw(BadSoundFileException(m_absoluteFilePath, qstrtostr(tr("Can't find WAV identifier"))));
     }
 
     // Look for the FORMAT identifier - note that this doesn't actually
@@ -394,7 +395,7 @@ RIFFAudioFile::readFormatChunk()
         RG_WARNING << "Can't find FORMAT identifier\n";
 #endif
 
-        throw(BadSoundFileException(m_fileName, qstrtostr(QObject::tr("Can't find FORMAT identifier"))));
+        throw(BadSoundFileException(m_absoluteFilePath, qstrtostr(tr("Can't find FORMAT identifier"))));
     }
 
     // Little endian conversion of length bytes into file length
@@ -444,7 +445,7 @@ RIFFAudioFile::readFormatChunk()
     } else if (subFormat == 0x03) {
         m_subFormat = FLOAT;
     } else {
-        throw(BadSoundFileException(m_fileName, qstrtostr(QObject::tr("Rosegarden currently only supports PCM or IEEE floating-point RIFF files"))));
+        throw(BadSoundFileException(m_absoluteFilePath, qstrtostr(tr("Rosegarden currently only supports PCM or IEEE floating-point RIFF files"))));
     }
 
     // We seem to have a good looking .WAV file - extract the
@@ -459,7 +460,7 @@ RIFFAudioFile::readFormatChunk()
         break;
 
     default: {
-            throw(BadSoundFileException(m_fileName, qstrtostr(QObject::tr("Unsupported number of channels"))));
+            throw(BadSoundFileException(m_absoluteFilePath, qstrtostr(tr("Unsupported number of channels"))));
         }
         break;
     }
@@ -473,11 +474,11 @@ RIFFAudioFile::readFormatChunk()
 
     if (m_subFormat == PCM) {
         if (m_bitsPerSample != 8 && m_bitsPerSample != 16 && m_bitsPerSample != 24) {
-            throw BadSoundFileException(QObject::tr("Rosegarden currently only supports 8-, 16- or 24-bit PCM in RIFF files"));
+            throw BadSoundFileException(tr("Rosegarden currently only supports 8-, 16- or 24-bit PCM in RIFF files"));
         }
     } else if (m_subFormat == FLOAT) {
         if (m_bitsPerSample != 32) {
-            throw BadSoundFileException(QObject::tr("Rosegarden currently only supports 32-bit floating-point in RIFF files"));
+            throw BadSoundFileException(tr("Rosegarden currently only supports 32-bit floating-point in RIFF files"));
         }
     }
 
@@ -594,20 +595,20 @@ RIFFAudioFile::identifySubType(const QString &filename)
 }
 
 float
-RIFFAudioFile::convertBytesToSample(const unsigned char *ubuf)
+RIFFAudioFile::convertBytesToSample(const unsigned char *bytes) const
 {
     switch (getBitsPerSample()) {
 
     case 8: {
             // WAV stores 8-bit samples unsigned, other sizes signed.
-            return (float)(ubuf[0] - 128.0) / 128.0;
+            return (float)(bytes[0] - 128.0) / 128.0;
         }
 
     case 16: {
             // Two's complement little-endian 16-bit integer.
             // We convert endianness (if necessary) but assume 16-bit short.
-            unsigned char b2 = ubuf[0];
-            unsigned char b1 = ubuf[1];
+            unsigned char b2 = bytes[0];
+            unsigned char b1 = bytes[1];
             unsigned int bits = (b1 << 8) + b2;
             return (float)(short(bits)) / 32768.0;
         }
@@ -615,9 +616,9 @@ RIFFAudioFile::convertBytesToSample(const unsigned char *ubuf)
     case 24: {
             // Two's complement little-endian 24-bit integer.
             // Again, convert endianness but assume 32-bit int.
-            unsigned char b3 = ubuf[0];
-            unsigned char b2 = ubuf[1];
-            unsigned char b1 = ubuf[2];
+            unsigned char b3 = bytes[0];
+            unsigned char b2 = bytes[1];
+            unsigned char b1 = bytes[2];
             // Rotate 8 bits too far in order to get the sign bit
             // in the right place; this gives us a 32-bit value,
             // hence the larger float divisor
@@ -627,7 +628,8 @@ RIFFAudioFile::convertBytesToSample(const unsigned char *ubuf)
 
     case 32: {
             // IEEE floating point
-            return *(float *)ubuf;
+            // cppcheck-suppress invalidPointerCast
+            return *(float *)bytes;
         }
 
     default:
@@ -636,4 +638,3 @@ RIFFAudioFile::convertBytesToSample(const unsigned char *ubuf)
 }
 
 }
-
